@@ -21,8 +21,8 @@ import org.kie.workbench.common.dmn.client.widgets.grid.BaseExpressionGridRender
 public class FunctionGridRenderer extends BaseExpressionGridRenderer {
 
     @SuppressWarnings("unused")
-    public FunctionGridRenderer(final boolean hideHeader) {
-        //TODO {manstis} We need to hide only the first header row when hideHeader is true
+    public FunctionGridRenderer(final boolean isHeaderHidden) {
+        //TODO {manstis} We need to hide only the first header row when header is hidden
         super(false);
     }
 }
\ No newline at end of file
