@@ -19,14 +19,17 @@ package org.kie.workbench.common.dmn.client.session;
 import javax.enterprise.context.Dependent;
 import javax.inject.Inject;
 
+import org.jboss.errai.ioc.client.api.Disposer;
 import org.kie.workbench.common.dmn.api.qualifiers.DMNEditor;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvas;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.canvas.CanvasFactory;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.CanvasControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.actions.CanvasInPlaceTextEditorControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.builder.ElementBuilderControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.clipboard.ClipboardControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.connection.ConnectionAcceptorControl;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.connection.ControlPointControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.containment.ContainmentAcceptorControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.docking.DockingAcceptorControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.drag.LocationControl;
@@ -59,7 +62,8 @@ public class DMNClientFullSession extends AbstractClientFullSession {
                                 final CanvasCommandManager<AbstractCanvasHandler> canvasCommandManager,
                                 final @Session SessionCommandManager<AbstractCanvasHandler> sessionCommandManager,
                                 final @Request SessionCommandManager<AbstractCanvasHandler> requestCommandManager,
-                                final RegistryFactory registryFactory) {
+                                final RegistryFactory registryFactory,
+                                final Disposer<CanvasControl> canvasControlDisposer) {
         super(factory.newCanvas(),
               factory.newCanvasHandler(),
               factory.newControl(SelectionControl.class),
@@ -74,7 +78,9 @@ public class DMNClientFullSession extends AbstractClientFullSession {
               factory.newControl(DockingAcceptorControl.class),
               factory.newControl(ElementBuilderControl.class),
               factory.newControl(KeyboardControl.class),
-              factory.newControl(ClipboardControl.class));
+              factory.newControl(ClipboardControl.class),
+              factory.newControl(ControlPointControl.class),
+              canvasControlDisposer);
         this.locationControl = factory.newControl(LocationControl.class);
         this.resizeControl = factory.newControl(ResizeControl.class);
         this.canvasInPlaceTextEditorControl = factory.newControl(CanvasInPlaceTextEditorControl.class);
@@ -88,18 +94,6 @@ public class DMNClientFullSession extends AbstractClientFullSession {
         canvasInPlaceTextEditorControl.setCommandManagerProvider(() -> sessionCommandManager);
     }
 
-    @Override
-    protected void doPause() {
-        getKeyboardControl().disable();
-        super.doPause();
-    }
-
-    @Override
-    protected void doResume() {
-        getKeyboardControl().enable(getCanvas());
-        super.doResume();
-    }
-
     public LocationControl<AbstractCanvasHandler, Element> getLocationControl() {
         return locationControl;
     }
