@@ -30,18 +30,17 @@ import org.kie.workbench.common.forms.dynamic.client.init.FormHandlerGeneratorMa
 import org.kie.workbench.common.forms.dynamic.client.rendering.FieldLayoutComponent;
 import org.kie.workbench.common.forms.dynamic.client.rendering.FieldRenderer;
 import org.kie.workbench.common.forms.dynamic.client.rendering.renderers.RequiresValueConverter;
-import org.kie.workbench.common.forms.dynamic.client.rendering.renderers.relations.subform.widget.SubFormWidget;
 import org.kie.workbench.common.forms.dynamic.service.shared.FormRenderingContext;
 import org.kie.workbench.common.forms.dynamic.service.shared.RenderMode;
 import org.kie.workbench.common.forms.dynamic.service.shared.adf.DynamicFormModelGenerator;
-import org.kie.workbench.common.forms.fields.shared.fieldTypes.relations.subForm.definition.SubFormFieldDefinition;
 import org.kie.workbench.common.forms.model.FieldDefinition;
 import org.kie.workbench.common.forms.processing.engine.handling.FieldChangeHandler;
 import org.kie.workbench.common.forms.processing.engine.handling.FormHandler;
 import org.uberfire.mvp.Command;
 
 @Dependent
-public class DynamicFormRenderer implements IsWidget, IsFormView {
+public class DynamicFormRenderer implements IsWidget,
+                                            IsFormView {
 
     public interface DynamicFormRendererView extends IsWidget {
 
@@ -67,7 +66,9 @@ public class DynamicFormRenderer implements IsWidget, IsFormView {
     private DynamicFormModelGenerator dynamicFormModelGenerator;
 
     @Inject
-    public DynamicFormRenderer(DynamicFormRendererView view, FormHandlerGeneratorManager formHandlerGenerator, DynamicFormModelGenerator dynamicFormModelGenerator) {
+    public DynamicFormRenderer(DynamicFormRendererView view,
+                               FormHandlerGeneratorManager formHandlerGenerator,
+                               DynamicFormModelGenerator dynamicFormModelGenerator) {
         this.view = view;
         this.formHandlerGenerator = formHandlerGenerator;
         this.dynamicFormModelGenerator = dynamicFormModelGenerator;
@@ -79,26 +80,43 @@ public class DynamicFormRenderer implements IsWidget, IsFormView {
     }
 
     public void renderDefaultForm(final Object model) {
-        renderDefaultForm(model, RenderMode.EDIT_MODE, null);
+        renderDefaultForm(model,
+                          RenderMode.EDIT_MODE,
+                          null);
     }
 
-    public void renderDefaultForm(final Object model, RenderMode renderMode) {
-        renderDefaultForm(model, renderMode, null);
+    public void renderDefaultForm(final Object model,
+                                  RenderMode renderMode) {
+        renderDefaultForm(model,
+                          renderMode,
+                          null);
     }
 
-    public void renderDefaultForm(final Object model, final Command callback) {
-        renderDefaultForm(model, RenderMode.EDIT_MODE, callback);
+    public void renderDefaultForm(final Object model,
+                                  final Command callback) {
+        renderDefaultForm(model,
+                          RenderMode.EDIT_MODE,
+                          callback);
     }
 
-    public void renderDefaultForm(final Object model, final RenderMode renderMode, final Command callback) {
-        PortablePreconditions.checkNotNull("model", model);
+    public void renderDefaultForm(final Object model,
+                                  final RenderMode renderMode,
+                                  final Command callback) {
+        PortablePreconditions.checkNotNull("model",
+                                           model);
         FormRenderingContext context = dynamicFormModelGenerator.getContextForModel(model);
         if (context != null) {
-            doRenderDefaultForm(context, model, renderMode, callback);
+            doRenderDefaultForm(context,
+                                model,
+                                renderMode,
+                                callback);
         }
     }
 
-    protected void doRenderDefaultForm(FormRenderingContext context, final Object model, final RenderMode renderMode, final Command callback) {
+    protected void doRenderDefaultForm(FormRenderingContext context,
+                                       final Object model,
+                                       final RenderMode renderMode,
+                                       final Command callback) {
         if (renderMode != null) {
             context.setRenderMode(renderMode);
         }
@@ -112,7 +130,10 @@ public class DynamicFormRenderer implements IsWidget, IsFormView {
     }
 
     public void render(FormRenderingContext context) {
-        Assert.notNull("FormRenderingContext must not be null", context);
+        Assert.notNull("FormRenderingContext must not be null",
+                       context);
+
+        unBind();
 
         this.context = context;
 
@@ -126,8 +147,8 @@ public class DynamicFormRenderer implements IsWidget, IsFormView {
 
     public void bind(Object model) {
         if (context != null && model != null) {
-            context.setModel(model);
             formHandler.setUp(model);
+            context.setModel(model);
             view.bind();
         }
     }
@@ -140,7 +161,8 @@ public class DynamicFormRenderer implements IsWidget, IsFormView {
         if (isInitialized() && renderer.getFormField() != null) {
             if (renderer instanceof RequiresValueConverter) {
                 Converter valueConverter = ((RequiresValueConverter) renderer).getConverter();
-                formHandler.registerInput(renderer.getFormField(), valueConverter);
+                formHandler.registerInput(renderer.getFormField(),
+                                          valueConverter);
             } else {
                 formHandler.registerInput(renderer.getFormField());
             }
@@ -148,17 +170,20 @@ public class DynamicFormRenderer implements IsWidget, IsFormView {
     }
 
     public void addFieldChangeHandler(FieldChangeHandler handler) {
-        addFieldChangeHandler(null, handler);
+        addFieldChangeHandler(null,
+                              handler);
     }
 
-    public void addFieldChangeHandler(String fieldName, FieldChangeHandler handler) {
+    public void addFieldChangeHandler(String fieldName,
+                                      FieldChangeHandler handler) {
         if (context != null && isInitialized()) {
             if (fieldName != null) {
                 FieldDefinition field = context.getRootForm().getFieldByName(fieldName);
                 if (field == null) {
                     throw new IllegalArgumentException("Form doesn't contain any field identified by: '" + fieldName + "'");
                 } else {
-                    formHandler.addFieldChangeHandler(fieldName, handler);
+                    formHandler.addFieldChangeHandler(fieldName,
+                                                      handler);
                 }
             } else {
                 formHandler.addFieldChangeHandler(handler);
@@ -168,15 +193,10 @@ public class DynamicFormRenderer implements IsWidget, IsFormView {
 
     public void unBind() {
         if (isInitialized()) {
-            for (FieldDefinition field : context.getRootForm().getFields()) {
-                if (field instanceof SubFormFieldDefinition) {
-                    FieldLayoutComponent component = view.getFieldLayoutComponentForField(field);
-                    SubFormWidget subFormWidget = (SubFormWidget) component.getFieldRenderer().getFormField().getWidget();
-                    subFormWidget.unBind();
-                }
-            }
             formHandler.clear();
             view.clear();
+            formHandler = null;
+            context = null;
         }
     }
 
@@ -192,7 +212,8 @@ public class DynamicFormRenderer implements IsWidget, IsFormView {
     }
 
     public void switchToMode(RenderMode renderMode) {
-        Assert.notNull("RenderMode cannot be null", renderMode);
+        Assert.notNull("RenderMode cannot be null",
+                       renderMode);
         RenderMode currentMode = context.getRenderMode();
         if (context != null && isInitialized() && !currentMode.equals(renderMode)) {
 
@@ -212,18 +233,12 @@ public class DynamicFormRenderer implements IsWidget, IsFormView {
         return isInitialized() && formHandler.validate();
     }
 
-    public void forceModelSynchronization() {
-        if (context != null && RenderMode.EDIT_MODE.equals(context.getRenderMode())) {
-            formHandler.forceModelSynchronization();
-        }
-    }
-
     @Override
     public Widget asWidget() {
         return view.asWidget();
     }
 
-    protected boolean isInitialized() {
-        return formHandler != null;
+    public boolean isInitialized() {
+        return context != null && formHandler != null;
     }
 }
