@@ -1,5 +1,5 @@
 /*
- * Copyright 2016 Red Hat, Inc. and/or its affiliates.
+ * Copyright 2017 Red Hat, Inc. and/or its affiliates.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,9 +17,9 @@
 package org.kie.workbench.common.forms.processing.engine.handling.impl;
 
 import java.util.ArrayList;
-import java.util.Collection;
 import java.util.List;
 import java.util.Optional;
+
 import javax.inject.Inject;
 
 import com.google.gwt.user.client.ui.IsWidget;
@@ -32,34 +32,31 @@ import org.jboss.errai.databinding.client.api.DataBinder;
 import org.jboss.errai.databinding.client.api.StateSync;
 import org.kie.workbench.common.forms.processing.engine.handling.FieldChangeHandler;
 import org.kie.workbench.common.forms.processing.engine.handling.FieldChangeHandlerManager;
+import org.kie.workbench.common.forms.processing.engine.handling.Form;
 import org.kie.workbench.common.forms.processing.engine.handling.FormField;
-import org.kie.workbench.common.forms.processing.engine.handling.FormFieldProvider;
 import org.kie.workbench.common.forms.processing.engine.handling.FormHandler;
 import org.kie.workbench.common.forms.processing.engine.handling.FormValidator;
 import org.kie.workbench.common.forms.processing.engine.handling.IsNestedModel;
 
-public class FormHandlerImpl<T> implements FormHandler<T>,
-                                           FormFieldProvider {
+public class FormHandlerImpl<T> implements FormHandler<T> {
 
     protected FormValidator validator;
 
     protected FieldChangeHandlerManager fieldChangeManager;
 
-    protected FormHandlerHelper<T> handlerHelper;
-
     protected DataBinder<T> binder;
 
-    protected List<FormField> formFields = new ArrayList<>();
-
     protected List<PropertyChangeUnsubscribeHandle> unsubscribeHandlers = new ArrayList<>();
 
+    protected Form form;
+
     @Inject
     public FormHandlerImpl(FormValidator validator,
                            FieldChangeHandlerManager fieldChangeManager) {
         this.validator = validator;
         this.fieldChangeManager = fieldChangeManager;
 
-        this.validator.setFormFieldProvider(this);
+        this.form = new Form();
 
         fieldChangeManager.setValidator(validator);
     }
@@ -79,8 +76,6 @@ public class FormHandlerImpl<T> implements FormHandler<T>,
         clear();
 
         this.binder = binder;
-        this.handlerHelper = new BoundBinderHelper<>(binder,
-                                                     bindInputs);
     }
 
     @Override
@@ -91,7 +86,6 @@ public class FormHandlerImpl<T> implements FormHandler<T>,
         clear();
 
         this.binder = getBinderForModel(model);
-        this.handlerHelper = new NewBinderHelper<>(model);
     }
 
     protected DataBinder<T> getBinderForModel(T model) {
@@ -115,9 +109,9 @@ public class FormHandlerImpl<T> implements FormHandler<T>,
         String fieldName = formField.getFieldName();
         IsWidget widget = formField.getWidget();
 
-        formFields.add(formField);
+        form.addField(formField);
 
-        if (handlerHelper.supportsInputBinding() && formField.isBindable()) {
+        if (formField.isBindable()) {
 
             BindableProxy proxy = (BindableProxy) binder.getModel();
 
@@ -132,8 +126,7 @@ public class FormHandlerImpl<T> implements FormHandler<T>,
                         stateSync);
         }
 
-        fieldChangeManager.registerField(formField.getFieldName(),
-                                         formField.isValidateOnChange());
+        fieldChangeManager.registerField(formField);
 
         formField.getChangeListeners().forEach(listener -> fieldChangeManager.addFieldChangeHandler(listener.getFieldToListen(),
                                                                                                     listener.getChangeHandler()));
@@ -147,15 +140,13 @@ public class FormHandlerImpl<T> implements FormHandler<T>,
 
         if (widget instanceof IsNestedModel) {
             IsNestedModel nestedModelWidget = (IsNestedModel) widget;
-            nestedModelWidget.addFieldChangeHandler((childFieldName, newValue) -> fieldChangeManager.notifyFieldChange(
-                    fieldName + "." + childFieldName,
-                    newValue));
+            nestedModelWidget.addFieldChangeHandler((childFieldName, newValue) -> fieldChangeManager.notifyFieldChange(fieldName + "." + childFieldName,
+                                                                                                                       newValue));
         } else {
-            PropertyChangeUnsubscribeHandle unsubscribeHandle = binder.addPropertyChangeHandler(
-                    formField.getFieldBinding(),
-                    event -> fieldChangeManager.processFieldChange(fieldName,
-                                                                   event.getNewValue(),
-                                                                   binder.getModel()));
+            PropertyChangeUnsubscribeHandle unsubscribeHandle = binder.addPropertyChangeHandler(formField.getFieldBinding(),
+                                                                                                event -> fieldChangeManager.processFieldChange(fieldName,
+                                                                                                                                               event.getNewValue(),
+                                                                                                                                               binder.getModel()));
             unsubscribeHandlers.add(unsubscribeHandle);
         }
     }
@@ -200,105 +191,50 @@ public class FormHandlerImpl<T> implements FormHandler<T>,
 
     @Override
     public boolean validate() {
-        return validator.validate(getModel());
+        return validator.validate(form,
+                                  getModel());
     }
 
     @Override
     public boolean validate(String propertyName) {
-        return validator.validate(propertyName,
+        return validator.validate(form.findFormField(propertyName),
                                   getModel());
     }
 
     @Override
     public void setReadOnly(boolean readOnly) {
-        formFields.forEach(field -> field.setReadOnly(readOnly));
+        form.getFields().forEach(field -> field.setReadOnly(readOnly));
+    }
+
+    public void disableNestedForms() {
+        form.getFields().stream()
+                .filter(formField -> formField.getWidget() instanceof IsNestedModel)
+                .map(formField -> (IsNestedModel) formField.getWidget())
+                .forEach(IsNestedModel::clear);
     }
 
     @Override
     public void clear() {
 
         // Check if it's initialized before clear.
-        if (handlerHelper == null || binder == null) {
+        if (binder == null) {
             return;
         }
 
-        for (PropertyChangeUnsubscribeHandle handle : unsubscribeHandlers) {
-            handle.unsubscribe();
-        }
+        disableNestedForms();
+
+        unsubscribeHandlers.forEach(PropertyChangeUnsubscribeHandle::unsubscribe);
+
         unsubscribeHandlers.clear();
-        formFields.clear();
+
         fieldChangeManager.clear();
-        if (handlerHelper.supportsInputBinding()) {
-            binder.unbind();
-        }
+
+        binder.unbind();
+
+        form = null;
     }
 
     public T getModel() {
-        return handlerHelper.getModel();
-    }
-
-    @Override
-    public FormField findFormField(String fieldName) {
-
-        for (FormField field : formFields) {
-            if (field.getFieldName().equals(fieldName) || fieldName.equals(field.getFieldBinding())) {
-                return field;
-            }
-        }
-
-        return null;
-    }
-
-    @Override
-    public Collection<FormField> getAll() {
-        return formFields;
-    }
-
-    public interface FormHandlerHelper<T> {
-
-        public boolean supportsInputBinding();
-
-        public T getModel();
-    }
-
-    protected class BoundBinderHelper<T> implements FormHandlerHelper {
-
-        private boolean bindInputs;
-        private DataBinder<T> dataBinder;
-
-        public BoundBinderHelper(DataBinder<T> dataBinder,
-                                 boolean bindInputs) {
-            this.dataBinder = dataBinder;
-            this.bindInputs = bindInputs;
-        }
-
-        @Override
-        public boolean supportsInputBinding() {
-            return bindInputs;
-        }
-
-        @Override
-        public T getModel() {
-            return dataBinder.getModel();
-        }
-    }
-
-    protected class NewBinderHelper<T> implements FormHandlerHelper {
-
-        private T model;
-
-        public NewBinderHelper(T model) {
-            this.model = model;
-        }
-
-        @Override
-        public boolean supportsInputBinding() {
-            return true;
-        }
-
-        @Override
-        public T getModel() {
-            return model;
-        }
+        return binder.getModel();
     }
 }
