@@ -17,6 +17,7 @@ package org.kie.workbench.common.forms.editor.backend.service.impl;
 
 import java.util.List;
 import java.util.Optional;
+
 import javax.enterprise.context.ApplicationScoped;
 import javax.enterprise.event.Event;
 import javax.inject.Inject;
@@ -31,24 +32,24 @@ import org.kie.workbench.common.forms.editor.model.FormModelSynchronizationResul
 import org.kie.workbench.common.forms.editor.model.FormModelerContent;
 import org.kie.workbench.common.forms.editor.service.backend.FormModelHandler;
 import org.kie.workbench.common.forms.editor.service.backend.FormModelHandlerManager;
-import org.kie.workbench.common.forms.editor.service.backend.util.UIDGenerator;
 import org.kie.workbench.common.forms.editor.service.shared.FormEditorRenderingContext;
 import org.kie.workbench.common.forms.editor.service.shared.FormEditorService;
 import org.kie.workbench.common.forms.editor.service.shared.VFSFormFinderService;
 import org.kie.workbench.common.forms.model.FieldDefinition;
 import org.kie.workbench.common.forms.model.FormDefinition;
 import org.kie.workbench.common.forms.model.FormModel;
-import org.kie.workbench.common.forms.model.HasFormModelProperties;
-import org.kie.workbench.common.forms.serialization.FormDefinitionSerializer;
 import org.kie.workbench.common.forms.service.shared.FieldManager;
+import org.kie.workbench.common.forms.services.backend.serialization.FormDefinitionSerializer;
+import org.kie.workbench.common.forms.services.backend.util.UIDGenerator;
 import org.kie.workbench.common.services.backend.service.KieService;
-import org.kie.workbench.common.services.shared.project.KieProject;
-import org.kie.workbench.common.services.shared.project.KieProjectService;
+import org.kie.workbench.common.services.shared.project.KieModule;
+import org.kie.workbench.common.services.shared.project.KieModuleService;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.uberfire.backend.server.util.Paths;
 import org.uberfire.backend.vfs.Path;
 import org.uberfire.ext.editor.commons.service.DeleteService;
+import org.uberfire.ext.editor.commons.service.RenameService;
 import org.uberfire.ext.layout.editor.api.editor.LayoutTemplate;
 import org.uberfire.io.IOService;
 import org.uberfire.java.nio.file.FileAlreadyExistsException;
@@ -59,24 +60,16 @@ import org.uberfire.workbench.events.ResourceOpenedEvent;
 @ApplicationScoped
 public class FormEditorServiceImpl extends KieService<FormModelerContent> implements FormEditorService {
 
-    private Logger log = LoggerFactory.getLogger(FormEditorServiceImpl.class);
-
-    private IOService ioService;
-
-    private SessionInfo sessionInfo;
-
-    private Event<ResourceOpenedEvent> resourceOpenedEvent;
-
     protected FieldManager fieldManager;
-
     protected FormModelHandlerManager modelHandlerManager;
-
     protected FormDefinitionSerializer formDefinitionSerializer;
-
     protected VFSFormFinderService vfsFormFinderService;
-
     protected DeleteService deleteService;
-
+    protected RenameService renameService;
+    private Logger log = LoggerFactory.getLogger(FormEditorServiceImpl.class);
+    private IOService ioService;
+    private SessionInfo sessionInfo;
+    private Event<ResourceOpenedEvent> resourceOpenedEvent;
     private CommentedOptionFactory commentedOptionFactory;
 
     @Inject
@@ -85,21 +78,23 @@ public class FormEditorServiceImpl extends KieService<FormModelerContent> implem
                                  Event<ResourceOpenedEvent> resourceOpenedEvent,
                                  FieldManager fieldManager,
                                  FormModelHandlerManager modelHandlerManager,
-                                 KieProjectService projectService,
+                                 KieModuleService moduleService,
                                  FormDefinitionSerializer formDefinitionSerializer,
                                  VFSFormFinderService vfsFormFinderService,
                                  DeleteService deleteService,
-                                 CommentedOptionFactory commentedOptionFactory) {
+                                 CommentedOptionFactory commentedOptionFactory,
+                                 RenameService renameService) {
         this.ioService = ioService;
         this.sessionInfo = sessionInfo;
         this.resourceOpenedEvent = resourceOpenedEvent;
         this.fieldManager = fieldManager;
         this.modelHandlerManager = modelHandlerManager;
-        this.projectService = projectService;
+        this.moduleService = moduleService;
         this.formDefinitionSerializer = formDefinitionSerializer;
         this.vfsFormFinderService = vfsFormFinderService;
         this.commentedOptionFactory = commentedOptionFactory;
         this.deleteService = deleteService;
+        this.renameService = renameService;
     }
 
     @Override
@@ -139,9 +134,9 @@ public class FormEditorServiceImpl extends KieService<FormModelerContent> implem
     public void delete(Path path,
                        String comment) {
         try {
-            KieProject project = projectService.resolveProject(path);
-            if (project == null) {
-                logger.warn("Form : " + path.toURI() + " does not belong to a valid project");
+            KieModule module = moduleService.resolveModule(path);
+            if (module == null) {
+                logger.warn("Form : " + path.toURI() + " does not belong to a valid module");
                 return;
             }
 
@@ -167,6 +162,34 @@ public class FormEditorServiceImpl extends KieService<FormModelerContent> implem
         return path;
     }
 
+    @Override
+    public FormModelerContent rename(Path path,
+                                     String newFileName,
+                                     String commitMessage,
+                                     boolean saveBeforeRenaming,
+                                     FormModelerContent content,
+                                     Metadata metadata) {
+
+        FormModelerContent contentToSave = content;
+        if (!saveBeforeRenaming) {
+            contentToSave = constructContent(path,
+                                             content.getOverview());
+        }
+
+        contentToSave.getDefinition().setName(newFileName);
+
+        save(path,
+             contentToSave,
+             metadata,
+             commitMessage);
+
+        renameService.rename(path,
+                             newFileName,
+                             commitMessage);
+
+        return contentToSave;
+    }
+
     @Override
     protected FormModelerContent constructContent(Path path,
                                                   Overview overview) {
@@ -185,29 +208,26 @@ public class FormEditorServiceImpl extends KieService<FormModelerContent> implem
 
             formModelConent.setRenderingContext(context);
 
-            if (Optional.ofNullable(form.getModel()).isPresent() && form.getModel() instanceof HasFormModelProperties) {
+            if (Optional.ofNullable(form.getModel()).isPresent()) {
 
-                HasFormModelProperties formModel = (HasFormModelProperties) form.getModel();
+                FormModel formModel = form.getModel();
 
-                Optional<FormModelHandler> modelOptional = getHandlerForForm(form,
-                                                                             path);
-                if (modelOptional.isPresent()) {
+                Optional<FormModelHandler> modelHandlerOptional = getHandlerForForm(form,
+                                                                                    path);
+                if (modelHandlerOptional.isPresent()) {
 
-                    FormModelHandler formModelHandler = modelOptional.get();
+                    FormModelHandler formModelHandler = modelHandlerOptional.get();
 
                     FormModelSynchronizationResult synchronizationResult = formModelHandler.synchronizeFormModel();
 
                     formModel.getProperties().forEach(property -> {
                         Optional<FieldDefinition> fieldOptional = Optional.ofNullable(form.getFieldByBinding(property.getName()));
                         if (!fieldOptional.isPresent()) {
-                            formModelConent.getAvailableFields().add(formModelHandler.createFieldDefinition(property));
                             synchronizationResult.resolveConflict(property.getName());
                         }
                     });
 
                     formModelConent.setSynchronizationResult(synchronizationResult);
-
-                    formModelConent.getModelProperties().addAll(formModel.getProperties());
                 }
             }
 
@@ -253,14 +273,10 @@ public class FormEditorServiceImpl extends KieService<FormModelerContent> implem
     protected Optional<FormModelHandler> getHandlerForForm(FormDefinition form,
                                                            Path path) {
 
-        if (!(form.getModel() instanceof HasFormModelProperties)) {
-            return Optional.empty();
-        }
-
         Optional<FormModelHandler> optional = Optional.ofNullable(modelHandlerManager.getFormModelHandler(form.getModel().getClass()));
 
         if (optional.isPresent()) {
-            optional.get().init((HasFormModelProperties) form.getModel(),
+            optional.get().init(form.getModel(),
                                 path);
         }
         return optional;
