@@ -56,8 +56,16 @@ import org.uberfire.ext.editor.commons.client.history.VersionRecordManager;
 import org.uberfire.ext.plugin.client.perspective.editor.layout.editor.HTMLLayoutDragComponent;
 import org.uberfire.mocks.CallerMock;
 
-import static org.junit.Assert.*;
-import static org.mockito.Mockito.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertTrue;
+import static org.mockito.Mockito.any;
+import static org.mockito.Mockito.anyString;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.spy;
+import static org.mockito.Mockito.when;
 
 @RunWith(GwtMockitoTestRunner.class)
 public class FormEditorHelperTest {
@@ -210,17 +218,22 @@ public class FormEditorHelperTest {
 
     @Test
     public void testGetFormFieldAvailable() {
-        FieldDefinition resultField = formEditorHelper.getAvailableFields().values().stream().filter( fieldDefinition -> fieldDefinition.getBinding().equals(nameField.getBinding())).findFirst().get();
+        FieldDefinition resultField = formEditorHelper.getAvailableFields().values().stream().filter(fieldDefinition -> fieldDefinition.getBinding().equals(nameField.getBinding())).findFirst().get();
 
         formEditorHelper.saveFormField(nameField,
                                        resultField);
 
         Assertions.assertThat(resultField)
                 .isNotNull()
-                .isEqualToComparingOnlyGivenFields(nameField, "name", "binding", "standaloneClassName");
+                .isEqualToComparingOnlyGivenFields(nameField,
+                                                   "name",
+                                                   "binding",
+                                                   "standaloneClassName");
 
         Assertions.assertThat(content.getDefinition().getFieldById(resultField.getId())).isNotNull();
 
+        Assertions.assertThat(content.getDefinition().getFields()).contains(resultField).doesNotContain(nameField);
+
         Assertions.assertThat(formEditorHelper.getAvailableFields().size()).isEqualTo(employeeFields.size() - 1);
     }
 
@@ -266,77 +279,83 @@ public class FormEditorHelperTest {
 
     @Test
     public void testRemoveFieldsNotAddToAvailableNoFields() {
-        testRemoveFields(false,
-                         false);
+        testRemoveFields(false);
     }
 
     @Test
     public void testRemoveFieldsAddToAvailable() {
-        testRemoveFields(true,
-                         true);
+        testRemoveFields(true);
     }
 
-    @Test
-    public void testRemoveFieldsNotAddToAvailable() {
-        testRemoveFields(false,
-                         true);
-    }
+    private void testRemoveFields(boolean addToAvailable) {
+        content.getDefinition().getFields().addAll(employeeFields);
+        formEditorHelper.getAvailableFields().clear();
 
-    @Test
-    public void testRemoveFieldsAddToAvailableNoFields() {
-        testRemoveFields(true,
-                         false);
-    }
-
-    private void testRemoveFields(boolean addToAvailable,
-                                  boolean definitionHasFields) {
-        if (definitionHasFields) {
-            content.getDefinition().getFields().addAll(employeeFields);
-            formEditorHelper.getAvailableFields().clear();
-        }
         int prevAvailableSize = formEditorHelper.getAvailableFields().size();
-        FieldDefinition removedField = formEditorHelper.removeField(nameField.getId(),
-                                                                    addToAvailable);
+        formEditorHelper.removeField(nameField.getId(), addToAvailable);
+
         assertEquals("It should " + (addToAvailable ? " " : "not ") + "add the field to the available fields",
                      formEditorHelper.getAvailableFields().size(),
-                     prevAvailableSize + (addToAvailable && definitionHasFields ? 1 : 0));
+                     prevAvailableSize + (addToAvailable ? 1 : 0));
+    }
 
-        assertFalse("Removed field should " + (definitionHasFields ? "not " : " ") + "be null",
-                    (removedField == null) == definitionHasFields);
+    @Test
+    public void testRemoveUnbindedFieldsAndAddToAvailable() {
+        testRemoveUnboundField(true);
+    }
+
+    @Test
+    public void testRemoveUnbindedFields() {
+       testRemoveUnboundField(false);
+    }
+
+    protected void testRemoveUnboundField(boolean addToAvailables) {
+        content.getDefinition().getFields().addAll(employeeFields);
+        formEditorHelper.getAvailableFields().clear();
+
+        TextBoxFieldDefinition textBoxFieldDefinition = new TextBoxFieldDefinition();
+
+        formDefinition.getFields().add(textBoxFieldDefinition);
+
+        formEditorHelper.removeField(textBoxFieldDefinition.getId(), true);
+
+        Assertions.assertThat(formEditorHelper.getAvailableFields())
+                .isNotNull()
+                .isEmpty();
     }
 
     @Test
     public void testGetCompatibleModelFields() {
         List<String> compatibleModelFields = formEditorHelper.getCompatibleModelFields(nameField);
-        assertEquals(2,
-                     compatibleModelFields.size());
-        Assertions.assertThat(compatibleModelFields).containsExactly(lastNameField.getId(),
-                                                                     nameField.getId());
+
+        Assertions.assertThat(compatibleModelFields)
+                .hasSize(2)
+                .contains(lastNameField.getId(), nameField.getId());
 
         // Getting compatible model propertynames for an integerbox field -> only checks integer properties (age -> integer)
         compatibleModelFields = formEditorHelper.getCompatibleModelFields(ageField);
-        assertEquals(1,
-                     compatibleModelFields.size());
+
         Assertions.assertThat(compatibleModelFields).containsOnly(ageField.getId());
 
         // Getting compatible model propertynames for an decimalbox field -> only checks decimal properties (weight -> double)
         compatibleModelFields = formEditorHelper.getCompatibleModelFields(weightField);
-        assertEquals(1,
-                     compatibleModelFields.size());
-        Assertions.assertThat(compatibleModelFields).containsOnly(weightField.getId());
+
+        Assertions.assertThat(compatibleModelFields)
+                .hasSize(1)
+                .containsOnly(weightField.getId());
 
         IntegerSliderDefinition slider = new IntegerSliderDefinition();
         slider.setId("slider");
         slider.setName("slider");
         slider.setLabel("slider");
+        slider.setBinding("slider");
 
-        // Getting compatible model propertynames for an integer slider field -> slider's are available for integer &
-        // decimal properties (age -> integer & weight -> double)
+        // Getting compatible model propertynames for an integer slider field -> slider's are available for integer properties (age -> integer)
         compatibleModelFields = formEditorHelper.getCompatibleModelFields(slider);
-        assertEquals(2,
-                     compatibleModelFields.size());
-        Assertions.assertThat(compatibleModelFields).containsExactly(ageField.getId(),
-                                                                     weightField.getId());
+
+        Assertions.assertThat(compatibleModelFields)
+                .hasSize(1)
+                .containsOnly(ageField.getId());
     }
 
     @Test
@@ -383,11 +402,17 @@ public class FormEditorHelperTest {
 
         Assertions.assertThat(result)
                 .isNotNull()
-                .isEqualToComparingOnlyGivenFields(expectedField, "name", "binding", "standaloneClassName");
+                .isEqualToComparingOnlyGivenFields(expectedField,
+                                                   "name",
+                                                   "binding",
+                                                   "standaloneClassName");
     }
 
     @Test
     public void testSwitchToFieldType() {
+        content.getDefinition().getFields().addAll(employeeFields);
+        formEditorHelper.getAvailableFields().clear();
+
         FieldDefinition fieldDefinition = formEditorHelper.switchToFieldType(nameField,
                                                                              TextAreaFieldDefinition.FIELD_TYPE.getTypeName());
         assertEquals(TextAreaFieldDefinition.class,
