@@ -18,9 +18,10 @@ package org.kie.workbench.common.forms.editor.client.editor;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.List;
+import java.util.Optional;
 
 import com.google.gwtmockito.GwtMockitoTestRunner;
-import org.guvnor.common.services.project.model.Project;
+import org.guvnor.common.services.project.model.WorkspaceProject;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.kie.workbench.common.forms.dynamic.client.rendering.FieldLayoutComponent;
@@ -215,9 +216,9 @@ public class FormEditorPresenterTest extends FormEditorPresenterAbstractTest {
         assertNotNull("No compatibles fields found!",
                       compatibleFields);
 
-        assertEquals("There should exist 2 compatible fields for " + field.getName() + "!",
-                     compatibleFields.size(),
-                     2);
+        assertEquals("There should exist 1 compatible fields for " + field.getName() + "!",
+                     1,
+                     compatibleFields.size());
 
         String expectedBindingExpression = "lastName";
 
@@ -227,9 +228,6 @@ public class FormEditorPresenterTest extends FormEditorPresenterAbstractTest {
         assertEquals("Wrong binding expression after switch field!",
                      field.getBinding(),
                      expectedBindingExpression);
-
-        presenter.onRemoveComponent(createComponentRemovedEvent(form,
-                                                                field));
     }
 
     protected ComponentRemovedEvent createComponentRemovedEvent(FormDefinition form,
@@ -317,7 +315,7 @@ public class FormEditorPresenterTest extends FormEditorPresenterAbstractTest {
         loadContent();
         addAllFields();
         when(layoutDragComponentPaletteMock.hasDraggableComponent(anyString(),
-                                                         anyString())).thenReturn(true);
+                                                                  anyString())).thenReturn(true);
         List<FieldDefinition> fieldList = presenter.getFormDefinition().getFields();
 
         presenter.removeAllDraggableGroupComponent(fieldList);
@@ -327,7 +325,7 @@ public class FormEditorPresenterTest extends FormEditorPresenterAbstractTest {
 
         verify(layoutDragComponentPaletteMock,
                times(fieldList.size())).removeDraggableComponent(anyString(),
-                                                        anyString());
+                                                                 anyString());
     }
 
     @Test
@@ -338,8 +336,8 @@ public class FormEditorPresenterTest extends FormEditorPresenterAbstractTest {
         presenter.addAllDraggableGroupComponent(fieldList);
         verify(layoutDragComponentPaletteMock,
                times(fieldList.size())).addDraggableComponent(anyString(),
-                                                    anyString(),
-                                                    any());
+                                                              anyString(),
+                                                              any());
     }
 
     @Test
@@ -459,7 +457,7 @@ public class FormEditorPresenterTest extends FormEditorPresenterAbstractTest {
 
     @Test
     public void testMakeMenuBar() {
-        doReturn(mock(Project.class)).when(workbenchContext).getActiveProject();
+        doReturn(Optional.of(mock(WorkspaceProject.class))).when(workbenchContext).getActiveWorkspaceProject();
         doReturn(true).when(projectController).canUpdateProject(any());
 
         loadContent();
@@ -469,6 +467,7 @@ public class FormEditorPresenterTest extends FormEditorPresenterAbstractTest {
                                         any(AssetUpdateValidator.class));
         verify(menuBuilderMock).addRename(any(Command.class));
         verify(menuBuilderMock).addDelete(any(Command.class));
+        verify(menuBuilderMock).addNewTopLevelMenu(alertsButtonMenuItem);
 
         assertNotNull(presenter.getMenus());
         verify(menuBuilderMock,
@@ -477,7 +476,7 @@ public class FormEditorPresenterTest extends FormEditorPresenterAbstractTest {
 
     @Test
     public void testMakeMenuBarWithoutUpdateProjectPermission() {
-        doReturn(mock(Project.class)).when(workbenchContext).getActiveProject();
+        doReturn(Optional.of(mock(WorkspaceProject.class))).when(workbenchContext).getActiveWorkspaceProject();
         doReturn(false).when(projectController).canUpdateProject(any());
 
         loadContent();
@@ -493,6 +492,7 @@ public class FormEditorPresenterTest extends FormEditorPresenterAbstractTest {
         verify(menuBuilderMock,
                never()).addDelete(any(Path.class),
                                   any(AssetUpdateValidator.class));
+        verify(menuBuilderMock).addNewTopLevelMenu(alertsButtonMenuItem);
 
         assertNotNull(presenter.getMenus());
         verify(menuBuilderMock,
