@@ -19,7 +19,7 @@ package org.kie.workbench.common.forms.data.modeller.service.impl;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.Optional;
-import java.util.stream.Collectors;
+
 import javax.enterprise.context.Dependent;
 import javax.inject.Inject;
 
@@ -28,16 +28,16 @@ import org.kie.workbench.common.forms.data.modeller.model.DataObjectFormModel;
 import org.kie.workbench.common.forms.data.modeller.service.DataObjectFinderService;
 import org.kie.workbench.common.forms.editor.backend.service.impl.AbstractFormModelHandler;
 import org.kie.workbench.common.forms.editor.service.backend.FormModelHandler;
-import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.HasPlaceHolder;
-import org.kie.workbench.common.forms.model.FieldDefinition;
+import org.kie.workbench.common.forms.fields.shared.model.meta.entries.FieldPlaceHolderEntry;
 import org.kie.workbench.common.forms.model.ModelProperty;
+import org.kie.workbench.common.forms.model.impl.meta.entries.FieldLabelEntry;
 import org.kie.workbench.common.forms.service.shared.FieldManager;
 import org.kie.workbench.common.screens.datamodeller.model.maindomain.MainDomainAnnotations;
-import org.kie.workbench.common.services.backend.project.ProjectClassLoaderHelper;
+import org.kie.workbench.common.services.backend.project.ModuleClassLoaderHelper;
 import org.kie.workbench.common.services.datamodeller.core.Annotation;
 import org.kie.workbench.common.services.datamodeller.core.DataObject;
 import org.kie.workbench.common.services.datamodeller.core.ObjectProperty;
-import org.kie.workbench.common.services.shared.project.KieProjectService;
+import org.kie.workbench.common.services.shared.project.KieModuleService;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.uberfire.backend.vfs.Path;
@@ -60,17 +60,31 @@ public class DataObjectFormModelHandler extends AbstractFormModelHandler<DataObj
     protected FieldManager fieldManager;
 
     @Inject
-    public DataObjectFormModelHandler(KieProjectService projectService,
-                                      ProjectClassLoaderHelper classLoaderHelper,
+    public DataObjectFormModelHandler(KieModuleService moduleService,
+                                      ModuleClassLoaderHelper classLoaderHelper,
                                       DataObjectFinderService finderService,
                                       FieldManager fieldManager) {
-        super(projectService,
+        super(moduleService,
               classLoaderHelper);
 
         this.finderService = finderService;
         this.fieldManager = fieldManager;
     }
 
+    public static boolean isValidDataObjectProperty(final ObjectProperty property) {
+        if (ArrayUtils.contains(RESTRICTED_PROPERTY_NAMES,
+                                property.getName())) {
+            return false;
+        }
+
+        for (String annotation : RESTRICTED_ANNOTATIONS) {
+            if (property.getAnnotation(annotation) != null) {
+                return false;
+            }
+        }
+        return true;
+    }
+
     @Override
     public Class<DataObjectFormModel> getModelType() {
         return DataObjectFormModel.class;
@@ -121,7 +135,12 @@ public class DataObjectFormModelHandler extends AbstractFormModelHandler<DataObj
                                                                        property.isMultiple());
 
                 if (optional.isPresent()) {
-                    properties.add(optional.get());
+                    ModelProperty modelProperty = optional.get();
+
+                    extractMetaData(property,
+                                    modelProperty);
+
+                    properties.add(modelProperty);
                 }
             }
         });
@@ -130,70 +149,19 @@ public class DataObjectFormModelHandler extends AbstractFormModelHandler<DataObj
 
     @Override
     public FormModelHandler<DataObjectFormModel> newInstance() {
-        return new DataObjectFormModelHandler(projectService,
+        return new DataObjectFormModelHandler(moduleService,
                                               classLoaderHelper,
                                               finderService,
                                               fieldManager);
     }
 
-    @Override
-    protected List<FieldDefinition> doGenerateModelFields() {
-        return formModel.getProperties().stream().map(this::doCreateFieldDefinition).collect(Collectors.toList());
-    }
-
-    @Override
-    protected FieldDefinition doCreateFieldDefinition(ModelProperty property) {
-
-        Optional<ObjectProperty> objectPropertyOptional = Optional.ofNullable(dataObject.getProperty(property.getName()));
-
-        if (!objectPropertyOptional.isPresent()) {
-            return null;
-        }
-
-        ObjectProperty objectProperty = objectPropertyOptional.get();
-
-        if (!isValidDataObjectProperty(objectProperty)) {
-            return null;
-        }
-
-        Optional<FieldDefinition> fieldOptional = Optional.ofNullable(fieldManager.getDefinitionByDataType(property.getTypeInfo()));
-
-        if (!fieldOptional.isPresent()) {
-            return null;
-        }
-
-        FieldDefinition field = fieldOptional.get();
-        field.setName(property.getName());
-        String label = getPropertyLabel(objectProperty);
-        field.setLabel(label);
-        field.setBinding(property.getName());
-
-        if (field instanceof HasPlaceHolder) {
-            ((HasPlaceHolder) field).setPlaceHolder(label);
-        }
-        return field;
-    }
-
-    private String getPropertyLabel(ObjectProperty property) {
+    private void extractMetaData(ObjectProperty property,
+                                 ModelProperty modelProperty) {
         Annotation labelAnnotation = property.getAnnotation(MainDomainAnnotations.LABEL_ANNOTATION);
         if (labelAnnotation != null) {
-            return labelAnnotation.getValue(MainDomainAnnotations.VALUE_PARAM).toString();
+            String label = labelAnnotation.getValue(MainDomainAnnotations.VALUE_PARAM).toString();
+            modelProperty.getMetaData().addEntry(new FieldLabelEntry(label));
+            modelProperty.getMetaData().addEntry(new FieldPlaceHolderEntry(label));
         }
-
-        return property.getName();
-    }
-
-    public static boolean isValidDataObjectProperty(ObjectProperty property) {
-        if (ArrayUtils.contains(RESTRICTED_PROPERTY_NAMES,
-                                property.getName())) {
-            return false;
-        }
-
-        for (String annotation : RESTRICTED_ANNOTATIONS) {
-            if (property.getAnnotation(annotation) != null) {
-                return false;
-            }
-        }
-        return true;
     }
 }
