@@ -17,6 +17,7 @@
 package org.kie.workbench.common.forms.jbpm.server.service.impl;
 
 import java.util.List;
+
 import javax.enterprise.context.Dependent;
 import javax.inject.Inject;
 
@@ -26,8 +27,8 @@ import org.kie.workbench.common.forms.jbpm.model.authoring.process.BusinessProce
 import org.kie.workbench.common.forms.jbpm.service.shared.BPMFinderService;
 import org.kie.workbench.common.forms.model.ModelProperty;
 import org.kie.workbench.common.forms.service.shared.FieldManager;
-import org.kie.workbench.common.services.backend.project.ProjectClassLoaderHelper;
-import org.kie.workbench.common.services.shared.project.KieProjectService;
+import org.kie.workbench.common.services.backend.project.ModuleClassLoaderHelper;
+import org.kie.workbench.common.services.shared.project.KieModuleService;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -37,8 +38,8 @@ public class BusinessProcessFormModelHandler extends AbstractJBPMFormModelHandle
     private static final Logger logger = LoggerFactory.getLogger(BusinessProcessFormModelHandler.class);
 
     @Inject
-    public BusinessProcessFormModelHandler(KieProjectService projectService,
-                                           ProjectClassLoaderHelper classLoaderHelper,
+    public BusinessProcessFormModelHandler(KieModuleService projectService,
+                                           ModuleClassLoaderHelper classLoaderHelper,
                                            FieldManager fieldManager,
                                            BPMFinderService bpmFinderService) {
         super(projectService,
@@ -54,7 +55,7 @@ public class BusinessProcessFormModelHandler extends AbstractJBPMFormModelHandle
 
     @Override
     public FormModelHandler<BusinessProcessFormModel> newInstance() {
-        return new BusinessProcessFormModelHandler(projectService,
+        return new BusinessProcessFormModelHandler(moduleService,
                                                    classLoaderHelper,
                                                    fieldManager,
                                                    bpmFinderService);
