@@ -27,8 +27,8 @@ import org.kie.workbench.common.forms.jbpm.model.authoring.task.TaskFormModel;
 import org.kie.workbench.common.forms.jbpm.service.shared.BPMFinderService;
 import org.kie.workbench.common.forms.model.ModelProperty;
 import org.kie.workbench.common.forms.service.shared.FieldManager;
-import org.kie.workbench.common.services.backend.project.ProjectClassLoaderHelper;
-import org.kie.workbench.common.services.shared.project.KieProjectService;
+import org.kie.workbench.common.services.backend.project.ModuleClassLoaderHelper;
+import org.kie.workbench.common.services.shared.project.KieModuleService;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -38,8 +38,8 @@ public class TaskFormModelHandler extends AbstractJBPMFormModelHandler<TaskFormM
     private static final Logger logger = LoggerFactory.getLogger(BusinessProcessFormModelHandler.class);
 
     @Inject
-    public TaskFormModelHandler(KieProjectService projectService,
-                                ProjectClassLoaderHelper classLoaderHelper,
+    public TaskFormModelHandler(KieModuleService projectService,
+                                ModuleClassLoaderHelper classLoaderHelper,
                                 FieldManager fieldManager,
                                 BPMFinderService bpmFinderService) {
         super(projectService,
@@ -55,7 +55,7 @@ public class TaskFormModelHandler extends AbstractJBPMFormModelHandler<TaskFormM
 
     @Override
     public FormModelHandler<TaskFormModel> newInstance() {
-        return new TaskFormModelHandler(projectService,
+        return new TaskFormModelHandler(moduleService,
                                         classLoaderHelper,
                                         fieldManager,
                                         bpmFinderService);
