@@ -100,7 +100,7 @@ import org.uberfire.workbench.model.menu.Menus;
         supportedTypes = {JavaResourceType.class},
         priority = Integer.MAX_VALUE)
 public class DataModelerScreenPresenter
-        extends KieEditor {
+        extends KieEditor<String> {
 
     public interface DataModelerScreenView
             extends
@@ -1264,7 +1264,8 @@ public class DataModelerScreenPresenter
                 .addValidate(
                         onValidate()
                 )
-                .addNewTopLevelMenu(versionRecordManager.buildMenu());
+                .addNewTopLevelMenu(versionRecordManager.buildMenu())
+                .addNewTopLevelMenu(alertsButtonMenuItemBuilder.build());
     }
 
     private void clearContext() {
