@@ -21,14 +21,16 @@ import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
+import java.util.Optional;
 import java.util.Set;
 
 import com.google.gwtmockito.GwtMock;
 import com.google.gwtmockito.GwtMockitoTestRunner;
+import org.guvnor.common.services.project.client.context.WorkspaceProjectContext;
 import org.guvnor.common.services.project.client.security.ProjectController;
-import org.guvnor.common.services.project.context.ProjectContext;
 import org.guvnor.common.services.shared.message.Level;
 import org.guvnor.common.services.shared.metadata.model.Overview;
+import org.guvnor.messageconsole.client.console.widget.button.AlertsButtonMenuItemBuilder;
 import org.guvnor.messageconsole.events.PublishBatchMessagesEvent;
 import org.guvnor.messageconsole.events.UnpublishMessagesEvent;
 import org.junit.Before;
@@ -37,7 +39,6 @@ import org.kie.api.definition.type.Description;
 import org.kie.api.definition.type.Label;
 import org.kie.workbench.common.screens.datamodeller.client.context.DataModelerWorkbenchContext;
 import org.kie.workbench.common.screens.datamodeller.client.context.DataModelerWorkbenchFocusEvent;
-import org.kie.workbench.common.screens.datamodeller.client.validation.JavaFileNameValidator;
 import org.kie.workbench.common.screens.datamodeller.client.validation.ValidatorService;
 import org.kie.workbench.common.screens.datamodeller.client.widgets.DataModelerEditorsTestHelper;
 import org.kie.workbench.common.screens.datamodeller.events.DataModelerEvent;
@@ -53,11 +54,12 @@ import org.kie.workbench.common.services.datamodeller.core.PropertyType;
 import org.kie.workbench.common.services.datamodeller.core.impl.PropertyTypeFactoryImpl;
 import org.kie.workbench.common.services.datamodeller.util.DriverUtils;
 import org.kie.workbench.common.services.refactoring.client.usages.ShowAssetUsagesDisplayer;
-import org.kie.workbench.common.services.shared.project.KieProject;
+import org.kie.workbench.common.services.shared.project.KieModule;
 import org.kie.workbench.common.services.shared.validation.ValidationService;
 import org.kie.workbench.common.widgets.client.menu.FileMenuBuilderImpl;
 import org.kie.workbench.common.widgets.client.popups.validation.ValidationPopup;
 import org.kie.workbench.common.widgets.metadata.client.KieEditorWrapperView;
+import org.kie.workbench.common.widgets.metadata.client.validation.JavaFileNameValidator;
 import org.kie.workbench.common.widgets.metadata.client.widget.OverviewWidgetPresenter;
 import org.mockito.InjectMocks;
 import org.mockito.Mock;
@@ -75,6 +77,8 @@ import org.uberfire.mocks.EventSourceMock;
 import org.uberfire.mvp.PlaceRequest;
 import org.uberfire.rpc.SessionInfo;
 import org.uberfire.security.authz.AuthorizationManager;
+import org.uberfire.workbench.events.NotificationEvent;
+import org.uberfire.workbench.model.menu.MenuItem;
 
 import static org.mockito.Mockito.*;
 
@@ -105,6 +109,9 @@ public abstract class DataModelerScreenPresenterTestBase {
     @Mock
     protected EventSourceMock<DataModelerWorkbenchFocusEvent> dataModelerFocusEvent;
 
+    @Mock
+    protected EventSourceMock<NotificationEvent> notificationEvent;
+
     @Mock
     protected DataModelerService modelerService;
 
@@ -157,7 +164,7 @@ public abstract class DataModelerScreenPresenterTestBase {
     protected ProjectController projectController;
 
     @Mock
-    protected ProjectContext workbenchContext;
+    protected WorkspaceProjectContext workbenchContext;
 
     @Mock
     protected DeletePopUpPresenter deletePopUpPresenter;
@@ -165,6 +172,12 @@ public abstract class DataModelerScreenPresenterTestBase {
     @Mock
     protected ShowAssetUsagesDisplayer showAssetUsages;
 
+    @Mock
+    protected AlertsButtonMenuItemBuilder alertsButtonMenuItemBuilder;
+
+    @Mock
+    protected MenuItem alertsButtonMenuItem;
+
     protected DataModelerScreenPresenter presenter;
 
     /**
@@ -177,7 +190,7 @@ public abstract class DataModelerScreenPresenterTestBase {
      * Emulates the project returned from server.
      */
     @Mock
-    protected KieProject kieProject;
+    protected KieModule kieModule;
 
     /**
      * Emulates the data object returned from server.
@@ -216,6 +229,7 @@ public abstract class DataModelerScreenPresenterTestBase {
 
     @Before
     public void setUp() throws Exception {
+        when(alertsButtonMenuItemBuilder.build()).thenReturn(alertsButtonMenuItem);
 
         testObject1 = DataModelerEditorsTestHelper.createTestObject1();
         testModel = DataModelerEditorsTestHelper.createTestModel(testObject1);
@@ -242,6 +256,7 @@ public abstract class DataModelerScreenPresenterTestBase {
                 publishBatchMessagesEvent = DataModelerScreenPresenterTestBase.this.publishBatchMessagesEvent;
                 lockRequired = DataModelerScreenPresenterTestBase.this.lockRequired;
                 dataModelerFocusEvent = DataModelerScreenPresenterTestBase.this.dataModelerFocusEvent;
+                notification = DataModelerScreenPresenterTestBase.this.notificationEvent;
                 modelerService = new CallerMock<>(DataModelerScreenPresenterTestBase.this.modelerService);
                 validationPopup = DataModelerScreenPresenterTestBase.this.validationPopup;
                 validationService = new CallerMock<>(DataModelerScreenPresenterTestBase.this.validationService);
@@ -254,7 +269,14 @@ public abstract class DataModelerScreenPresenterTestBase {
                 projectController = DataModelerScreenPresenterTestBase.this.projectController;
                 deletePopUpPresenter = DataModelerScreenPresenterTestBase.this.deletePopUpPresenter;
                 showAssetUsagesDisplayer = DataModelerScreenPresenterTestBase.this.showAssetUsages;
+                alertsButtonMenuItemBuilder = DataModelerScreenPresenterTestBase.this.alertsButtonMenuItemBuilder;
                 uiStarted = true;
+
+                when(workbenchContext.getActiveOrganizationalUnit()).thenReturn(Optional.empty());
+                when(workbenchContext.getActiveWorkspaceProject()).thenReturn(Optional.empty());
+                when(workbenchContext.getActiveModule()).thenReturn(Optional.empty());
+                when(workbenchContext.getActiveRepositoryRoot()).thenReturn(Optional.empty());
+                when(workbenchContext.getActivePackage()).thenReturn(Optional.empty());
             }
 
             @Override
@@ -299,8 +321,8 @@ public abstract class DataModelerScreenPresenterTestBase {
         content.setOriginalClassName(testObject1.getClassName());
         content.setOriginalPackageName(testObject1.getPackageName());
         content.setPath(path);
-        content.setCurrentProject(kieProject);
-        content.setCurrentProjectPackages(testPackages);
+        content.setCurrentModule(kieModule);
+        content.setCurrentModulePackages(testPackages);
         content.setOverview(overview);
 
         if (includeTypesInfo) {
