@@ -39,47 +39,43 @@ import javax.inject.Named;
 
 import org.eclipse.jgit.api.Git;
 import org.eclipse.jgit.api.errors.GitAPIException;
-import org.guvnor.common.services.backend.config.SafeSessionInfo;
-import org.guvnor.common.services.project.context.ProjectContextChangeEvent;
+import org.guvnor.common.services.project.context.WorkspaceProjectContextChangeEvent;
 import org.guvnor.common.services.project.events.NewProjectEvent;
+import org.guvnor.common.services.project.model.Module;
 import org.guvnor.common.services.project.model.POM;
-import org.guvnor.common.services.project.model.Project;
+import org.guvnor.common.services.project.model.WorkspaceProject;
+import org.guvnor.common.services.project.service.WorkspaceProjectService;
 import org.guvnor.common.services.shared.metadata.MetadataService;
 import org.guvnor.structure.organizationalunit.OrganizationalUnit;
 import org.guvnor.structure.organizationalunit.OrganizationalUnitService;
+import org.guvnor.structure.repositories.EnvironmentParameters;
 import org.guvnor.structure.repositories.Repository;
-import org.guvnor.structure.repositories.RepositoryEnvironmentConfigurations;
+import org.guvnor.structure.repositories.RepositoryCopier;
 import org.guvnor.structure.repositories.RepositoryService;
 import org.guvnor.structure.repositories.impl.git.GitRepository;
 import org.guvnor.structure.server.config.ConfigGroup;
 import org.guvnor.structure.server.config.ConfigurationFactory;
 import org.guvnor.structure.server.repositories.RepositoryFactory;
 import org.jboss.errai.bus.server.annotations.Service;
+import org.kie.soup.commons.validation.PortablePreconditions;
 import org.kie.workbench.common.screens.examples.model.ExampleOrganizationalUnit;
 import org.kie.workbench.common.screens.examples.model.ExampleProject;
 import org.kie.workbench.common.screens.examples.model.ExampleRepository;
-import org.kie.workbench.common.screens.examples.model.ExampleTargetRepository;
 import org.kie.workbench.common.screens.examples.model.ExamplesMetaData;
 import org.kie.workbench.common.screens.examples.service.ExamplesService;
-import org.kie.workbench.common.services.shared.project.KieProject;
-import org.kie.workbench.common.services.shared.project.KieProjectService;
+import org.kie.workbench.common.screens.projecteditor.model.ProjectScreenModel;
+import org.kie.workbench.common.screens.projecteditor.service.ProjectScreenService;
+import org.kie.workbench.common.services.shared.project.KieModuleService;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.uberfire.backend.server.util.Paths;
 import org.uberfire.backend.vfs.Path;
-import org.uberfire.commons.validation.PortablePreconditions;
 import org.uberfire.io.IOService;
 import org.uberfire.java.nio.IOException;
-import org.uberfire.java.nio.file.FileAlreadyExistsException;
-import org.uberfire.java.nio.file.FileVisitResult;
-import org.uberfire.java.nio.file.FileVisitor;
-import org.uberfire.java.nio.file.Files;
-import org.uberfire.java.nio.file.StandardCopyOption;
-import org.uberfire.java.nio.file.attribute.BasicFileAttributes;
-import org.uberfire.java.nio.fs.jgit.util.JGitUtil;
-import org.uberfire.rpc.SessionInfo;
+import org.uberfire.spaces.SpacesAPI;
 
 import static org.guvnor.structure.repositories.EnvironmentParameters.SCHEME;
+import static org.guvnor.structure.repositories.EnvironmentParameters.MIRROR;
 import static org.guvnor.structure.server.config.ConfigType.REPOSITORY;
 
 @Service
@@ -91,17 +87,20 @@ public class ExamplesServiceImpl implements ExamplesService {
     private static final String PROJECT_DESCRIPTON = "project.description";
 
     private static final String KIE_WB_PLAYGROUND_ZIP = "org/kie/kie-wb-playground/kie-wb-playground.zip";
-    private final Set<Repository> clonedRepositories = new HashSet<Repository>();
+    private final Set<Repository> clonedRepositories = new HashSet<>();
+    private WorkspaceProjectService projectService;
     private IOService ioService;
     private ConfigurationFactory configurationFactory;
     private RepositoryFactory repositoryFactory;
-    private KieProjectService projectService;
+    private KieModuleService moduleService;
     private RepositoryService repositoryService;
+    private RepositoryCopier repositoryCopier;
     private OrganizationalUnitService ouService;
     private Event<NewProjectEvent> newProjectEvent;
-    private SafeSessionInfo sessionInfo;
     private MetadataService metadataService;
+    private SpacesAPI spaces;
     private ExampleRepository playgroundRepository;
+    private ProjectScreenService projectScreenService;
 
     public ExamplesServiceImpl() {
         //Zero-parameter Constructor for CDI proxies
@@ -111,21 +110,27 @@ public class ExamplesServiceImpl implements ExamplesService {
     public ExamplesServiceImpl(final @Named("ioStrategy") IOService ioService,
                                final ConfigurationFactory configurationFactory,
                                final RepositoryFactory repositoryFactory,
-                               final KieProjectService projectService,
+                               final KieModuleService moduleService,
                                final RepositoryService repositoryService,
+                               final RepositoryCopier repositoryCopier,
                                final OrganizationalUnitService ouService,
+                               final WorkspaceProjectService projectService,
                                final MetadataService metadataService,
+                               final SpacesAPI spaces,
                                final Event<NewProjectEvent> newProjectEvent,
-                               final SessionInfo sessionInfo) {
+                               final ProjectScreenService projectScreenService) {
         this.ioService = ioService;
         this.configurationFactory = configurationFactory;
         this.repositoryFactory = repositoryFactory;
-        this.projectService = projectService;
+        this.moduleService = moduleService;
         this.repositoryService = repositoryService;
+        this.repositoryCopier = repositoryCopier;
         this.ouService = ouService;
+        this.projectService = projectService;
         this.metadataService = metadataService;
+        this.spaces = spaces;
         this.newProjectEvent = newProjectEvent;
-        this.sessionInfo = new SafeSessionInfo(sessionInfo);
+        this.projectScreenService = projectScreenService;
     }
 
     @PostConstruct
@@ -166,8 +171,7 @@ public class ExamplesServiceImpl implements ExamplesService {
                     }
                 }
 
-                Git git = JGitUtil.newRepository(playgroundDirectory,
-                                                 false);
+                final Git git = Git.init().setBare(false).setDirectory(playgroundDirectory).call();
                 git.add().addFilepattern(".").call();
                 git.commit().setMessage("Initial commit").call();
 
@@ -210,8 +214,7 @@ public class ExamplesServiceImpl implements ExamplesService {
 
     @Override
     public ExamplesMetaData getMetaData() {
-        return new ExamplesMetaData(getPlaygroundRepository(),
-                                    getExampleOrganizationalUnits());
+        return new ExamplesMetaData(getPlaygroundRepository());
     }
 
     @Override
@@ -219,15 +222,6 @@ public class ExamplesServiceImpl implements ExamplesService {
         return playgroundRepository;
     }
 
-    Set<ExampleOrganizationalUnit> getExampleOrganizationalUnits() {
-        final Collection<OrganizationalUnit> organizationalUnits = ouService.getOrganizationalUnits();
-        final Set<ExampleOrganizationalUnit> exampleOrganizationalUnits = new HashSet<ExampleOrganizationalUnit>();
-        for (OrganizationalUnit ou : organizationalUnits) {
-            exampleOrganizationalUnits.add(new ExampleOrganizationalUnit(ou.getName()));
-        }
-        return exampleOrganizationalUnits;
-    }
-
     @Override
     public Set<ExampleProject> getProjects(final ExampleRepository repository) {
         if (repository == null) {
@@ -245,20 +239,29 @@ public class ExamplesServiceImpl implements ExamplesService {
             return Collections.emptySet();
         }
 
-        final Set<Project> projects = projectService.getProjects(gitRepository,
-                                                                 "master");
-        return convert(projects);
+        final Set<Module> modules = moduleService.getAllModules(gitRepository.getBranch("master").get());
+        return convert(modules);
     }
 
     Repository resolveGitRepository(final ExampleRepository exampleRepository) {
         if (exampleRepository.equals(playgroundRepository)) {
             return clonedRepositories.stream().filter(r -> exampleRepository.getUrl().equals(r.getEnvironment().get("origin"))).findFirst().orElseGet(() -> cloneRepository(exampleRepository.getUrl()));
         } else {
-            return cloneRepository(exampleRepository.getUrl());
+            return cloneRepository(exampleRepository.getUrl(),
+                                   exampleRepository.getUserName(),
+                                   exampleRepository.getPassword());
         }
     }
 
     private Repository cloneRepository(final String repositoryURL) {
+        return cloneRepository(repositoryURL,
+                               null,
+                               null);
+    }
+
+    private Repository cloneRepository(final String repositoryURL,
+                                       final String userName,
+                                       final String password) {
         Repository repository = null;
         try {
             final String alias = getExampleAlias(repositoryURL);
@@ -266,12 +269,19 @@ public class ExamplesServiceImpl implements ExamplesService {
                 put("origin",
                     repositoryURL);
                 put(SCHEME,
-                    "git");
+                    GitRepository.SCHEME.toString());
                 put("replaceIfExists",
                     true);
+                put("username",
+                    userName);
+                put("password",
+                    password);
+                put(MIRROR,
+                    false);
             }};
 
             final ConfigGroup repositoryConfig = configurationFactory.newConfigGroup(REPOSITORY,
+                                                                                     "system",
                                                                                      alias,
                                                                                      "");
             for (final Map.Entry<String, Object> entry : env.entrySet()) {
@@ -279,6 +289,12 @@ public class ExamplesServiceImpl implements ExamplesService {
                                                                                   entry.getValue()));
             }
 
+            repositoryConfig.addConfigItem(configurationFactory.newConfigItem(EnvironmentParameters.AVOID_INDEX,
+                                                                              "true"));
+
+            repositoryConfig.addConfigItem(configurationFactory.newConfigItem(EnvironmentParameters.SPACE,
+                                                                              "system"));
+
             repository = repositoryFactory.newRepository(repositoryConfig);
             clonedRepositories.add(repository);
             return repository;
@@ -304,21 +320,28 @@ public class ExamplesServiceImpl implements ExamplesService {
         return FileSystems.getDefault().getSeparator();
     }
 
-    private Set<ExampleProject> convert(final Set<Project> projects) {
-        return projects.stream()
-                .map(p -> new ExampleProject(p.getRootPath(),
-                                             p.getProjectName(),
-                                             readDescription(p),
-                                             getTags(p)))
+    private Set<ExampleProject> convert(final Set<Module> modules) {
+        return modules.stream()
+                .map(p -> makeExampleProject(p))
                 .collect(Collectors.toSet());
     }
 
-    private String readDescription(final Project project) {
-        final Path root = project.getRootPath();
-        final POM pom = project.getPom();
+    private ExampleProject makeExampleProject(final Module module) {
+        final String description = readDescription(module);
+        final List<String> tags = getTags(module);
+
+        return new ExampleProject(module.getRootPath(),
+                                  module.getModuleName(),
+                                  description,
+                                  tags);
+    }
+
+    private String readDescription(final Module module) {
+        final Path root = module.getRootPath();
+        final POM pom = module.getPom();
         final org.uberfire.java.nio.file.Path nioRoot = Paths.convert(root);
         final org.uberfire.java.nio.file.Path nioDescription = nioRoot.resolve(PROJECT_DESCRIPTON);
-        String description = "Example '" + project.getProjectName() + "' project";
+        String description = "Example '" + module.getModuleName() + "' module";
 
         if (ioService.exists(nioDescription)) {
             description = ioService.readAllString(nioDescription);
@@ -336,28 +359,17 @@ public class ExamplesServiceImpl implements ExamplesService {
         return description;
     }
 
-    private List<String> getTags(final Project project) {
-        List<String> tags = metadataService.getTags(project.getPomXMLPath());
-        tags.sort((t1, t2) -> t1.compareTo(t2));
+    private List<String> getTags(final Module module) {
+        List<String> tags = metadataService.getTags(module.getPomXMLPath());
+        tags.sort(String::compareTo);
         return tags;
     }
 
     @Override
-    public boolean validateRepositoryName(final String name) {
-        return repositoryService.validateRepositoryName(name);
-    }
-
-    @Override
-    public ProjectContextChangeEvent setupExamples(final ExampleOrganizationalUnit exampleTargetOU,
-                                                   final ExampleTargetRepository exampleTarget,
-                                                   final String branch,
-                                                   final List<ExampleProject> exampleProjects) {
+    public WorkspaceProjectContextChangeEvent setupExamples(final ExampleOrganizationalUnit exampleTargetOU,
+                                                            final List<ExampleProject> exampleProjects) {
         PortablePreconditions.checkNotNull("exampleTargetOU",
                                            exampleTargetOU);
-        PortablePreconditions.checkNotNull("exampleTarget",
-                                           exampleTarget);
-        PortablePreconditions.checkNotNull("branch",
-                                           branch);
         PortablePreconditions.checkNotNull("exampleProjects",
                                            exampleProjects);
         PortablePreconditions.checkCondition("Must have at least one ExampleProject",
@@ -365,58 +377,68 @@ public class ExamplesServiceImpl implements ExamplesService {
 
         //Retrieve or create Organizational Unit
         final String targetOUName = exampleTargetOU.getName();
-        OrganizationalUnit targetOU = ouService.getOrganizationalUnit(targetOUName);
-        if (targetOU == null) {
-            targetOU = createOrganizationalUnit(targetOUName);
-        }
+        final OrganizationalUnit targetOU = getOrganizationalUnit(targetOUName);
 
-        //Retrieve or create target Repository
-        final String targetRepositoryAlias = exampleTarget.getAlias();
-        Repository targetRepository = repositoryService.getRepository(targetRepositoryAlias);
-        if (targetRepository == null) {
-            targetRepository = createTargetRepository(targetOU,
-                                                      targetRepositoryAlias);
-        }
+        WorkspaceProject firstExampleProject = null;
 
-        final Path targetRepositoryRoot = targetRepository.getBranchRoot(branch);
-        final org.uberfire.java.nio.file.Path nioTargetRepositoryRoot = Paths.convert(targetRepositoryRoot);
-        KieProject firstExampleProject = null;
-
-        try {
-            ioService.startBatch(nioTargetRepositoryRoot.getFileSystem());
-            for (ExampleProject exampleProject : exampleProjects) {
-                final Path exampleProjectRoot = exampleProject.getRoot();
-                final org.uberfire.java.nio.file.Path nioExampleProjectRoot = Paths.convert(exampleProjectRoot);
-                final org.uberfire.java.nio.file.Path nioTargetProjectRoot = nioTargetRepositoryRoot.resolve(exampleProject.getName());
-
-                final RecursiveCopier copier = new RecursiveCopier(nioExampleProjectRoot,
-                                                                   nioTargetProjectRoot);
-                Files.walkFileTree(nioExampleProjectRoot,
-                                   copier);
+        for (final ExampleProject exampleProject : exampleProjects) {
+            try {
+                final Repository targetRepository = repositoryCopier.copy(targetOU,
+                                                                          exampleProject.getName(),
+                                                                          exampleProject.getRoot());
 
                 // Signal creation of new Project (Creation of OU and Repository, if applicable,
                 // are already handled in the corresponding services).
-                final Path targetProjectRoot = Paths.convert(nioTargetProjectRoot);
-                final KieProject project = projectService.resolveProject(targetProjectRoot);
-                newProjectEvent.fire(new NewProjectEvent(project,
-                                                         sessionInfo.getId(),
-                                                         sessionInfo.getIdentity().getIdentifier()));
+                WorkspaceProject project = projectService.resolveProject(targetRepository);
+                project = renameIfNecessary(targetOU,
+                                            project);
+                newProjectEvent.fire(new NewProjectEvent(project));
 
                 //Store first new example project
                 if (firstExampleProject == null) {
                     firstExampleProject = project;
                 }
+            } catch (IOException ioe) {
+                logger.error("Unable to create Example(s).",
+                             ioe);
             }
-        } catch (IOException ioe) {
-            logger.error("Unable to create Example(s).",
-                         ioe);
-        } finally {
-            ioService.endBatch();
         }
-        return new ProjectContextChangeEvent(targetOU,
-                                             targetRepository,
-                                             targetRepository.getDefaultBranch(),
-                                             firstExampleProject);
+
+        return new WorkspaceProjectContextChangeEvent(firstExampleProject,
+                                                      firstExampleProject.getMainModule());
+    }
+
+    private WorkspaceProject renameIfNecessary(final OrganizationalUnit ou,
+                                               final WorkspaceProject project) {
+
+        String name = project.getName();
+        Collection<WorkspaceProject> projectsWithSameName = projectService.getAllWorkspaceProjectsByName(ou,
+                                                                                                         name);
+
+        if (projectsWithSameName.size() > 1) {
+            name = this.projectService.createFreshProjectName(ou,
+                                                              project.getName());
+        }
+
+        if (!name.equals(project.getName())) {
+            final Path pomXMLPath = project.getMainModule().getPomXMLPath();
+            final ProjectScreenModel model = projectScreenService.load(pomXMLPath);
+            model.getPOM().setName(name);
+            projectScreenService.save(pomXMLPath,
+                                      model,
+                                      "");
+            return projectService.resolveProject(pomXMLPath);
+        }
+
+        return project;
+    }
+
+    private OrganizationalUnit getOrganizationalUnit(String targetOUName) {
+        OrganizationalUnit targetOU = ouService.getOrganizationalUnit(targetOUName);
+        if (targetOU == null) {
+            targetOU = createOrganizationalUnit(targetOUName);
+        }
+        return targetOU;
     }
 
     private OrganizationalUnit createOrganizationalUnit(final String name) {
@@ -426,17 +448,6 @@ public class ExamplesServiceImpl implements ExamplesService {
         return ou;
     }
 
-    private Repository createTargetRepository(final OrganizationalUnit ou,
-                                              final String alias) {
-        final RepositoryEnvironmentConfigurations configuration = new RepositoryEnvironmentConfigurations();
-        configuration.setManaged(false);
-        final Repository repository = repositoryService.createRepository(ou,
-                                                                         GitRepository.SCHEME,
-                                                                         alias,
-                                                                         configuration);
-        return repository;
-    }
-
     @Override
     public int priority() {
         return 0;
@@ -444,9 +455,11 @@ public class ExamplesServiceImpl implements ExamplesService {
 
     @Override
     public void dispose() {
-        for (Repository repository : clonedRepositories) {
+        for (final Repository repository : clonedRepositories) {
             try {
-                ioService.delete(Paths.convert(repository.getRoot()).getFileSystem().getPath(null));
+                if (repository.getDefaultBranch().isPresent()) {
+                    ioService.delete(Paths.convert(repository.getDefaultBranch().get().getPath()).getFileSystem().getPath(null));
+                }
             } catch (Exception e) {
                 logger.warn("Unable to remove transient Repository '" + repository.getAlias() + "'.",
                             e);
@@ -454,50 +467,6 @@ public class ExamplesServiceImpl implements ExamplesService {
         }
     }
 
-    static class RecursiveCopier implements FileVisitor<org.uberfire.java.nio.file.Path> {
-
-        private final org.uberfire.java.nio.file.Path source;
-        private final org.uberfire.java.nio.file.Path target;
-
-        RecursiveCopier(final org.uberfire.java.nio.file.Path source,
-                        final org.uberfire.java.nio.file.Path target) {
-            this.source = source;
-            this.target = target;
-        }
-
-        @Override
-        public FileVisitResult preVisitDirectory(final org.uberfire.java.nio.file.Path src,
-                                                 final BasicFileAttributes attrs) {
-            final org.uberfire.java.nio.file.Path tgt = target.resolve(source.relativize(src));
-            try {
-                Files.copy(src,
-                           tgt,
-                           StandardCopyOption.REPLACE_EXISTING);
-            } catch (FileAlreadyExistsException x) {
-                //Swallow
-            }
-            return FileVisitResult.CONTINUE;
-        }
-
-        @Override
-        public FileVisitResult visitFile(final org.uberfire.java.nio.file.Path file,
-                                         final BasicFileAttributes attrs) {
-            return FileVisitResult.CONTINUE;
-        }
-
-        @Override
-        public FileVisitResult postVisitDirectory(final org.uberfire.java.nio.file.Path dir,
-                                                  final IOException exc) {
-            return FileVisitResult.CONTINUE;
-        }
-
-        @Override
-        public FileVisitResult visitFileFailed(final org.uberfire.java.nio.file.Path file,
-                                               final IOException exc) {
-            return FileVisitResult.CONTINUE;
-        }
-    }
-
     // Test getters and setters
     Set<Repository> getClonedRepositories() {
         return clonedRepositories;
