@@ -21,13 +21,12 @@ import java.util.Set;
 
 import org.ext.uberfire.social.activities.model.SocialUser;
 import org.guvnor.common.services.project.model.GAV;
-import org.guvnor.common.services.project.model.Project;
+import org.guvnor.common.services.project.model.POM;
+import org.guvnor.common.services.project.model.WorkspaceProject;
 import org.guvnor.common.services.project.service.DeploymentMode;
 import org.guvnor.structure.organizationalunit.OrganizationalUnit;
-import org.guvnor.structure.repositories.Repository;
 import org.jboss.errai.bus.server.annotations.Remote;
 import org.kie.workbench.common.screens.examples.model.ExampleProject;
-import org.kie.workbench.common.services.shared.project.KieProject;
 
 @Remote
 public interface LibraryService {
@@ -39,48 +38,51 @@ public interface LibraryService {
 
     OrganizationalUnitRepositoryInfo getOrganizationalUnitRepositoryInfo(final OrganizationalUnit selectedOrganizationalUnit);
 
-    LibraryInfo getLibraryInfo(final Repository selectedRepository,
-                               final String branch);
+    LibraryInfo getLibraryInfo(final OrganizationalUnit organizationalUnit);
 
-    KieProject createProject(final String projectName,
-                             final OrganizationalUnit selectedOrganizationalUnit,
-                             final Repository selectedRepository,
-                             final String baseURL,
-                             final String projectDescription,
-                             final DeploymentMode mode);
+    WorkspaceProject createProject(final String projectName,
+                                   final OrganizationalUnit selectedOrganizationalUnit,
+                                   final String description,
+                                   final DeploymentMode deploymentMode);
 
-    KieProject createProject(final String name,
-                             final String description,
-                             final String groupId,
-                             final String artifactId,
-                             final String version,
-                             final OrganizationalUnit selectedOrganizationalUnit,
-                             final Repository selectedRepository,
-                             final String baseURL,
-                             final DeploymentMode mode);
+    WorkspaceProject createProject(final OrganizationalUnit activeOrganizationalUnit,
+                                   final POM pom,
+                                   final DeploymentMode mode);
 
     Boolean thereIsAProjectInTheWorkbench();
 
-    List<AssetInfo> getProjectAssets(final ProjectAssetsQuery query);
+    AssetQueryResult getProjectAssets(final ProjectAssetsQuery query);
 
-    Boolean hasProjects(final Repository repository,
-                        final String branch);
+    Boolean hasProjects(final OrganizationalUnit organizationalUnit);
 
-    Boolean hasAssets(final Project project);
+    int getNumberOfAssets(final ProjectAssetsQuery query);
+
+    int getNumberOfAssets(final WorkspaceProject project);
+
+    Boolean hasAssets(final WorkspaceProject project);
+
+    /**
+     * Imports a project from a repository with full history (i.e. `git clone ${repositoryURL}`).
+     */
+    WorkspaceProject importProject(OrganizationalUnit targetOU, String repositoryURL, String username, String password);
+
+    /**
+     * Imports a project by copying the files (without history) from the given {@link ExampleProject}.
+     */
+    WorkspaceProject importProject(OrganizationalUnit targetOU, ExampleProject example);
 
     Set<ExampleProject> getExampleProjects();
 
     Set<ExampleProject> getProjects(final String repositoryUrl);
 
-    Project importProject(final OrganizationalUnit organizationalUnit,
-                          final Repository repository,
-                          final String branch,
-                          final ExampleProject exampleProject);
-
-    Project importProject(final ExampleProject exampleProject);
+    Set<ExampleProject> getProjects(final String repositoryUrl,
+                                    final String userName,
+                                    final String password);
 
     List<OrganizationalUnit> getOrganizationalUnits();
 
+    OrganizationalUnit getDefaultOrganizationalUnit();
+
     GAV createGAV(final String projectName,
                   final OrganizationalUnit selectedOrganizationalUnit);
 
