@@ -22,8 +22,9 @@ import javax.inject.Inject;
 import org.apache.lucene.search.Query;
 import org.apache.lucene.search.Sort;
 import org.apache.lucene.search.SortField;
+import org.kie.workbench.common.screens.library.api.index.LibraryFileExtensionIndexTerm;
 import org.kie.workbench.common.screens.library.api.index.LibraryValueFileNameIndexTerm;
-import org.kie.workbench.common.screens.library.api.index.LibraryValueProjectRootPathIndexTerm;
+import org.kie.workbench.common.screens.library.api.index.LibraryValueModuleRootPathIndexTerm;
 import org.kie.workbench.common.services.refactoring.backend.server.query.NamedQuery;
 import org.kie.workbench.common.services.refactoring.backend.server.query.response.FileDetailsResponseBuilder;
 import org.kie.workbench.common.services.refactoring.backend.server.query.response.ResponseBuilder;
@@ -76,14 +77,16 @@ public class FindAllLibraryAssetsQuery
         checkInvalidAndRequiredTerms(queryTerms,
                                      NAME,
                                      new String[]{
-                                             LibraryValueProjectRootPathIndexTerm.TERM,
-                                             null // not required
+                                             LibraryValueModuleRootPathIndexTerm.TERM,
+                                             null, // not required
+                                             null// not required
                                      },
-                                     (t) -> (t instanceof LibraryValueProjectRootPathIndexTerm),
-                                     (t) -> (t instanceof LibraryValueFileNameIndexTerm)
+                                     (t) -> (t instanceof LibraryValueModuleRootPathIndexTerm),
+                                     (t) -> (t instanceof LibraryValueFileNameIndexTerm),
+                                     (t) -> (t instanceof LibraryFileExtensionIndexTerm)
         );
 
-        checkTermsSize(2,
+        checkTermsSize(3,
                        queryTerms);
     }
 }
