@@ -21,10 +21,13 @@ import java.util.Collections;
 import java.util.List;
 import javax.enterprise.event.Event;
 
-import org.guvnor.common.services.project.context.ProjectContextChangeEvent;
+import org.guvnor.common.services.project.client.context.WorkspaceProjectContext;
+import org.guvnor.common.services.project.context.WorkspaceProjectContextChangeEvent;
 import org.guvnor.structure.client.security.OrganizationalUnitController;
 import org.guvnor.structure.events.AfterCreateOrganizationalUnitEvent;
+import org.guvnor.structure.organizationalunit.NewOrganizationalUnitEvent;
 import org.guvnor.structure.organizationalunit.OrganizationalUnit;
+import org.guvnor.structure.organizationalunit.RemoveOrganizationalUnitEvent;
 import org.guvnor.structure.organizationalunit.impl.OrganizationalUnitImpl;
 import org.jboss.errai.common.client.api.Caller;
 import org.jboss.errai.ioc.client.api.ManagedInstance;
@@ -33,6 +36,7 @@ import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.kie.workbench.common.screens.library.api.LibraryService;
+import org.kie.workbench.common.screens.library.api.cluster.ClusterLibraryEvent;
 import org.kie.workbench.common.screens.library.api.preferences.LibraryInternalPreferences;
 import org.kie.workbench.common.screens.library.client.screens.organizationalunit.popup.OrganizationalUnitPopUpPresenter;
 import org.kie.workbench.common.screens.library.client.util.LibraryPlaces;
@@ -41,8 +45,10 @@ import org.kie.workbench.common.screens.library.client.widgets.common.TileWidget
 import org.mockito.Mock;
 import org.mockito.runners.MockitoJUnitRunner;
 import org.uberfire.mocks.CallerMock;
+import org.uberfire.mocks.EventSourceMock;
 
 import static org.junit.Assert.*;
+import static org.kie.workbench.common.screens.contributors.model.ContributorsDataSetColumns.COLUMN_DATE;
 import static org.mockito.Matchers.any;
 import static org.mockito.Mockito.*;
 
@@ -69,7 +75,7 @@ public class OrganizationalUnitsScreenTest {
     private ManagedInstance<TileWidget> organizationalUnitTileWidgets;
 
     @Mock
-    private Event<ProjectContextChangeEvent> projectContextChangeEvent;
+    private Event<WorkspaceProjectContextChangeEvent> projectContextChangeEvent;
 
     @Mock
     private LibraryInternalPreferences libraryInternalPreferences;
@@ -121,6 +127,7 @@ public class OrganizationalUnitsScreenTest {
                                                       organizationalUnitController,
                                                       organizationalUnitTileWidgets,
                                                       projectContextChangeEvent,
+                                                      mock(WorkspaceProjectContext.class),
                                                       libraryInternalPreferences,
                                                       emptyOrganizationalUnitsScreen));
 
@@ -192,21 +199,16 @@ public class OrganizationalUnitsScreenTest {
     }
 
     @Test
-    public void organizationalUnitCreatedTest() {
-        final OrganizationalUnit newOrganizationalUnit = new OrganizationalUnitImpl("newOu",
-                                                                                    "newOwner",
-                                                                                    "newDefaultGroupId");
-        List<OrganizationalUnit> organizationalUnits = new ArrayList<>();
-        organizationalUnits.add(organizationalUnit1);
-        organizationalUnits.add(organizationalUnit2);
-        organizationalUnits.add(organizationalUnit3);
-        organizationalUnits.add(newOrganizationalUnit);
+    public void ouEventsShouldReloadOUs() {
 
-        presenter.init();
-        presenter.organizationalUnitCreated(new AfterCreateOrganizationalUnitEvent(newOrganizationalUnit));
+        presenter.onNewOrganizationalUnitEvent(new NewOrganizationalUnitEvent());
 
-        assertEquals(organizationalUnits,
-                     presenter.organizationalUnits);
+        presenter.onClusterLibraryEvent(new ClusterLibraryEvent());
+
+        presenter.onRemoveOrganizationalUnitEvent(new RemoveOrganizationalUnitEvent());
+
+        verify(presenter, times(3)).setupOrganizationalUnits();
+        verify(libraryService, times(3)).getOrganizationalUnits();
     }
 
     @Test
