@@ -20,7 +20,6 @@ import javax.enterprise.context.ApplicationScoped;
 import javax.enterprise.inject.Instance;
 import javax.inject.Inject;
 
-import org.guvnor.common.services.project.client.security.ProjectTreeProvider;
 import org.guvnor.structure.client.security.OrganizationalUnitTreeProvider;
 import org.guvnor.structure.client.security.RepositoryTreeProvider;
 import org.kie.workbench.common.workbench.client.resources.i18n.DefaultWorkbenchConstants;
@@ -31,29 +30,7 @@ import static org.kie.workbench.common.workbench.client.EditorIds.GUIDED_DECISIO
 import static org.kie.workbench.common.workbench.client.EditorIds.GUIDED_SCORE_CARD;
 import static org.kie.workbench.common.workbench.client.EditorIds.STUNNER_DESIGNER;
 import static org.kie.workbench.common.workbench.client.EditorIds.XLS_SCORE_CARD;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.ADMIN;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.ADMINISTRATION;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.APPS;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.AUTHORING;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.CONTENT_MANAGEMENT;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.DATASET_AUTHORING;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.DATASOURCE_MANAGEMENT;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.DEPLOYMENTS;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.EXECUTION_ERRORS;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.GUVNOR_M2REPO;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.HOME;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.JOBS;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.LIBRARY;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.PLUGIN_AUTHORING;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.PROCESS_DASHBOARD;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.PROCESS_DEFINITIONS;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.PROCESS_INSTANCES;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.SECURITY_MANAGEMENT;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.SERVER_MANAGEMENT;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.SOCIAL_HOME;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.SOCIAL_USER_HOME;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.TASKS;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.TASKS_ADMIN;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.*;
 
 /**
  * This is an example of how to customize some of the permission tree nodes.
@@ -66,7 +43,6 @@ public class PermissionTreeSetup {
     private EditorTreeProvider editorTreeProvider;
     private Instance<OrganizationalUnitTreeProvider> orgUnitTreeProvider;
     private Instance<RepositoryTreeProvider> repositoryTreeProvider;
-    private Instance<ProjectTreeProvider> projectTreeProvider;
 
     private DefaultWorkbenchConstants i18n = DefaultWorkbenchConstants.INSTANCE;
 
@@ -79,14 +55,12 @@ public class PermissionTreeSetup {
                                final PerspectiveTreeProvider perspectiveTreeProvider,
                                final EditorTreeProvider editorTreeProvider,
                                final Instance<OrganizationalUnitTreeProvider> orgUnitTreeProvider,
-                               final Instance<RepositoryTreeProvider> repositoryTreeProvider,
-                               final Instance<ProjectTreeProvider> projectTreeProvider) {
+                               final Instance<RepositoryTreeProvider> repositoryTreeProvider) {
         this.workbenchTreeProvider = workbenchTreeProvider;
         this.perspectiveTreeProvider = perspectiveTreeProvider;
         this.editorTreeProvider = editorTreeProvider;
         this.orgUnitTreeProvider = orgUnitTreeProvider;
         this.repositoryTreeProvider = repositoryTreeProvider;
-        this.projectTreeProvider = projectTreeProvider;
     }
 
     public void configureTree() {
@@ -115,15 +89,17 @@ public class PermissionTreeSetup {
         perspectiveTreeProvider.setPerspectiveName(PROCESS_INSTANCES,
                                                    i18n.ProcessInstances());
         perspectiveTreeProvider.setPerspectiveName(TASKS_ADMIN,
-                                                   i18n.Tasks_Admin());
+                                                   i18n.Tasks());
         perspectiveTreeProvider.setPerspectiveName(JOBS,
                                                    i18n.Jobs());
         perspectiveTreeProvider.setPerspectiveName(EXECUTION_ERRORS,
                                                    i18n.ExecutionErrors());
         perspectiveTreeProvider.setPerspectiveName(TASKS,
-                                                   i18n.Tasks());
+                                                   i18n.Task_Inbox());
         perspectiveTreeProvider.setPerspectiveName(PROCESS_DASHBOARD,
-                                                   i18n.Process_Dashboard());
+                                                   i18n.Process_Reports());
+        perspectiveTreeProvider.setPerspectiveName(TASK_DASHBOARD,
+                                                   i18n.Task_Reports());
         perspectiveTreeProvider.setPerspectiveName(APPS,
                                                    i18n.Apps());
 
@@ -142,7 +118,6 @@ public class PermissionTreeSetup {
         perspectiveTreeProvider.excludePerspectiveId(APPS); /* uberfire */
         perspectiveTreeProvider.excludePerspectiveId(SOCIAL_HOME); /* uberfire */
         perspectiveTreeProvider.excludePerspectiveId(SOCIAL_USER_HOME); /* uberfire */
-        perspectiveTreeProvider.excludePerspectiveId("Asset Management"); /* guvnor */
 
         // Include optional editors
         editorTreeProvider.registerEditor(GUIDED_DECISION_TREE,
@@ -164,8 +139,5 @@ public class PermissionTreeSetup {
         if (!repositoryTreeProvider.isUnsatisfied()) {
             repositoryTreeProvider.get().setRootNodePosition(4);
         }
-        if (!projectTreeProvider.isUnsatisfied()) {
-            projectTreeProvider.get().setRootNodePosition(5);
-        }
     }
 }
\ No newline at end of file
