@@ -67,9 +67,11 @@ public interface DefaultWorkbenchConstants
 
     String ExecutionErrors();
 
-    String Tasks();
+    String Task_Inbox();
 
-    String Process_Dashboard();
+    String Process_Reports();
+
+    String Task_Reports();
 
     String Content_Management();
 
@@ -91,28 +93,16 @@ public interface DefaultWorkbenchConstants
 
     String WorkbenchRootNodeName();
 
-    String ConfigureRepositories();
-
     String PermissionAllow();
 
     String PermissionDeny();
 
-    String PromoteAssets();
-
-    String ReleaseProjects();
-
     String DataModelerEditSources();
 
     String ResourcePlanner();
 
     String WorkbenchRootNodeHelp();
 
-    String ConfigureRepositoriesHelp();
-
-    String PromoteAssetsHelp();
-
-    String ReleaseProjectsHelp();
-
     String DataModelerEditSourcesHelp();
 
     String ResourcePlannerHelp();
@@ -151,7 +141,7 @@ public interface DefaultWorkbenchConstants
 
     String Languages();
 
-    String Tasks_Admin();
+    String Tasks();
 
     String GuidedDecisionTree();
 
