@@ -16,7 +16,9 @@
 
 package org.kie.workbench.common.stunner.client.lienzo.canvas.controls;
 
+import java.util.ArrayList;
 import java.util.Collections;
+import java.util.List;
 
 import com.ait.lienzo.client.core.event.NodeMouseEnterEvent;
 import com.ait.lienzo.client.core.event.NodeMouseEnterHandler;
@@ -25,7 +27,9 @@ import com.ait.lienzo.client.core.event.NodeMouseExitHandler;
 import com.ait.lienzo.client.core.shape.MultiPath;
 import com.ait.lienzo.client.core.shape.wires.SelectionListener;
 import com.ait.lienzo.client.core.shape.wires.SelectionManager;
+import com.ait.lienzo.client.core.shape.wires.WiresLayer;
 import com.ait.lienzo.client.core.shape.wires.WiresManager;
+import com.ait.lienzo.client.core.types.BoundingBox;
 import com.ait.lienzo.client.core.types.Point2D;
 import com.ait.lienzo.test.LienzoMockitoTestRunner;
 import com.google.gwt.event.shared.HandlerRegistration;
@@ -36,9 +40,11 @@ import org.kie.workbench.common.stunner.client.lienzo.canvas.wires.WiresCanvas;
 import org.kie.workbench.common.stunner.client.lienzo.shape.view.wires.ext.WiresShapeViewExt;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvas;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
+import org.kie.workbench.common.stunner.core.client.canvas.CanvasHandler;
 import org.kie.workbench.common.stunner.core.client.canvas.Layer;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.select.MapSelectionControl;
 import org.kie.workbench.common.stunner.core.client.canvas.event.CanvasDrawnEvent;
+import org.kie.workbench.common.stunner.core.client.canvas.event.ShapeLocationsChangedEvent;
 import org.kie.workbench.common.stunner.core.client.canvas.event.selection.CanvasClearSelectionEvent;
 import org.kie.workbench.common.stunner.core.client.canvas.event.selection.CanvasSelectionEvent;
 import org.kie.workbench.common.stunner.core.client.shape.Shape;
@@ -68,9 +74,16 @@ import static org.mockito.Mockito.when;
 public class LienzoMultipleSelectionControlTest {
 
     private static final String ELEMENT_UUID = "element-uuid1";
-    private static ViewEventType[] viewEventTypes = {};
     private final static MultiPath PATH = new MultiPath();
 
+    private final static double MIN_WIDTH = 0D;
+    private final static double MIN_HEIGHT = 0D;
+    private final static double MAX_WIDTH = 100D;
+    private final static double MAX_HEIGHT = 100D;
+    private final static double PADDING = SelectionManager.SELECTION_PADDING;
+
+    private static ViewEventType[] viewEventTypes = {};
+
     @Mock
     private EventSourceMock<CanvasSelectionEvent> canvasSelectionEvent;
 
@@ -92,12 +105,21 @@ public class LienzoMultipleSelectionControlTest {
     @Mock
     private com.ait.lienzo.client.core.shape.Layer lienzoLayer;
 
+    @Mock
+    private WiresLayer wiresLayer;
+
+    @Mock
+    private com.ait.lienzo.client.core.shape.Layer overLayer;
+
     @Mock
     private WiresManager wiresManager;
 
     @Mock
     private SelectionManager selectionManager;
 
+    @Mock
+    private SelectionManager.SelectedItems selectedItems;
+
     @Mock
     private Object definition;
 
@@ -113,6 +135,9 @@ public class LienzoMultipleSelectionControlTest {
     @Mock
     private SelectionManager.SelectionShapeProvider delegateShapeProvider;
 
+    @Mock
+    private ShapeLocationsChangedEvent shapeLocationsChangedEvent;
+
     private LienzoMultipleSelectionControl<AbstractCanvasHandler> tested;
     private SelectionListener selectionListener;
     private LienzoMultipleSelectionControl.CursoredSelectionShapeProvider selectionShapeProvider;
@@ -121,6 +146,10 @@ public class LienzoMultipleSelectionControlTest {
     @Before
     @SuppressWarnings("unchecked")
     public void setup() {
+
+        when(wiresManager.getLayer()).thenReturn(wiresLayer);
+        when(wiresLayer.getLayer()).thenReturn(lienzoLayer);
+        when(lienzoLayer.getOverLayer()).thenReturn(overLayer);
         when(wiresManager.getSelectionManager()).thenReturn(selectionManager);
         doAnswer(new Answer() {
             @Override
@@ -225,6 +254,58 @@ public class LienzoMultipleSelectionControlTest {
         verify(selectionControl, never()).clearSelection();
     }
 
+    @Test
+    public void testOnShapeLocationsChanged() {
+
+        //Different canvas
+        when(shapeLocationsChangedEvent.getCanvasHandler()).thenReturn(mock(CanvasHandler.class));
+        tested.onShapeLocationsChanged(shapeLocationsChangedEvent);
+
+        verify(selectedItems, never()).rebuildBoundingBox();
+        verify(selectionManager, never()).drawSelectionShape(eq(MIN_WIDTH),
+                                                             eq(MIN_HEIGHT),
+                                                             eq(MAX_WIDTH),
+                                                             eq(MAX_HEIGHT),
+                                                             eq(overLayer));
+
+        //Same canvas no selectedItems
+
+        when(shapeLocationsChangedEvent.getCanvasHandler()).thenReturn(canvasHandler);
+        when(shapeLocationsChangedEvent.getUuids()).thenReturn(new ArrayList<>());
+        tested.onShapeLocationsChanged(shapeLocationsChangedEvent);
+
+        verify(selectedItems, never()).rebuildBoundingBox();
+        verify(selectionManager, never()).drawSelectionShape(eq(MIN_WIDTH),
+                                                             eq(MIN_HEIGHT),
+                                                             eq(MAX_WIDTH),
+                                                             eq(MAX_HEIGHT),
+                                                             eq(overLayer));
+
+        //Same canvas with selected items
+
+        when(shapeLocationsChangedEvent.getCanvasHandler()).thenReturn(canvasHandler);
+
+        List<String> selectedUUIds = new ArrayList<>();
+        selectedUUIds.add("ELEMENT_UUID");
+
+        when(shapeLocationsChangedEvent.getUuids()).thenReturn(selectedUUIds);
+        when(tested.getSelectedItems()).thenReturn(selectedUUIds);
+
+        when(delegateShapeProvider.getShape()).thenReturn(mock(com.ait.lienzo.client.core.shape.Shape.class));
+        when(selectionManager.getSelectedItems()).thenReturn(selectedItems);
+        when(selectedItems.getBoundingBox()).thenReturn(new BoundingBox(MIN_WIDTH, MIN_HEIGHT, MAX_WIDTH, MAX_HEIGHT));
+        when(shapeLocationsChangedEvent.getCanvasHandler()).thenReturn(canvasHandler);
+
+        tested.onShapeLocationsChanged(shapeLocationsChangedEvent);
+
+        verify(selectedItems, times(1)).rebuildBoundingBox();
+        verify(selectionManager, times(1)).drawSelectionShape(eq(MIN_WIDTH),
+                                                              eq(MIN_HEIGHT),
+                                                              eq(MAX_WIDTH),
+                                                              eq(MAX_HEIGHT),
+                                                              eq(overLayer));
+    }
+
     @Test
     public void testDeselect() {
         tested.enable(canvasHandler);
