@@ -16,6 +16,8 @@
 
 package org.kie.workbench.common.stunner.client.lienzo.shape.view.wires;
 
+import java.util.List;
+
 import com.ait.lienzo.client.core.shape.IPrimitive;
 import com.ait.lienzo.client.core.shape.MultiPath;
 import com.ait.lienzo.client.core.shape.MultiPathDecorator;
@@ -31,6 +33,7 @@ import com.ait.lienzo.client.core.shape.wires.handlers.WiresConnectorControl;
 import com.ait.lienzo.client.core.types.BoundingBox;
 import com.ait.lienzo.client.core.types.Point2D;
 import com.ait.lienzo.client.core.types.Point2DArray;
+import com.ait.lienzo.client.core.types.Shadow;
 import com.ait.lienzo.shared.core.types.IColor;
 import com.ait.lienzo.test.LienzoMockitoTestRunner;
 import org.junit.Before;
@@ -38,7 +41,11 @@ import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.kie.workbench.common.stunner.client.lienzo.canvas.wires.WiresUtils;
 import org.kie.workbench.common.stunner.core.client.shape.view.HasControlPoints;
+import org.kie.workbench.common.stunner.core.graph.content.view.ControlPoint;
+import org.kie.workbench.common.stunner.core.graph.content.view.ControlPointImpl;
 import org.kie.workbench.common.stunner.core.graph.content.view.MagnetConnection;
+import org.mockito.ArgumentCaptor;
+import org.mockito.InOrder;
 import org.mockito.Mock;
 
 import static org.junit.Assert.assertEquals;
@@ -47,8 +54,11 @@ import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.anyDouble;
 import static org.mockito.Matchers.anyString;
 import static org.mockito.Matchers.eq;
+import static org.mockito.Matchers.isNull;
+import static org.mockito.Mockito.inOrder;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.never;
+import static org.mockito.Mockito.spy;
 import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
@@ -60,6 +70,8 @@ public class WiresConnectorViewTest {
     private OrthogonalPolyLine line;
 
     @Mock
+    private Shape lineShape;
+
     private Point2DArray point2DArray;
 
     @Mock
@@ -76,22 +88,29 @@ public class WiresConnectorViewTest {
 
     private WiresConnectorView tested;
 
+    @Mock
+    private WiresConnectorControl wiresConnectorControl;
+
     @Before
     @SuppressWarnings("unchecked")
     public void setup() throws Exception {
         Node lineNode = line;
         Node headPathNode = headPath;
         Node tailPathNode = tailPath;
-        when(line.getPoint2DArray()).thenReturn(new Point2DArray(10,
-                                                                 10));
+
+        point2DArray = new Point2DArray(new Point2D(0, 10), new Point2D(10, 10), new Point2D(20, 20), new Point2D(30, 30), new Point2D(40, 40));
+
+        when(line.getPoint2DArray()).thenReturn(point2DArray);
+        when(line.asShape()).thenReturn(lineShape);
         when(line.asNode()).thenReturn(lineNode);
-        when(line.setFillColor(anyString())).thenReturn(line);
-        when(line.setFillColor(any(IColor.class))).thenReturn(line);
-        when(line.setFillAlpha(anyDouble())).thenReturn(line);
-        when(line.setStrokeColor(anyString())).thenReturn(line);
-        when(line.setStrokeColor(any(IColor.class))).thenReturn(line);
-        when(line.setStrokeAlpha(anyDouble())).thenReturn(line);
-        when(line.setStrokeWidth(anyDouble())).thenReturn(line);
+        when(lineShape.setFillColor(anyString())).thenReturn(lineShape);
+        when(lineShape.setFillColor(any(IColor.class))).thenReturn(lineShape);
+        when(lineShape.setFillAlpha(anyDouble())).thenReturn(lineShape);
+        when(lineShape.setStrokeColor(anyString())).thenReturn(lineShape);
+        when(lineShape.setStrokeColor(any(IColor.class))).thenReturn(lineShape);
+        when(lineShape.setStrokeAlpha(anyDouble())).thenReturn(lineShape);
+        when(lineShape.setStrokeWidth(anyDouble())).thenReturn(lineShape);
+        when(line.isControlPointShape()).thenReturn(true);
         when(headDecorator.getPath()).thenReturn(headPath);
         when(tailDecorator.getPath()).thenReturn(tailPath);
         when(headPath.asNode()).thenReturn(headPathNode);
@@ -103,6 +122,8 @@ public class WiresConnectorViewTest {
         this.tested = new WiresConnectorView(line,
                                              headDecorator,
                                              tailDecorator);
+        this.tested.setControl(wiresConnectorControl);
+        tested = spy(tested);
     }
 
     @Test
@@ -139,7 +160,7 @@ public class WiresConnectorViewTest {
     public void testFillAttributes() {
         tested.setFillColor("color1");
         tested.setFillAlpha(0.53);
-        verify(line,
+        verify(lineShape,
                times(1)).setFillColor(eq("color1"));
         verify(line,
                times(1)).setFillAlpha(eq(0.53));
@@ -158,11 +179,11 @@ public class WiresConnectorViewTest {
         tested.setStrokeColor("color1");
         tested.setStrokeWidth(3.89);
         tested.setStrokeAlpha(0.53);
-        verify(line,
+        verify(lineShape,
                times(1)).setStrokeColor(eq("color1"));
         verify(line,
                times(1)).setStrokeAlpha(eq(0.53));
-        verify(line,
+        verify(lineShape,
                times(1)).setStrokeWidth(eq(3.89));
         verify(headPath,
                times(1)).setStrokeColor(eq("color1"));
@@ -361,4 +382,79 @@ public class WiresConnectorViewTest {
         verify(tailWiresConnection,
                times(1)).setMagnet(eq(tailMagnet2));
     }
-}
+
+    @Test
+    public void testAddControlPoint() {
+        Point2D point1 = point2DArray.get(1);
+        Point2D point2 = point2DArray.get(2);
+        Point2D point3 = point2DArray.get(3);
+
+        when(wiresConnectorControl.addControlPoint(point1.getX(), point1.getY())).thenReturn(1);
+        when(wiresConnectorControl.addControlPoint(point2.getX(), point2.getY())).thenReturn(2);
+        when(wiresConnectorControl.addControlPoint(point3.getX(), point3.getY())).thenReturn(3);
+
+        ControlPoint controlPoint1 = new ControlPointImpl(point1.getX(), point1.getY());
+        ControlPoint controlPoint2 = new ControlPointImpl(point2.getX(), point2.getY());
+        ControlPoint controlPoint3 = new ControlPointImpl(point3.getX(), point3.getY());
+
+        //without index
+        List<ControlPoint> addedControlPoint = tested.addControlPoint(controlPoint1, controlPoint2);
+        addedControlPoint.addAll(tested.addControlPoint(controlPoint3));
+
+        InOrder addControlPointOrder = inOrder(wiresConnectorControl);
+        addControlPointOrder.verify(wiresConnectorControl).addControlPoint(point1.getX(), point1.getY());
+        addControlPointOrder.verify(wiresConnectorControl).addControlPoint(point2.getX(), point2.getY());
+        addControlPointOrder.verify(wiresConnectorControl).addControlPoint(point3.getX(), point3.getY());
+
+        assertEquals(addedControlPoint.get(0).getIndex(), 1, 0);
+        assertEquals(addedControlPoint.get(1).getIndex(), 2, 0);
+        assertEquals(addedControlPoint.get(2).getIndex(), 3, 0);
+
+        //now with index
+        addedControlPoint = tested.addControlPoint(controlPoint1, controlPoint2, controlPoint3);
+        addControlPointOrder = inOrder(wiresConnectorControl);
+        addControlPointOrder.verify(wiresConnectorControl).addControlPointToLine(controlPoint1.getLocation().getX(),
+                                                                                 controlPoint1.getLocation().getY(),
+                                                                                 controlPoint1.getIndex());
+        addControlPointOrder.verify(wiresConnectorControl).addControlPointToLine(controlPoint2.getLocation().getX(),
+                                                                                 controlPoint2.getLocation().getY(),
+                                                                                 controlPoint2.getIndex());
+        addControlPointOrder.verify(wiresConnectorControl).addControlPointToLine(controlPoint3.getLocation().getX(),
+                                                                                 controlPoint3.getLocation().getY(),
+                                                                                 controlPoint3.getIndex());
+
+        assertEquals(addedControlPoint.get(0).getIndex(), 1, 0);
+        assertEquals(addedControlPoint.get(1).getIndex(), 2, 0);
+        assertEquals(addedControlPoint.get(2).getIndex(), 3, 0);
+    }
+
+    @Test
+    public void testGetShapeControlPoints() {
+        List<ControlPoint> controlPoints = tested.getShapeControlPoints();
+        for (int i = 1; i < controlPoints.size() - 1; i++) {
+            ControlPoint controlPoint = controlPoints.get(i);
+            Point2D point = point2DArray.get(i);
+            assertEquals(controlPoint.getLocation().getX(), point.getX(), 0);
+            assertEquals(controlPoint.getLocation().getY(), point.getY(), 0);
+            assertEquals(controlPoint.getIndex().intValue(), i);
+        }
+    }
+
+    @Test
+    public void testSetShadow() {
+        tested.setShadow("red", 1, 2d, 3d);
+        ArgumentCaptor<Shadow> shadowArgumentCaptor = ArgumentCaptor.forClass(Shadow.class);
+        verify(line, times(1)).setShadow(shadowArgumentCaptor.capture());
+        final Shadow shadow = shadowArgumentCaptor.getValue();
+        assertEquals("red", shadow.getColor());
+        assertEquals(1, shadow.getBlur());
+        assertEquals(2d, shadow.getOffset().getX(), 0d);
+        assertEquals(3d, shadow.getOffset().getY(), 0d);
+    }
+
+    @Test
+    public void testRemoveShadow() {
+        tested.removeShadow();
+        verify(line, times(1)).setShadow((Shadow) isNull());
+    }
+}
\ No newline at end of file
