@@ -17,6 +17,7 @@ package org.kie.workbench.common.stunner.client.widgets.menu.dev.impl;
 
 import java.util.logging.Level;
 import java.util.logging.Logger;
+
 import javax.enterprise.context.Dependent;
 import javax.inject.Inject;
 
@@ -41,7 +42,7 @@ public class LogCommandHistoryDevCommand extends AbstractMenuDevCommand {
 
     @Override
     public String getText() {
-        return "Log Command History";
+        return "Command History - Log";
     }
 
     @Override
