@@ -16,7 +16,9 @@
 
 package org.kie.workbench.common.stunner.client.widgets.palette;
 
-import java.util.List;
+import java.util.HashMap;
+import java.util.Map;
+import java.util.function.Consumer;
 
 import javax.annotation.PostConstruct;
 import javax.annotation.PreDestroy;
@@ -29,13 +31,16 @@ import org.jboss.errai.common.client.dom.HTMLElement;
 import org.jboss.errai.ioc.client.api.ManagedInstance;
 import org.kie.soup.commons.validation.PortablePreconditions;
 import org.kie.workbench.common.stunner.client.widgets.palette.categories.DefinitionPaletteCategoryWidget;
-import org.kie.workbench.common.stunner.client.widgets.palette.factory.BS3PaletteViewFactory;
+import org.kie.workbench.common.stunner.client.widgets.palette.categories.items.DefinitionPaletteItemWidget;
 import org.kie.workbench.common.stunner.core.client.api.ShapeManager;
 import org.kie.workbench.common.stunner.core.client.canvas.event.CanvasFocusedEvent;
 import org.kie.workbench.common.stunner.core.client.components.glyph.ShapeGlyphDragHandler;
 import org.kie.workbench.common.stunner.core.client.components.palette.AbstractPalette;
-import org.kie.workbench.common.stunner.core.client.components.palette.model.definition.DefinitionPaletteCategory;
-import org.kie.workbench.common.stunner.core.client.components.palette.model.definition.DefinitionSetPalette;
+import org.kie.workbench.common.stunner.core.client.components.palette.DefaultPaletteCategory;
+import org.kie.workbench.common.stunner.core.client.components.palette.DefaultPaletteDefinition;
+import org.kie.workbench.common.stunner.core.client.components.palette.DefaultPaletteItem;
+import org.kie.workbench.common.stunner.core.client.components.palette.DefaultPaletteUtils;
+import org.kie.workbench.common.stunner.core.client.components.palette.PaletteItemMouseEvent;
 import org.kie.workbench.common.stunner.core.client.event.screen.ScreenMaximizedEvent;
 import org.kie.workbench.common.stunner.core.client.event.screen.ScreenMinimizedEvent;
 import org.kie.workbench.common.stunner.core.client.service.ClientFactoryService;
@@ -46,24 +51,23 @@ import org.kie.workbench.common.stunner.core.definition.shape.Glyph;
 import static org.kie.soup.commons.validation.PortablePreconditions.checkNotNull;
 
 @Dependent
-public class BS3PaletteWidgetImpl extends AbstractPalette<DefinitionSetPalette>
-        implements BS3PaletteWidget<DefinitionSetPalette>,
+public class BS3PaletteWidgetImpl
+        extends AbstractPalette<DefaultPaletteDefinition>
+        implements BS3PaletteWidget,
                    IsElement {
 
-    public static final String BG_COLOR = "#D3D3D3";
-
     private static final int GLYPH_ICON_SIZE = 30;
     private static final int PADDING = 10;
 
-    protected final ClientFactoryService clientFactoryServices;
-    protected ItemDropCallback itemDropCallback;
-    protected ItemDragStartCallback itemDragStartCallback;
-    protected ItemDragUpdateCallback itemDragUpdateCallback;
+    private final ClientFactoryService clientFactoryServices;
     private final ShapeGlyphDragHandler shapeGlyphDragHandler;
+    private final ManagedInstance<DefinitionPaletteCategoryWidget> categoryWidgetInstances;
+    private final ManagedInstance<DefinitionPaletteItemWidget> definitionPaletteItemWidgetInstances;
+    private Consumer<PaletteIDefinitionItemEvent> itemDropCallback;
+    private Consumer<PaletteIDefinitionItemEvent> itemDragStartCallback;
+    private Consumer<PaletteIDefinitionItemEvent> itemDragUpdateCallback;
+    private Map<String, DefinitionPaletteCategoryWidget> categoryWidgets = new HashMap<>();
 
-    private BS3PaletteViewFactory viewFactory;
-
-    private ManagedInstance<DefinitionPaletteCategoryWidget> categoryWidgetInstance;
     private BS3PaletteWidgetView view;
 
     @Inject
@@ -71,12 +75,14 @@ public class BS3PaletteWidgetImpl extends AbstractPalette<DefinitionSetPalette>
                                 final ClientFactoryService clientFactoryServices,
                                 final BS3PaletteWidgetView view,
                                 final ShapeGlyphDragHandler shapeGlyphDragHandler,
-                                final ManagedInstance<DefinitionPaletteCategoryWidget> categoryWidgetInstance) {
+                                final ManagedInstance<DefinitionPaletteCategoryWidget> categoryWidgetInstance,
+                                final ManagedInstance<DefinitionPaletteItemWidget> definitionPaletteItemWidgets) {
         super(shapeManager);
         this.clientFactoryServices = clientFactoryServices;
         this.view = view;
         this.shapeGlyphDragHandler = shapeGlyphDragHandler;
-        this.categoryWidgetInstance = categoryWidgetInstance;
+        this.categoryWidgetInstances = categoryWidgetInstance;
+        this.definitionPaletteItemWidgetInstances = definitionPaletteItemWidgets;
     }
 
     public static int getDefaultWidth() {
@@ -87,24 +93,23 @@ public class BS3PaletteWidgetImpl extends AbstractPalette<DefinitionSetPalette>
     public void init() {
         view.init(this);
         view.setShapeGlyphDragHandler(shapeGlyphDragHandler);
-        view.setBackgroundColor(BG_COLOR);
         view.showEmptyView(true);
     }
 
     @Override
-    public BS3PaletteWidget onItemDrop(ItemDropCallback callback) {
+    public BS3PaletteWidget onItemDrop(final Consumer<PaletteIDefinitionItemEvent> callback) {
         this.itemDropCallback = callback;
         return this;
     }
 
     @Override
-    public BS3PaletteWidget onItemDragStart(final ItemDragStartCallback callback) {
+    public BS3PaletteWidget onItemDragStart(final Consumer<PaletteIDefinitionItemEvent> callback) {
         this.itemDragStartCallback = callback;
         return this;
     }
 
     @Override
-    public BS3PaletteWidget onItemDragUpdate(final ItemDragUpdateCallback callback) {
+    public BS3PaletteWidget onItemDragUpdate(final Consumer<PaletteIDefinitionItemEvent> callback) {
         this.itemDragUpdateCallback = callback;
         return this;
     }
@@ -117,10 +122,11 @@ public class BS3PaletteWidgetImpl extends AbstractPalette<DefinitionSetPalette>
             final Object definition = clientFactoryServices.getClientFactoryManager().newDefinition(definitionId);
             final ShapeFactory<?, ? extends Shape> factory = getShapeFactory();
             // Fire the callback as shape drag starts.
-            itemDragStartCallback.onDragStartItem(definition,
-                                                  factory,
-                                                  x,
-                                                  y);
+            itemDragStartCallback.accept(new PaletteIDefinitionItemEvent(definitionId,
+                                                                         definition,
+                                                                         factory,
+                                                                         x,
+                                                                         y));
         }
     }
 
@@ -132,19 +138,14 @@ public class BS3PaletteWidgetImpl extends AbstractPalette<DefinitionSetPalette>
             final Object definition = clientFactoryServices.getClientFactoryManager().newDefinition(definitionId);
             final ShapeFactory<?, ? extends Shape> factory = getShapeFactory();
             // Fire the callback as shape dragged over the target canvas.
-            itemDragUpdateCallback.onDragUpdateItem(definition,
-                                                    factory,
-                                                    x,
-                                                    y);
+            itemDragUpdateCallback.accept(new PaletteIDefinitionItemEvent(definitionId,
+                                                                          definition,
+                                                                          factory,
+                                                                          x,
+                                                                          y));
         }
     }
 
-    @Override
-    public BS3PaletteWidget setViewFactory(final BS3PaletteViewFactory viewFactory) {
-        this.viewFactory = viewFactory;
-        return this;
-    }
-
     public void unbind() {
         if (null != paletteDefinition) {
             view.clear();
@@ -154,23 +155,22 @@ public class BS3PaletteWidgetImpl extends AbstractPalette<DefinitionSetPalette>
     }
 
     @Override
-    public void setVisible(final PaletteVisibility visibility) {
-        view.showEmptyView(!visibility.isVisible());
+    public void setVisible(final boolean visible) {
+        view.showEmptyView(!visible);
     }
 
     @Override
     public void onScreenMaximized(final ScreenMaximizedEvent event) {
-        setVisible(event.isDiagramScreen() ? PaletteWidget.VISIBLE : PaletteWidget.HIDDEN);
+        setVisible(event.isDiagramScreen());
     }
 
     @Override
     public void onScreenMinimized(final ScreenMinimizedEvent event) {
-        setVisible(PaletteWidget.VISIBLE);
+        setVisible(true);
     }
 
     protected ShapeFactory getShapeFactory() {
-        final DefinitionSetPalette palette = paletteDefinition;
-        return shapeManager.getDefaultShapeSet(palette.getDefinitionSetId()).getShapeFactory();
+        return shapeManager.getDefaultShapeSet(paletteDefinition.getDefinitionSetId()).getShapeFactory();
     }
 
     public double getIconSize() {
@@ -185,30 +185,22 @@ public class BS3PaletteWidgetImpl extends AbstractPalette<DefinitionSetPalette>
 
     @Override
     @SuppressWarnings("unchecked")
-    protected AbstractPalette<DefinitionSetPalette> bind() {
-        final DefinitionSetPalette palette = paletteDefinition;
-        if (null != palette) {
-            palette.getItems().forEach(definitionPaletteCategory -> {
-                final DefinitionPaletteCategoryWidget widget = categoryWidgetInstance.get();
-                widget.initialize(definitionPaletteCategory,
-                                  viewFactory,
+    protected AbstractPalette<DefaultPaletteDefinition> bind() {
+        if (null != paletteDefinition) {
+            paletteDefinition.getItems().forEach(item -> {
+                BS3PaletteWidgetPresenter widget;
+                if (item instanceof DefaultPaletteCategory) {
+                    widget = categoryWidgetInstances.get();
+                    categoryWidgets.put(item.getId(),
+                                        (DefinitionPaletteCategoryWidget) widget);
+                } else {
+                    widget = definitionPaletteItemWidgetInstances.get();
+                }
+                final Consumer<PaletteItemMouseEvent> itemMouseEventHandler =
+                        this::handleMouseDownEvent;
+                widget.initialize(item,
                                   getShapeFactory(),
-                                  (id, mouseX, mouseY, itemX, itemY) -> {
-                                      PortablePreconditions.checkNotNull("id",
-                                                                         id);
-                                      final String catDefId = getDefinitionIdForCategory(id);
-                                      if (null != catDefId) {
-                                          BS3PaletteWidgetImpl.this.onPaletteItemMouseDown(catDefId,
-                                                                                           mouseX,
-                                                                                           mouseY);
-                                          return true;
-                                      }
-                                      BS3PaletteWidgetImpl.this.onPaletteItemMouseDown(id,
-                                                                                       mouseX,
-                                                                                       mouseY);
-                                      return true;
-                                  });
-
+                                  itemMouseEventHandler);
                 view.add(widget);
             });
         }
@@ -216,6 +208,7 @@ public class BS3PaletteWidgetImpl extends AbstractPalette<DefinitionSetPalette>
     }
 
     @Override
+    @SuppressWarnings("unchecked")
     public void onDragProxyComplete(final String definitionId,
                                     final double x,
                                     final double y) {
@@ -223,10 +216,11 @@ public class BS3PaletteWidgetImpl extends AbstractPalette<DefinitionSetPalette>
             final Object definition = clientFactoryServices.getClientFactoryManager().newDefinition(definitionId);
             final ShapeFactory<?, ? extends Shape> factory = getShapeFactory();
             // Fire the callback as shape dropped onto the target canvas.
-            itemDropCallback.onDropItem(definition,
-                                        factory,
-                                        x,
-                                        y);
+            itemDropCallback.accept(new PaletteIDefinitionItemEvent(definitionId,
+                                                                    definition,
+                                                                    factory,
+                                                                    x,
+                                                                    y));
         }
     }
 
@@ -235,22 +229,33 @@ public class BS3PaletteWidgetImpl extends AbstractPalette<DefinitionSetPalette>
         return getShapeFactory().getGlyph(definitionId);
     }
 
-    private String getDefinitionIdForCategory(final String id) {
-        final DefinitionPaletteCategory categoryItem = getMainPaletteItem(id);
-        return null != categoryItem ? categoryItem.getDefinitionId() : null;
+    private void handleMouseDownEvent(final PaletteItemMouseEvent event) {
+        PortablePreconditions.checkNotNull("event",
+                                           event);
+        if (categoryWidgets.containsKey(event.getId())) {
+            showCategory(event.getId());
+        } else {
+            final String defId = getItemDefinitionId(event.getId());
+            BS3PaletteWidgetImpl.this.onPaletteItemMouseDown(defId,
+                                                             event.getMouseX(),
+                                                             event.getMouseY());
+        }
+    }
+
+    private String getItemDefinitionId(final String itemId) {
+        return DefaultPaletteUtils.getPaletteItemDefinitionId(paletteDefinition,
+                                                              itemId);
+    }
+
+    private void showCategory(final String categoryId) {
+        categoryWidgets.entrySet().stream().filter(entry -> !entry.getKey().equals(categoryId)).forEach(entry -> entry.getValue().setVisible(false));
+        DefinitionPaletteCategoryWidget widget = categoryWidgets.get(categoryId);
+        widget.setVisible(!widget.isVisible());
     }
 
     private void onPaletteItemMouseDown(final String id,
                                         final double x,
                                         final double y) {
-        showDragProxy(id,
-                      x,
-                      y);
-    }
-
-    private void showDragProxy(final String id,
-                               final double x,
-                               final double y) {
         // Show the drag proxy for the element at x, y.
         view.showDragProxy(id,
                            x,
@@ -259,26 +264,6 @@ public class BS3PaletteWidgetImpl extends AbstractPalette<DefinitionSetPalette>
                            getIconSize());
     }
 
-    private List<DefinitionPaletteCategory> getMainPaletteItems() {
-        return paletteDefinition.getItems();
-    }
-
-    private DefinitionPaletteCategory getMainPaletteItem(final int index) {
-        return getMainPaletteItems().get(index);
-    }
-
-    private DefinitionPaletteCategory getMainPaletteItem(final String id) {
-        final List<DefinitionPaletteCategory> categories = getMainPaletteItems();
-        if (null != categories && !categories.isEmpty()) {
-            for (final DefinitionPaletteCategory category : categories) {
-                if (category.getId().equals(id)) {
-                    return category;
-                }
-            }
-        }
-        return null;
-    }
-
     void onCanvasFocusedEvent(final @Observes CanvasFocusedEvent canvasFocusedEvent) {
         checkNotNull("canvasFocusedEvent",
                      canvasFocusedEvent);
@@ -287,15 +272,15 @@ public class BS3PaletteWidgetImpl extends AbstractPalette<DefinitionSetPalette>
     @PreDestroy
     @Override
     protected void doDestroy() {
-        categoryWidgetInstance.destroyAll();
-        viewFactory.destroy();
+        categoryWidgetInstances.destroyAll();
+        definitionPaletteItemWidgetInstances.destroyAll();
         view.destroy();
         this.itemDropCallback = null;
     }
 
     @Override
     protected String getPaletteItemId(final int index) {
-        final DefinitionPaletteCategory item = getMainPaletteItem(index);
+        final DefaultPaletteItem item = paletteDefinition.getItems().get(index);
         return null != item ? item.getId() : null;
     }
 
