@@ -16,12 +16,14 @@
 
 package org.kie.workbench.common.stunner.client.widgets.presenters.diagram.impl;
 
+import org.jboss.errai.ioc.client.api.Disposer;
 import org.kie.workbench.common.stunner.client.widgets.presenters.diagram.DiagramEditor;
 import org.kie.workbench.common.stunner.client.widgets.presenters.diagram.DiagramViewer;
 import org.kie.workbench.common.stunner.client.widgets.views.WidgetWrapperView;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvas;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.canvas.Canvas;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.CanvasControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.CanvasControlRegistrationHandler;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.connection.ConnectionAcceptorControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.containment.ContainmentAcceptorControl;
@@ -30,6 +32,7 @@ import org.kie.workbench.common.stunner.core.client.canvas.controls.select.Selec
 import org.kie.workbench.common.stunner.core.client.canvas.controls.zoom.ZoomControl;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommandManager;
 import org.kie.workbench.common.stunner.core.client.service.ClientRuntimeError;
+import org.kie.workbench.common.stunner.core.client.session.ClientSession;
 import org.kie.workbench.common.stunner.core.diagram.Diagram;
 
 /**
@@ -38,7 +41,7 @@ import org.kie.workbench.common.stunner.core.diagram.Diagram;
  * @param <D> The diagram type.
  * @param <H> The canvas handler type.
  */
-public class DiagramEditorImpl<D extends Diagram, H extends AbstractCanvasHandler>
+public class DiagramEditorImpl<D extends Diagram, H extends AbstractCanvasHandler, S extends ClientSession>
         implements DiagramEditor<D, H> {
 
     private final DiagramViewer<D, H> viewer;
@@ -46,19 +49,22 @@ public class DiagramEditorImpl<D extends Diagram, H extends AbstractCanvasHandle
     private final ConnectionAcceptorControl<H> connectionAcceptorControl;
     private final ContainmentAcceptorControl<H> containmentAcceptorControl;
     private final DockingAcceptorControl<H> dockingAcceptorControl;
+    private final Disposer<CanvasControl> disposer;
 
-    private CanvasControlRegistrationHandler<AbstractCanvas, H> registrationHandler;
+    private CanvasControlRegistrationHandler<AbstractCanvas, H, S> registrationHandler;
 
     DiagramEditorImpl(final DiagramViewer<D, H> viewer,
                       final CanvasCommandManager<H> commandManager,
                       final ConnectionAcceptorControl<H> connectionAcceptorControl,
                       final ContainmentAcceptorControl<H> containmentAcceptorControl,
-                      final DockingAcceptorControl<H> dockingAcceptorControl) {
+                      final DockingAcceptorControl<H> dockingAcceptorControl,
+                      final Disposer<CanvasControl> disposer) {
         this.viewer = viewer;
         this.commandManager = commandManager;
         this.connectionAcceptorControl = connectionAcceptorControl;
         this.containmentAcceptorControl = containmentAcceptorControl;
         this.dockingAcceptorControl = dockingAcceptorControl;
+        this.disposer = disposer;
         this.registrationHandler = null;
     }
 
@@ -104,6 +110,7 @@ public class DiagramEditorImpl<D extends Diagram, H extends AbstractCanvasHandle
 
     public void clear() {
         if (null != registrationHandler) {
+            this.registrationHandler.disable();
             this.registrationHandler.clear();
             this.registrationHandler = null;
         }
@@ -113,6 +120,7 @@ public class DiagramEditorImpl<D extends Diagram, H extends AbstractCanvasHandle
     @Override
     public void destroy() {
         if (null != registrationHandler) {
+            this.registrationHandler.disable();
             this.registrationHandler.destroy();
             this.registrationHandler = null;
         }
@@ -180,8 +188,8 @@ public class DiagramEditorImpl<D extends Diagram, H extends AbstractCanvasHandle
 
     private void prepareEdit() {
         registrationHandler =
-                new CanvasControlRegistrationHandler<AbstractCanvas, H>((AbstractCanvas) getHandler().getCanvas(),
-                                                                        getHandler());
+                new CanvasControlRegistrationHandler<AbstractCanvas, H, S>((AbstractCanvas) getHandler().getCanvas(),
+                                                                           getHandler(), disposer);
         registrationHandler.setCommandManagerProvider(this::getCommandManager);
         // Register the canvas controls that the aggregated diagram viewer instance does not provide.
         registrationHandler.registerCanvasHandlerControl(connectionAcceptorControl);
