@@ -16,13 +16,16 @@
 
 package org.kie.workbench.common.stunner.client.widgets.presenters.diagram.impl;
 
+import org.jboss.errai.ioc.client.api.Disposer;
 import org.kie.workbench.common.stunner.client.widgets.canvas.wires.WiresCanvasPresenter;
 import org.kie.workbench.common.stunner.client.widgets.views.WidgetWrapperView;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvas;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.CanvasControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.CanvasControlRegistrationHandler;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.select.SelectionControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.zoom.ZoomControl;
+import org.kie.workbench.common.stunner.core.client.session.ClientSession;
 import org.kie.workbench.common.stunner.core.diagram.Diagram;
 import org.kie.workbench.common.stunner.core.graph.Element;
 
@@ -32,27 +35,30 @@ import org.kie.workbench.common.stunner.core.graph.Element;
  * It provides a zoom and selection control that third parties can interacti with, but it does not provide
  * any controls that allow the diagram's authoring.
  */
-public class DiagramViewerImpl<D extends Diagram, H extends AbstractCanvasHandler>
+public class DiagramViewerImpl<D extends Diagram, H extends AbstractCanvasHandler, S extends ClientSession>
         extends AbstractDiagramViewer<D, H> {
 
     private final AbstractCanvas canvas;
     private final H canvasHandler;
     private final ZoomControl<AbstractCanvas> zoomControl;
     private final SelectionControl<H, Element> selectionControl;
+    private final Disposer<CanvasControl> disposer;
 
-    private CanvasControlRegistrationHandler<AbstractCanvas, H> registrationHandler;
+    private CanvasControlRegistrationHandler<AbstractCanvas, H, S> registrationHandler;
 
     DiagramViewerImpl(final AbstractCanvas canvas,
                       final H canvasHandler,
                       final WidgetWrapperView view,
                       final ZoomControl<AbstractCanvas> zoomControl,
-                      final SelectionControl<H, Element> selectionControl) {
+                      final SelectionControl<H, Element> selectionControl,
+                      final Disposer<CanvasControl> disposer) {
         super(view);
         this.canvas = canvas;
         this.canvasHandler = canvasHandler;
         this.zoomControl = zoomControl;
         this.selectionControl = selectionControl;
         this.registrationHandler = null;
+        this.disposer = disposer;
     }
 
     @Override
@@ -70,13 +76,14 @@ public class DiagramViewerImpl<D extends Diagram, H extends AbstractCanvasHandle
     @Override
     protected void enableControls() {
         registrationHandler =
-                new CanvasControlRegistrationHandler<AbstractCanvas, H>(getHandler().getAbstractCanvas(),
-                                                                        getHandler());
+                new CanvasControlRegistrationHandler<AbstractCanvas, H, S>(getHandler().getAbstractCanvas(),
+                                                                           getHandler(),
+                                                                           disposer);
         registerControls(registrationHandler);
         registrationHandler.enable();
     }
 
-    protected void registerControls(final CanvasControlRegistrationHandler<AbstractCanvas, H> registrationHandler) {
+    protected void registerControls(final CanvasControlRegistrationHandler<AbstractCanvas, H, S> registrationHandler) {
         registrationHandler.registerCanvasControl(getZoomControl());
         registrationHandler.registerCanvasHandlerControl(getSelectionControl());
     }
@@ -84,6 +91,7 @@ public class DiagramViewerImpl<D extends Diagram, H extends AbstractCanvasHandle
     @Override
     protected void disableControls() {
         if (null != registrationHandler) {
+            registrationHandler.disable();
             registrationHandler.clear();
             registrationHandler = null;
         }
@@ -92,6 +100,7 @@ public class DiagramViewerImpl<D extends Diagram, H extends AbstractCanvasHandle
     @Override
     protected void destroyControls() {
         if (null != registrationHandler) {
+            registrationHandler.disable();
             registrationHandler.destroy();
             registrationHandler = null;
         }
