@@ -22,7 +22,7 @@ import javax.enterprise.event.Event;
 
 import org.kie.workbench.common.stunner.client.widgets.event.SessionDiagramOpenedEvent;
 import org.kie.workbench.common.stunner.client.widgets.notification.NotificationsObserver;
-import org.kie.workbench.common.stunner.client.widgets.palette.factory.BS3PaletteFactory;
+import org.kie.workbench.common.stunner.client.widgets.palette.DefaultPaletteFactory;
 import org.kie.workbench.common.stunner.client.widgets.presenters.session.SessionDiagramPresenter;
 import org.kie.workbench.common.stunner.client.widgets.presenters.session.SessionEditor;
 import org.kie.workbench.common.stunner.client.widgets.toolbar.ToolbarFactory;
@@ -39,9 +39,9 @@ import org.kie.workbench.common.stunner.core.diagram.Diagram;
 
 /**
  * A generic session's presenter instance for authoring purposes.
- * <p/>
+ * <p>
  * It provides support for an editor Toolbar and a BS3 Palette widget.
- * <p/>
+ * <p>
  * It aggregates a custom session viewer type which provides binds the editors's diagram instance and the
  * different editors' controls with the diagram and controls for the given session.
  * @see <a>org.kie.workbench.common.stunner.client.widgets.presenters.session.impl.SessionEditorImpl</a>
@@ -58,7 +58,7 @@ public class SessionEditorPresenter<S extends AbstractClientFullSession, H exten
                            final CanvasCommandManager<H> commandManager,
                            final Event<SessionDiagramOpenedEvent> sessionDiagramOpenedEvent,
                            final EditorToolbarFactory toolbarFactory,
-                           final BS3PaletteFactory paletteWidgetFactory,
+                           final DefaultPaletteFactory<H> paletteWidgetFactory,
                            final WidgetWrapperView diagramEditorView,
                            final NotificationsObserver notificationsObserver,
                            final View view,
