@@ -17,6 +17,7 @@
 package org.kie.workbench.common.stunner.client.widgets.presenters.session.impl;
 
 import java.util.Optional;
+
 import javax.enterprise.event.Event;
 
 import org.kie.workbench.common.stunner.client.widgets.event.SessionDiagramOpenedEvent;
@@ -93,7 +94,7 @@ public class SessionViewerPresenter<S extends AbstractClientReadOnlySession, H e
     }
 
     @Override
-    protected SessionViewer<S, H, Diagram> getDisplayer() {
+    public SessionViewer<S, H, Diagram> getDisplayer() {
         return viewer;
     }
 
