@@ -29,12 +29,15 @@ import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvas;
 import org.kie.workbench.common.stunner.core.client.shape.view.ShapeView;
 import org.mockito.Mock;
 
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertEquals;
 import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.anyString;
 import static org.mockito.Matchers.eq;
 import static org.mockito.Matchers.isNull;
-import static org.mockito.Mockito.*;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(LienzoMockitoTestRunner.class)
 public class CanvasViewTest {
@@ -228,6 +231,10 @@ public class CanvasViewTest {
         tested.setCursor(AbstractCanvas.Cursors.CROSSHAIR);
         verify(panelStyle,
                times(1)).setCursor(eq(Style.Cursor.CROSSHAIR));
+        tested.setCursor(AbstractCanvas.Cursors.NOT_ALLOWED);
+        verify(panelStyle,
+               times(1)).setProperty(eq(CanvasView.CURSOR),
+                                     eq(CanvasView.CURSOR_NOT_ALLOWED));
     }
 
     @Test
