@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *   http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -42,5 +42,9 @@ public interface Metadata {
 
     void setPath(final Path path);
 
+    Path getRoot();
+
+    void setRoot(final Path path);
+
     Class<? extends Metadata> getMetadataType();
 }
