@@ -23,6 +23,7 @@ import java.util.Collection;
 import java.util.LinkedHashSet;
 import java.util.LinkedList;
 import java.util.Set;
+
 import javax.enterprise.inject.Instance;
 
 import org.kie.workbench.common.stunner.core.api.DefinitionManager;
@@ -50,7 +51,7 @@ import org.uberfire.java.nio.file.SimpleFileVisitor;
 import org.uberfire.java.nio.file.attribute.BasicFileAttributes;
 import org.uberfire.workbench.type.ResourceTypeDefinition;
 
-import static org.uberfire.commons.validation.PortablePreconditions.checkNotNull;
+import static org.kie.soup.commons.validation.PortablePreconditions.checkNotNull;
 import static org.uberfire.java.nio.file.Files.walkFileTree;
 
 // TODO: Use the diagram registry cache.
@@ -61,7 +62,6 @@ public abstract class AbstractVFSDiagramService<M extends Metadata, D extends Di
 
     private final DefinitionManager definitionManager;
     private final FactoryManager factoryManager;
-    private final IOService ioService;
     private final Instance<DefinitionSetService> definitionSetServiceInstances;
     private final BackendRegistryFactory registryFactory;
     private Collection<DefinitionSetService> definitionSetServices = new LinkedList<>();
@@ -70,15 +70,15 @@ public abstract class AbstractVFSDiagramService<M extends Metadata, D extends Di
     public AbstractVFSDiagramService(final DefinitionManager definitionManager,
                                      final FactoryManager factoryManager,
                                      final Instance<DefinitionSetService> definitionSetServiceInstances,
-                                     final IOService ioService,
                                      final BackendRegistryFactory registryFactory) {
         this.definitionManager = definitionManager;
         this.factoryManager = factoryManager;
-        this.ioService = ioService;
         this.definitionSetServiceInstances = definitionSetServiceInstances;
         this.registryFactory = registryFactory;
     }
 
+    protected abstract IOService getIoService();
+
     protected void initialize() {
         for (DefinitionSetService definitionSetService : definitionSetServiceInstances) {
             definitionSetServices.add(definitionSetService);
@@ -98,15 +98,15 @@ public abstract class AbstractVFSDiagramService<M extends Metadata, D extends Di
                                            services.getResourceType());
         final org.uberfire.java.nio.file.Path kiePath = Paths.convert(path).resolve(fName);
         try {
-            if (ioService.exists(kiePath)) {
+            if (getIoService().exists(kiePath)) {
                 throw new FileAlreadyExistsException(kiePath.toString());
             }
             final D diagram = factoryManager.newDiagram(name,
                                                         defSetId,
                                                         metadata);
-            final String[] raw = serizalize(diagram);
-            ioService.write(kiePath,
-                            raw[0]);
+            final String[] raw = serialize(diagram);
+            getIoService().write(kiePath,
+                                 raw[0]);
             return Paths.convert(kiePath);
         } catch (final Exception e) {
             LOG.error("Cannot create diagram in path [" + kiePath + "]",
@@ -115,6 +115,17 @@ public abstract class AbstractVFSDiagramService<M extends Metadata, D extends Di
         return null;
     }
 
+    @Override
+    public String getRawContent(D diagram) {
+        try {
+            return serialize(diagram)[0];
+        } catch (java.io.IOException e) {
+            LOG.error("Error while getting raw content for diagram with UUID [" + diagram.getName() + "].",
+                      e);
+            throw new RuntimeException(e);
+        }
+    }
+
     protected abstract Class<? extends Metadata> getMetadataType();
 
     private String buildFileName(final String baseFileName,
@@ -137,16 +148,10 @@ public abstract class AbstractVFSDiagramService<M extends Metadata, D extends Di
                 final String name = parseFileName(file,
                                                   services);
                 // Check if any metadata definition exist.
-                M metadata = null;
-                InputStream metaDataStream = loadMetadataForPath(file);
-                if (null != metaDataStream) {
-                    try {
-                        metadata = (M) services.getDiagramMarshaller().getMetadataMarshaller().unmarshall(metaDataStream);
-                    } catch (java.io.IOException e) {
-                        LOG.error("Cannot unmarshall metadata for diagram's path [" + file + "]",
-                                  e);
-                    }
-                }
+                M metadata = obtainMetadata(services,
+                                            file,
+                                            defSetId,
+                                            name);
                 if (null == metadata) {
                     metadata = (M) buildMetadataInstance(file,
                                                          defSetId,
@@ -173,6 +178,12 @@ public abstract class AbstractVFSDiagramService<M extends Metadata, D extends Di
         throw new UnsupportedOperationException("Diagram format not supported [" + file + "]");
     }
 
+    @SuppressWarnings("unchecked")
+    protected abstract M obtainMetadata(DefinitionSetService services,
+                                        final org.uberfire.backend.vfs.Path diagramFilePath,
+                                        final String defSetId,
+                                        final String fileName);
+
     private String parseFileName(final org.uberfire.backend.vfs.Path file,
                                  final DefinitionSetService services) {
         final String n = file.getFileName();
@@ -202,7 +213,7 @@ public abstract class AbstractVFSDiagramService<M extends Metadata, D extends Di
     @SuppressWarnings("unchecked")
     private M register(final D diagram) {
         try {
-            String[] raw = serizalize(diagram);
+            String[] raw = serialize(diagram);
             return doSave(diagram,
                           raw[0],
                           raw[1]);
@@ -214,7 +225,7 @@ public abstract class AbstractVFSDiagramService<M extends Metadata, D extends Di
     }
 
     @SuppressWarnings("unchecked")
-    protected String[] serizalize(final D diagram) throws java.io.IOException {
+    protected String[] serialize(final D diagram) throws java.io.IOException {
         final String defSetId = diagram.getMetadata().getDefinitionSetId();
         final DefinitionSetService services = getServiceById(defSetId);
         // Serialize using the concrete marshalling service.
@@ -232,7 +243,7 @@ public abstract class AbstractVFSDiagramService<M extends Metadata, D extends Di
     public Collection<D> getDiagramsByPath(final org.uberfire.java.nio.file.Path root) {
         try {
             final Collection<D> result = new ArrayList<D>();
-            if (ioService.exists(root)) {
+            if (getIoService().exists(root)) {
                 walkFileTree(checkNotNull("root",
                                           root),
                              new SimpleFileVisitor<org.uberfire.java.nio.file.Path>() {
@@ -245,10 +256,17 @@ public abstract class AbstractVFSDiagramService<M extends Metadata, D extends Di
                                                   attrs);
                                      org.uberfire.backend.vfs.Path file = org.uberfire.backend.server.util.Paths.convert(_file);
                                      if (accepts(file)) {
-                                         // portable diagram representation.
-                                         D diagram = getDiagramByPath(file);
-                                         if (null != diagram) {
-                                             result.add(diagram);
+                                         try {
+                                             // portable diagram representation.
+                                             D diagram = getDiagramByPath(file);
+                                             if (null != diagram) {
+                                                 result.add(diagram);
+                                             }
+                                         } catch (Exception e) {
+                                             //skipping add diagram to the result
+                                             LOG.error("Error getting diagram for path {}",
+                                                       file,
+                                                       e);
                                          }
                                      }
                                      return FileVisitResult.CONTINUE;
@@ -263,20 +281,18 @@ public abstract class AbstractVFSDiagramService<M extends Metadata, D extends Di
         }
     }
 
-    protected abstract InputStream loadMetadataForPath(final org.uberfire.backend.vfs.Path path);
-
     protected abstract Metadata buildMetadataInstance(final org.uberfire.backend.vfs.Path path,
                                                       final String defSetId,
                                                       final String title);
 
     protected InputStream loadPath(final org.uberfire.backend.vfs.Path _path) {
         org.uberfire.java.nio.file.Path path = Paths.convert(_path);
-        final byte[] bytes = ioService.readAllBytes(path);
+        final byte[] bytes = getIoService().readAllBytes(path);
         return new ByteArrayInputStream(bytes);
     }
 
     protected InputStream loadPath(final org.uberfire.java.nio.file.Path _path) {
-        final byte[] bytes = ioService.readAllBytes(_path);
+        final byte[] bytes = getIoService().readAllBytes(_path);
         return new ByteArrayInputStream(bytes);
     }
 
@@ -326,10 +342,6 @@ public abstract class AbstractVFSDiagramService<M extends Metadata, D extends Di
         return null;
     }
 
-    protected IOService getIoService() {
-        return ioService;
-    }
-
     protected DefinitionManager getDefinitionManager() {
         return definitionManager;
     }
