@@ -18,13 +18,10 @@ package org.kie.workbench.common.stunner.core.client.session.command;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 
-import elemental2.dom.RadioNodeList;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
-import org.kie.workbench.common.stunner.core.client.command.CanvasViolation;
-import org.kie.workbench.common.stunner.core.client.service.ClientRuntimeError;
+import org.kie.workbench.common.stunner.core.client.canvas.CanvasHandler;
+import org.kie.workbench.common.stunner.core.client.canvas.event.AbstractCanvasHandlerEvent;
 import org.kie.workbench.common.stunner.core.client.session.ClientSession;
-import org.kie.workbench.common.stunner.core.command.CommandResult;
-import org.kie.workbench.common.stunner.core.command.util.CommandUtils;
 import org.kie.workbench.common.stunner.core.graph.Element;
 import org.kie.workbench.common.stunner.core.graph.content.view.View;
 import org.uberfire.mvp.Command;
@@ -108,8 +105,16 @@ public abstract class AbstractClientSessionCommand<S extends ClientSession> impl
 
             @Override
             public void onError(final Throwable error) {
-                LOGGER.log(Level.SEVERE,errorMessage + " Details: " + error.toString());
+                LOGGER.log(Level.SEVERE,
+                           errorMessage + " Details: " + error.toString());
             }
         };
     }
+
+    protected boolean checkEventContext(final AbstractCanvasHandlerEvent canvasHandlerEvent) {
+        final CanvasHandler _canvasHandler = canvasHandlerEvent.getCanvasHandler();
+        return null != getSession() &&
+                getSession().getCanvasHandler() != null
+                && getSession().getCanvasHandler().equals(_canvasHandler);
+    }
 }
\ No newline at end of file
