@@ -31,6 +31,7 @@ import java.util.stream.StreamSupport;
 
 import javax.enterprise.context.Dependent;
 import javax.enterprise.event.Event;
+import javax.enterprise.event.Observes;
 import javax.inject.Inject;
 
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvas;
@@ -181,7 +182,7 @@ public class PasteSelectionSessionCommand extends AbstractClientSessionCommand<C
         CommandResult<CanvasViolation> connectorsResult = processConnectors(processedNodesCountdown);
 
         //After nodes and connectors command execution than it is necessary to update the command registry (to allow a single undo/redo)
-        if(!CommandUtils.isError(connectorsResult)) {
+        if (!CommandUtils.isError(connectorsResult)) {
             updateCommandsRegistry();
         }
 
@@ -243,7 +244,9 @@ public class PasteSelectionSessionCommand extends AbstractClientSessionCommand<C
     }
 
     public void clear() {
-        clipboardControl.clear();
+        if (null != clipboardControl) {
+            clipboardControl.clear();
+        }
         clonedElements.clear();
         yPositionStatistics = null;
     }
@@ -255,6 +258,22 @@ public class PasteSelectionSessionCommand extends AbstractClientSessionCommand<C
         return "";
     }
 
+    protected void onCopySelectionCommandExecuted(@Observes CopySelectionSessionCommandExecutedEvent event) {
+        checkNotNull("event", event);
+        if (Objects.equals(getSession(), event.getClientSession())) {
+            setEnabled(true);
+            fire();
+        }
+    }
+
+    protected void onCutSelectionCommandExecuted(@Observes CutSelectionSessionCommandExecutedEvent event) {
+        checkNotNull("event", event);
+        if (Objects.equals(getSession(), event.getClientSession())) {
+            setEnabled(true);
+            fire();
+        }
+    }
+
     private Consumer<Node> cloneNodeCallback(Node candidate, Counter processedNodesCountdown) {
         return clone -> {
             clonedElements.put(candidate.getUUID(), clone.getUUID());
