@@ -38,7 +38,10 @@ import org.uberfire.mocks.CallerMock;
 import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.anyString;
 import static org.mockito.Matchers.eq;
-import static org.mockito.Mockito.*;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(MockitoJUnitRunner.class)
 public class ClientDiagramServicesTest {
@@ -170,4 +173,18 @@ public class ClientDiagramServicesTest {
         verify(metadata,
                times(3)).setShapeSetId(eq(ssid));
     }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    public void testGetRawContent() {
+        ServiceCallback<String> callback = mock(ServiceCallback.class);
+        tested.getRawContent(diagram,
+                             callback);
+        verify(diagramService,
+               times(1)).getRawContent(eq(diagram));
+        verify(callback,
+               times(1)).onSuccess(any(String.class));
+        verify(callback,
+               times(0)).onError(any(ClientRuntimeError.class));
+    }
 }
