@@ -20,6 +20,7 @@ import java.util.logging.Logger;
 
 import org.jboss.errai.common.client.api.annotations.MapsTo;
 import org.jboss.errai.common.client.api.annotations.Portable;
+import org.kie.soup.commons.validation.PortablePreconditions;
 import org.kie.workbench.common.stunner.core.command.CommandResult;
 import org.kie.workbench.common.stunner.core.graph.Edge;
 import org.kie.workbench.common.stunner.core.graph.Element;
@@ -36,7 +37,6 @@ import org.kie.workbench.common.stunner.core.graph.content.view.View;
 import org.kie.workbench.common.stunner.core.graph.util.GraphUtils;
 import org.kie.workbench.common.stunner.core.rule.RuleViolation;
 import org.kie.workbench.common.stunner.core.rule.violations.BoundsExceededViolation;
-import org.uberfire.commons.validation.PortablePreconditions;
 
 /**
  * A Command to update an element's bounds.
@@ -47,62 +47,43 @@ public final class UpdateElementPositionCommand extends AbstractGraphCommand {
     private static Logger LOGGER = Logger.getLogger(UpdateElementPositionCommand.class.getName());
 
     private final String uuid;
-    private final Double x;
-    private final Double y;
-    private final Double oldX;
-    private final Double oldY;
+    private final Point2D location;
+    private final Point2D previousLocation;
     private transient Node<? extends View<?>, Edge> node;
 
     public UpdateElementPositionCommand(final @MapsTo("uuid") String uuid,
-                                        final @MapsTo("x") Double x,
-                                        final @MapsTo("y") Double y,
-                                        final @MapsTo("oldX") Double oldX,
-                                        final @MapsTo("oldY") Double oldY) {
+                                        final @MapsTo("location") Point2D location,
+                                        final @MapsTo("previousLocation") Point2D previousLocation) {
         this.uuid = PortablePreconditions.checkNotNull("uuid",
                                                        uuid);
-        this.x = PortablePreconditions.checkNotNull("x",
-                                                    x);
-        this.y = PortablePreconditions.checkNotNull("y",
-                                                    y);
-        this.oldX = PortablePreconditions.checkNotNull("oldX",
-                                                       oldX);
-        this.oldY = PortablePreconditions.checkNotNull("oldY",
-                                                       oldY);
+        this.location = PortablePreconditions.checkNotNull("location",
+                                                           location);
+        this.previousLocation = PortablePreconditions.checkNotNull("previousLocation",
+                                                                   previousLocation);
         this.node = null;
     }
 
     public UpdateElementPositionCommand(final Node<? extends View<?>, Edge> node,
-                                        final Double x,
-                                        final Double y) {
+                                        final Point2D location) {
         this(node.getUUID(),
-             x,
-             y,
-             GraphUtils.getPosition(node.getContent()).getX(),
-             GraphUtils.getPosition(node.getContent()).getY());
+             location,
+             GraphUtils.getPosition(node.getContent()));
         this.node = PortablePreconditions.checkNotNull("node",
                                                        node);
     }
 
-    public Double getX() {
-        return x;
+    public Point2D getLocation() {
+        return location;
     }
 
-    public Double getY() {
-        return y;
+    public Point2D getPreviousLocation() {
+        return previousLocation;
     }
 
     public Node<?, Edge> getNode() {
         return node;
     }
 
-    public Double getOldX() {
-        return oldX;
-    }
-
-    public Double getOldY() {
-        return oldY;
-    }
-
     public String getUuid() {
         return uuid;
     }
@@ -128,16 +109,20 @@ public final class UpdateElementPositionCommand extends AbstractGraphCommand {
     private CommandResult<RuleViolation> checkBounds(final GraphCommandExecutionContext context) {
         final Element<? extends View<?>> element = getNodeNotNull(context);
         final Graph<DefinitionSet, Node> graph = (Graph<DefinitionSet, Node>) getGraph(context);
+
         final BoundsImpl newBounds = getTargetBounds(element);
+
         final GraphCommandResultBuilder result = new GraphCommandResultBuilder();
-        if (checkBoundsExceeded(graph,
-                                newBounds)) {
+
+        final Bounds parentBounds = getParentBounds(element, graph);
+
+        if (GraphUtils.checkBoundsExceeded(parentBounds, newBounds)) {
             ((View) element.getContent()).setBounds(newBounds);
         } else {
-            final Bounds graphBounds = graph.getContent().getBounds();
-            result.addViolation(new BoundsExceededViolation(graphBounds)
+            result.addViolation(new BoundsExceededViolation(parentBounds)
                                         .setUUID(element.getUUID()));
         }
+
         return result.build();
     }
 
@@ -146,24 +131,28 @@ public final class UpdateElementPositionCommand extends AbstractGraphCommand {
         final double[] oldSize = GraphUtils.getNodeSize(element.getContent());
         final double w = oldSize[0];
         final double h = oldSize[1];
-        return new BoundsImpl(new BoundImpl(x,
-                                            y),
-                              new BoundImpl(x + w,
-                                            y + h));
+        return new BoundsImpl(new BoundImpl(location.getX(),
+                                            location.getY()),
+                              new BoundImpl(location.getX() + w,
+                                            location.getY() + h));
     }
 
     @SuppressWarnings("unchecked")
-    private boolean checkBoundsExceeded(final Graph<DefinitionSet, Node> graph,
-                                        final Bounds bounds) {
-        return GraphUtils.checkBoundsExceeded(graph,
-                                              bounds);
+    private Bounds getParentBounds(Element element, final Graph<DefinitionSet, Node> graph) {
+        final Element<? extends View<?>> parent = (Element<? extends View<?>>) GraphUtils.getParent((Node) element);
+
+        if (parent != null && !GraphUtils.isRootNode(parent, graph)) {
+            final double[] size = GraphUtils.getNodeSize(parent.getContent());
+            return new BoundsImpl(new BoundImpl(0d, 0d), new BoundImpl(size[0], size[1]));
+        } else {
+            return GraphUtils.getBounds(graph);
+        }
     }
 
     @Override
     public CommandResult<RuleViolation> undo(final GraphCommandExecutionContext context) {
         final UpdateElementPositionCommand undoCommand = new UpdateElementPositionCommand(getNodeNotNull(context),
-                                                                                          oldX,
-                                                                                          oldY);
+                                                                                          previousLocation);
         return undoCommand.execute(context);
     }
 
@@ -179,10 +168,8 @@ public final class UpdateElementPositionCommand extends AbstractGraphCommand {
     public String toString() {
         return "UpdateElementPositionCommand " +
                 "[element=" + uuid +
-                ", x=" + x +
-                ", y=" + y +
-                ", oldX=" + oldX +
-                ", oldY=" + oldY +
+                ", location=" + location +
+                ", previousLocation=" + previousLocation +
                 "]";
     }
 }
