@@ -25,6 +25,7 @@ import java.util.Optional;
 import java.util.Set;
 import java.util.logging.Level;
 import java.util.logging.Logger;
+
 import javax.enterprise.context.ApplicationScoped;
 import javax.inject.Inject;
 
@@ -39,11 +40,9 @@ import org.kie.workbench.common.stunner.core.graph.util.GraphUtils;
 import org.kie.workbench.common.stunner.core.lookup.LookupManager;
 import org.kie.workbench.common.stunner.core.lookup.definition.DefinitionLookupManager;
 import org.kie.workbench.common.stunner.core.lookup.definition.DefinitionLookupRequest;
-import org.kie.workbench.common.stunner.core.lookup.definition.DefinitionLookupRequestImpl;
 import org.kie.workbench.common.stunner.core.lookup.definition.DefinitionRepresentation;
 import org.kie.workbench.common.stunner.core.lookup.rule.RuleLookupManager;
 import org.kie.workbench.common.stunner.core.lookup.rule.RuleLookupRequest;
-import org.kie.workbench.common.stunner.core.lookup.rule.RuleLookupRequestImpl;
 import org.kie.workbench.common.stunner.core.rule.Rule;
 import org.kie.workbench.common.stunner.core.rule.RuleManager;
 import org.kie.workbench.common.stunner.core.rule.RuleSet;
@@ -55,7 +54,7 @@ import org.kie.workbench.common.stunner.core.rule.context.impl.RuleContextBuilde
 import org.kie.workbench.common.stunner.core.rule.impl.CanConnect;
 import org.kie.workbench.common.stunner.core.util.DefinitionUtils;
 
-import static org.uberfire.commons.validation.PortablePreconditions.checkNotNull;
+import static org.kie.soup.commons.validation.PortablePreconditions.checkNotNull;
 
 /**
  * An utils class that provides common used look-ups and other logic for querying the domain model and the rules model,
@@ -311,7 +310,7 @@ public class CommonLookups {
                                        final Set<String> labels) {
         if (null != labels && !labels.isEmpty()) {
             final DefinitionLookupRequest request =
-                    new DefinitionLookupRequestImpl.Builder()
+                    new DefinitionLookupRequest.Builder()
                             .definitionSetId(defSetId)
                             .labels(labels)
                             .page(0)
@@ -399,9 +398,9 @@ public class CommonLookups {
                                                  final int pageSize) {
         if (null != defSetId) {
             final Set<String> defLabels = getDefinitionLabels(sourceDefinition);
-            final RuleLookupRequestImpl.Builder builder = new RuleLookupRequestImpl.Builder();
+            final RuleLookupRequest.Builder builder = new RuleLookupRequest.Builder();
             builder.definitionSetId(defSetId)
-                    .type(RuleLookupRequestImpl.Builder.RuleType.CONNECTION)
+                    .type(RuleLookupRequest.Builder.RuleType.CONNECTION)
                     .from(defLabels)
                     .page(page)
                     .pageSize(pageSize);
