@@ -53,10 +53,12 @@ import org.kie.workbench.common.stunner.core.util.DefinitionUtils;
 import org.mockito.Mock;
 import org.mockito.MockitoAnnotations;
 
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertNotEquals;
 import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.eq;
-import static org.mockito.Mockito.*;
+import static org.mockito.Mockito.anyDouble;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.when;
 
 /**
  * An utility class for testing scope that provides
@@ -198,6 +200,7 @@ public class TestingGraphMockHandler {
                                                                         definition);
         execute(commandFactory.addNode(result));
         when(graphIndex.getNode(eq(uuid))).thenReturn(result);
+        when(graphIndex.get(eq(uuid))).thenReturn(result);
         return result;
     }
 
@@ -206,9 +209,14 @@ public class TestingGraphMockHandler {
                         final Optional<Set<String>> labels) {
         final Object definition = newDef(id,
                                          labels);
+        return newEdge(uuid, definition);
+    }
+
+    private Edge newEdge(String uuid, Object definition) {
         final Edge<Definition<Object>, Node> edge = edgeFactory.build(uuid,
                                                                       definition);
         when(graphIndex.getEdge(eq(uuid))).thenReturn(edge);
+        when(graphIndex.get(eq(uuid))).thenReturn(edge);
         return edge;
     }
 
@@ -218,10 +226,9 @@ public class TestingGraphMockHandler {
                 def.get() :
                 newDef("def-" + uuid,
                        Optional.empty());
-        final Edge<Definition<Object>, Node> edge = edgeFactory.build(uuid,
-                                                                      definition);
-        when(graphIndex.getEdge(eq(uuid))).thenReturn(edge);
-        return edge;
+
+
+        return newEdge(uuid, definition);
     }
 
     @SuppressWarnings("unchecked")
