@@ -38,6 +38,6 @@ public class FormPropertiesWidgetViewImpl implements FormPropertiesWidgetView,
     public void init(Presenter presenter) {
         this.presenter = presenter;
         DOMUtil.removeAllChildren(formContent);
-        DOMUtil.appendWidgetToElement(formContent, presenter.getRenderer());
+        formContent.appendChild(presenter.getDisplayerElement());
     }
 }
