@@ -1,25 +1,26 @@
 /*
- * Copyright 2016 Red Hat, Inc. and/or its affiliates.
+ * Copyright 2017 Red Hat, Inc. and/or its affiliates.
+ *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- *  
- *     http://www.apache.org/licenses/LICENSE-2.0
- *  
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.kie.workbench.common.stunner.project.diagram;
 
+import org.guvnor.common.services.project.model.Package;
 import org.kie.workbench.common.stunner.core.diagram.Metadata;
 
 public interface ProjectMetadata extends Metadata {
 
-    String getProjectPackage();
+    String getModuleName();
 
-    String getProjectName();
+    Package getProjectPackage();
 }
