@@ -16,7 +16,10 @@
 
 package org.kie.workbench.common.stunner.project.client.editor;
 
+import java.util.function.Consumer;
+
 import com.google.gwtmockito.GwtMockitoTestRunner;
+import com.google.gwtmockito.WithClassesToStub;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
@@ -24,12 +27,14 @@ import org.kie.workbench.common.stunner.client.widgets.presenters.session.Sessio
 import org.kie.workbench.common.stunner.client.widgets.presenters.session.SessionPresenterFactory;
 import org.kie.workbench.common.stunner.core.client.api.AbstractClientSessionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
+import org.kie.workbench.common.stunner.core.client.error.DiagramClientErrorHandler;
+import org.kie.workbench.common.stunner.core.client.i18n.ClientTranslationService;
+import org.kie.workbench.common.stunner.core.client.service.ClientRuntimeError;
 import org.kie.workbench.common.stunner.core.client.service.ServiceCallback;
 import org.kie.workbench.common.stunner.core.client.session.ClientFullSession;
 import org.kie.workbench.common.stunner.core.client.session.ClientSessionFactory;
 import org.kie.workbench.common.stunner.core.client.session.command.ClientSessionCommand;
 import org.kie.workbench.common.stunner.core.client.session.command.impl.ClearSessionCommand;
-import org.kie.workbench.common.stunner.core.client.session.command.impl.ClearStatesSessionCommand;
 import org.kie.workbench.common.stunner.core.client.session.command.impl.DeleteSelectionSessionCommand;
 import org.kie.workbench.common.stunner.core.client.session.command.impl.RedoSessionCommand;
 import org.kie.workbench.common.stunner.core.client.session.command.impl.SessionCommandFactory;
@@ -40,6 +45,7 @@ import org.kie.workbench.common.stunner.core.client.session.command.impl.VisitGr
 import org.kie.workbench.common.stunner.core.client.session.impl.AbstractClientFullSession;
 import org.kie.workbench.common.stunner.core.client.session.impl.AbstractClientReadOnlySession;
 import org.kie.workbench.common.stunner.core.client.session.impl.ClientFullSessionImpl;
+import org.kie.workbench.common.stunner.core.definition.exception.DefinitionNotFoundException;
 import org.kie.workbench.common.stunner.core.diagram.Diagram;
 import org.kie.workbench.common.stunner.project.client.editor.event.OnDiagramFocusEvent;
 import org.kie.workbench.common.stunner.project.client.editor.event.OnDiagramLoseFocusEvent;
@@ -48,8 +54,8 @@ import org.kie.workbench.common.stunner.project.client.service.ClientProjectDiag
 import org.kie.workbench.common.stunner.project.diagram.ProjectDiagram;
 import org.kie.workbench.common.stunner.project.diagram.ProjectMetadata;
 import org.kie.workbench.common.widgets.metadata.client.widget.OverviewWidgetPresenter;
+import org.mockito.ArgumentCaptor;
 import org.mockito.Mock;
-import org.mockito.Mockito;
 import org.uberfire.backend.vfs.ObservablePath;
 import org.uberfire.client.mvp.PlaceManager;
 import org.uberfire.client.workbench.events.ChangeTitleWidgetEvent;
@@ -59,100 +65,101 @@ import org.uberfire.client.workbench.type.ClientResourceType;
 import org.uberfire.client.workbench.widgets.common.ErrorPopupPresenter;
 import org.uberfire.ext.editor.commons.client.file.popups.SavePopUpPresenter;
 import org.uberfire.ext.editor.commons.client.history.VersionRecordManager;
-import org.uberfire.ext.editor.commons.client.menu.BasicFileMenuBuilder;
-import org.uberfire.ext.editor.commons.client.validation.DefaultFileNameValidator;
 import org.uberfire.mocks.EventSourceMock;
 import org.uberfire.mvp.PlaceRequest;
-import org.uberfire.workbench.events.NotificationEvent;
+import org.uberfire.mvp.impl.PathPlaceRequest;
 
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertTrue;
+import static org.mockito.ArgumentCaptor.forClass;
+import static org.mockito.Matchers.any;
+import static org.mockito.Matchers.anyBoolean;
 import static org.mockito.Matchers.eq;
-import static org.mockito.Mockito.*;
+import static org.mockito.Mockito.doAnswer;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.never;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(GwtMockitoTestRunner.class)
+@WithClassesToStub(PathPlaceRequest.class)
 public class ProjectDiagramEditorTest {
 
     @Mock
-    EventSourceMock<ChangeTitleWidgetEvent> changeTitleNotification;
+    private VersionRecordManager versionRecordManager;
     @Mock
-    EventSourceMock<NotificationEvent> notification;
+    private PlaceRequest placeRequest;
     @Mock
-    VersionRecordManager versionRecordManager;
+    private AbstractProjectDiagramEditor.View view;
     @Mock
-    BasicFileMenuBuilder menuBuilder;
+    private PlaceManager placeManager;
     @Mock
-    DefaultFileNameValidator fileNameValidator;
+    private ErrorPopupPresenter errorPopupPresenter;
     @Mock
-    PlaceRequest placeRequest;
+    private EventSourceMock<ChangeTitleWidgetEvent> changeTitleNotificationEvent;
     @Mock
-    AbstractProjectDiagramEditor.View view;
+    private SavePopUpPresenter savePopUpPresenter;
     @Mock
-    PlaceManager placeManager;
+    private ClientResourceType resourceType;
     @Mock
-    ErrorPopupPresenter errorPopupPresenter;
+    private ClientProjectDiagramService projectDiagramServices;
     @Mock
-    EventSourceMock<ChangeTitleWidgetEvent> changeTitleNotificationEvent;
+    private AbstractClientSessionManager clientSessionManager;
     @Mock
-    SavePopUpPresenter savePopUpPresenter;
+    private SessionPresenterFactory<Diagram, AbstractClientReadOnlySession, AbstractClientFullSession> presenterFactory;
     @Mock
-    ClientResourceType resourceType;
+    private SessionPresenter presenter;
     @Mock
-    ClientProjectDiagramService projectDiagramServices;
+    private SessionCommandFactory sessionCommandFactory;
     @Mock
-    AbstractClientSessionManager clientSessionManager;
+    private ProjectDiagramEditorMenuItemsBuilder menuItemsBuilder;
     @Mock
-    SessionPresenterFactory<Diagram, AbstractClientReadOnlySession, AbstractClientFullSession> presenterFactory;
+    private VisitGraphSessionCommand sessionVisitGraphCommand;
     @Mock
-    SessionPresenter presenter;
+    private SwitchGridSessionCommand sessionSwitchGridCommand;
     @Mock
-    SessionCommandFactory sessionCommandFactory;
+    private ClearSessionCommand sessionClearCommand;
     @Mock
-    ProjectDiagramEditorMenuItemsBuilder menuItemsBuilder;
+    private DeleteSelectionSessionCommand sessionDeleteSelectionCommand;
     @Mock
-    ClearStatesSessionCommand sessionClearStatesCommand;
+    private UndoSessionCommand sessionUndoCommand;
     @Mock
-    VisitGraphSessionCommand sessionVisitGraphCommand;
+    private RedoSessionCommand sessionRedoCommand;
     @Mock
-    SwitchGridSessionCommand sessionSwitchGridCommand;
+    private ValidateSessionCommand sessionValidateCommand;
     @Mock
-    ClearSessionCommand sessionClearCommand;
+    private ClientFullSessionImpl fullSession;
     @Mock
-    DeleteSelectionSessionCommand sessionDeleteSelectionCommand;
+    private ObservablePath path;
     @Mock
-    UndoSessionCommand sessionUndoCommand;
+    private ProjectDiagram diagram;
     @Mock
-    RedoSessionCommand sessionRedoCommand;
+    private ProjectMetadata metadata;
     @Mock
-    ValidateSessionCommand sessionValidateCommand;
+    private  OverviewWidgetPresenter overviewWidgetMock;
     @Mock
-    ClientFullSessionImpl fullSession;
+    private ClientSessionFactory<ClientFullSession> clientSessionFactory;
     @Mock
-    ObservablePath path;
+    private AbstractCanvasHandler canvasHandler;
     @Mock
-    ProjectDiagram diagram;
+    private EventSourceMock<OnDiagramFocusEvent> onDiagramFocusEvent;
     @Mock
-    ProjectMetadata metadata;
+    private EventSourceMock<OnDiagramLoseFocusEvent> onDiagramLostFocusEven;
     @Mock
-    OverviewWidgetPresenter overviewWidgetMock;
+    private ProjectMessagesListener projectMessagesListener;
     @Mock
-    ClientSessionFactory<ClientFullSession> clientSessionFactory;
+    private DiagramClientErrorHandler diagramClientErrorHandler;
     @Mock
-    AbstractCanvasHandler canvasHandler;
-    @Mock
-    EventSourceMock<OnDiagramFocusEvent> onDiagramFocusEvent;
-    @Mock
-    EventSourceMock<OnDiagramLoseFocusEvent> onDiagramLostFocusEven;
-    @Mock
-    ProjectMessagesListener projectMessagesListener;
+    private ClientTranslationService translationService;
 
     private ProjectDiagramEditorStub tested;
 
     @Before
-    public void setup() throws Exception {
+    public void setup() {
         VersionRecordManager versionRecordManagerMock = versionRecordManager;
         when(versionRecordManager.getCurrentPath()).thenReturn(path);
         when(sessionCommandFactory.newClearCommand()).thenReturn(sessionClearCommand);
-        when(sessionCommandFactory.newClearStatesCommand()).thenReturn(sessionClearStatesCommand);
         when(sessionCommandFactory.newVisitGraphCommand()).thenReturn(sessionVisitGraphCommand);
         when(sessionCommandFactory.newSwitchGridCommand()).thenReturn(sessionSwitchGridCommand);
         when(sessionCommandFactory.newDeleteSelectedElementsCommand()).thenReturn(sessionDeleteSelectionCommand);
@@ -161,9 +168,15 @@ public class ProjectDiagramEditorTest {
         when(sessionCommandFactory.newValidateCommand()).thenReturn(sessionValidateCommand);
         when(presenterFactory.newPresenterEditor()).thenReturn(presenter);
         when(clientSessionManager.getCurrentSession()).thenReturn(fullSession);
-        when(clientSessionManager.getSessionFactory(diagram,
+        when(clientSessionManager.getSessionFactory(metadata,
                                                     ClientFullSession.class)).thenReturn(clientSessionFactory);
-        when(clientSessionFactory.newSession()).thenReturn((fullSession));
+        doAnswer(invocationOnMock -> {
+            final Consumer<ClientFullSessionImpl> sessionConsumer =
+                    (Consumer<ClientFullSessionImpl>) invocationOnMock.getArguments()[1];
+            sessionConsumer.accept(fullSession);
+            return null;
+        }).when(clientSessionFactory).newSession(eq(metadata),
+                                                     any(Consumer.class));
         when(presenter.getInstance()).thenReturn(fullSession);
         when(presenter.withToolbar(anyBoolean())).thenReturn(presenter);
         when(presenter.withPalette(anyBoolean())).thenReturn(presenter);
@@ -175,8 +188,6 @@ public class ProjectDiagramEditorTest {
 
         when(placeRequest.getIdentifier()).thenReturn(ProjectDiagramEditorStub.EDITOR_ID);
 
-        ClientProjectDiagramService mock = Mockito.mock(ClientProjectDiagramService.class);
-
         this.tested = new ProjectDiagramEditorStub(view,
                                                    placeManager,
                                                    errorPopupPresenter,
@@ -190,7 +201,9 @@ public class ProjectDiagramEditorTest {
                                                    menuItemsBuilder,
                                                    onDiagramFocusEvent,
                                                    onDiagramLostFocusEven,
-                                                   projectMessagesListener
+                                                   projectMessagesListener,
+                                                   diagramClientErrorHandler,
+                                                   translationService
         ) {
             {
                 overviewWidget = overviewWidgetMock;
@@ -198,16 +211,14 @@ public class ProjectDiagramEditorTest {
                 place = placeRequest;
             }
         };
+        tested.init();
     }
 
     @Test
     @SuppressWarnings("unchecked")
     public void testInit() {
-        tested.init();
         verify(view,
                times(1)).init(eq(tested));
-        verify(sessionClearStatesCommand,
-               times(0)).bind(eq(fullSession));
         verify(sessionVisitGraphCommand,
                times(0)).bind(eq(fullSession));
         verify(sessionSwitchGridCommand,
@@ -241,6 +252,30 @@ public class ProjectDiagramEditorTest {
                                    any(ServiceCallback.class));
     }
 
+    @Test
+    public void testLoadContentError() {
+        ArgumentCaptor<ServiceCallback> callbackArgumentCaptor = forClass(ServiceCallback.class);
+
+        tested.loadContent();
+
+        verify(projectDiagramServices,
+               times(1)).getByPath(eq(path),
+                                   callbackArgumentCaptor.capture());
+
+        callbackArgumentCaptor.getValue().onError(new ClientRuntimeError(new DefinitionNotFoundException()));
+
+        verify(placeManager,
+               times(1)).forceClosePlace(any(PathPlaceRequest.class));
+
+        ArgumentCaptor<Consumer> consumerArgumentCaptor = forClass(Consumer.class);
+        verify(diagramClientErrorHandler,
+               times(1)).handleError(any(ClientRuntimeError.class),
+                                     consumerArgumentCaptor.capture());
+        consumerArgumentCaptor.getValue().accept("error message");
+        verify(errorPopupPresenter,
+               times(1)).showMessage("error message");
+    }
+
     @Test
     public void testIsDirty() {
         tested.init();
