@@ -17,11 +17,12 @@
 package org.kie.workbench.common.stunner.bpmn.definition;
 
 import java.util.HashSet;
+import java.util.Objects;
 import java.util.Set;
+
 import javax.validation.Valid;
 
 import org.jboss.errai.common.client.api.annotations.MapsTo;
-import org.jboss.errai.common.client.api.annotations.NonPortable;
 import org.kie.workbench.common.forms.adf.definitions.annotations.FormField;
 import org.kie.workbench.common.stunner.bpmn.definition.property.background.BackgroundSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.CircleDimensionSet;
@@ -31,14 +32,13 @@ import org.kie.workbench.common.stunner.core.definition.annotation.PropertySet;
 import org.kie.workbench.common.stunner.core.definition.annotation.definition.Category;
 import org.kie.workbench.common.stunner.core.definition.annotation.definition.Labels;
 import org.kie.workbench.common.stunner.core.definition.annotation.morph.MorphBase;
-import org.kie.workbench.common.stunner.core.definition.builder.Builder;
 import org.kie.workbench.common.stunner.core.util.HashUtil;
 
 @MorphBase(defaultType = ParallelGateway.class)
-public abstract class BaseGateway implements BPMNDefinition {
+public abstract class BaseGateway implements BPMNViewDefinition {
 
     @Category
-    public static final transient String category = Categories.GATEWAYS;
+    public static final transient String category = BPMNCategories.GATEWAYS;
 
     @PropertySet
     @FormField
@@ -67,16 +67,6 @@ public abstract class BaseGateway implements BPMNDefinition {
         add("cm_nop");
     }};
 
-    @NonPortable
-    static abstract class BaseGatewayBuilder<T extends BaseGateway> implements Builder<T> {
-
-        public static final transient String COLOR = "#f2ea9e";
-        public static final transient String ICON_COLOR = "#ae8104";
-        public static final transient String BORDER_COLOR = "#000000";
-        public static final Double BORDER_SIZE = 1d;
-        public static final Double RADIUS = 20d;
-    }
-
     public BaseGateway() {
     }
 
@@ -132,20 +122,27 @@ public abstract class BaseGateway implements BPMNDefinition {
 
     @Override
     public int hashCode() {
-        return HashUtil.combineHashCodes(general.hashCode(),
-                                         backgroundSet.hashCode(),
-                                         fontSet.hashCode(),
-                                         dimensionsSet.hashCode());
+        return HashUtil.combineHashCodes(Objects.hashCode(general),
+                                         Objects.hashCode(backgroundSet),
+                                         Objects.hashCode(fontSet),
+                                         Objects.hashCode(dimensionsSet),
+                                         Objects.hashCode(labels));
     }
 
     @Override
     public boolean equals(Object o) {
         if (o instanceof BaseGateway) {
             BaseGateway other = (BaseGateway) o;
-            return general.equals(other.general) &&
-                    backgroundSet.equals(other.backgroundSet) &&
-                    fontSet.equals(other.fontSet) &&
-                    dimensionsSet.equals(other.dimensionsSet);
+            return Objects.equals(general,
+                                  other.general) &&
+                    Objects.equals(backgroundSet,
+                                   other.backgroundSet) &&
+                    Objects.equals(fontSet,
+                                   other.fontSet) &&
+                    Objects.equals(dimensionsSet,
+                                   other.dimensionsSet) &&
+                    Objects.equals(labels,
+                                   other.labels);
         }
         return false;
     }
