@@ -17,20 +17,23 @@
 package org.kie.workbench.common.stunner.bpmn.backend.marshall.json.builder;
 
 import java.io.IOException;
+import java.io.InputStream;
 import java.math.BigDecimal;
 import java.math.BigInteger;
 import java.util.Collection;
 import java.util.LinkedList;
 import java.util.Stack;
 
-import org.codehaus.jackson.Base64Variant;
-import org.codehaus.jackson.JsonGenerationException;
-import org.codehaus.jackson.JsonGenerator;
-import org.codehaus.jackson.JsonNode;
-import org.codehaus.jackson.JsonParser;
-import org.codehaus.jackson.JsonProcessingException;
-import org.codehaus.jackson.JsonStreamContext;
-import org.codehaus.jackson.ObjectCodec;
+import com.fasterxml.jackson.core.Base64Variant;
+import com.fasterxml.jackson.core.JsonGenerationException;
+import com.fasterxml.jackson.core.JsonGenerator;
+import com.fasterxml.jackson.core.JsonParser;
+import com.fasterxml.jackson.core.JsonProcessingException;
+import com.fasterxml.jackson.core.JsonStreamContext;
+import com.fasterxml.jackson.core.ObjectCodec;
+import com.fasterxml.jackson.core.SerializableString;
+import com.fasterxml.jackson.core.TreeNode;
+import com.fasterxml.jackson.core.Version;
 import org.kie.workbench.common.stunner.bpmn.backend.marshall.json.oryx.OryxManager;
 import org.kie.workbench.common.stunner.bpmn.definition.BPMNDefinition;
 import org.kie.workbench.common.stunner.bpmn.definition.BPMNDiagram;
@@ -140,8 +143,11 @@ public class BPMNGraphGenerator extends JsonGenerator {
     @SuppressWarnings("unchecked")
     public void close() throws IOException {
         logBuilders();
-        this.graph = (Graph<DefinitionSet, Node>) factoryManager.newElement(UUID.uuid(),
-                                                                            diagramDefinitionSetClass);
+    }
+
+    public Graph<DefinitionSet, Node> createGraph() {
+        Graph<DefinitionSet, Node> graph = (Graph<DefinitionSet, Node>) factoryManager.newElement(UUID.uuid(),
+                                                                                                  diagramDefinitionSetClass);
         // TODO: Where are the BPMN diagram bounds in the Oryx json structure? Exist?
         if (null == graph.getContent().getBounds()) {
             graph.getContent().setBounds(new BoundsImpl(
@@ -163,7 +169,10 @@ public class BPMNGraphGenerator extends JsonGenerator {
         }
         Node<View<BPMNDefinition>, Edge> diagramNode = (Node<View<BPMNDefinition>, Edge>) diagramBuilder.build(builderContext);
         graph.addNode(diagramNode);
-        this.isClosed = true;
+
+        logBuilders();
+
+        return graph;
     }
 
     @SuppressWarnings("unchecked")
@@ -184,11 +193,6 @@ public class BPMNGraphGenerator extends JsonGenerator {
         return null;
     }
 
-    public Graph<DefinitionSet, Node> getGraph() {
-        assert isClosed();
-        return this.graph;
-    }
-
     final GraphObjectBuilder.BuilderContext builderContext = new GraphObjectBuilder.BuilderContext() {
 
         Graph<DefinitionSet, Node> graph;
@@ -244,7 +248,7 @@ public class BPMNGraphGenerator extends JsonGenerator {
 
     // For local testing...
     private void logBuilders() {
-        log("Logging builders at close time...");
+        log("Logging builders at creation time...");
         for (GraphObjectBuilder<?, ?> builder : builders) {
             log(builder.toString());
         }
@@ -687,13 +691,6 @@ public class BPMNGraphGenerator extends JsonGenerator {
                               int i1) throws IOException, JsonGenerationException {
     }
 
-    @Override
-    public void writeBinary(final Base64Variant base64Variant,
-                            final byte[] bytes,
-                            final int i,
-                            final int i1) throws IOException, JsonGenerationException {
-    }
-
     @Override
     public void writeNumber(final int i) throws IOException, JsonGenerationException {
     }
@@ -731,7 +728,7 @@ public class BPMNGraphGenerator extends JsonGenerator {
     }
 
     @Override
-    public void writeTree(final JsonNode jsonNode) throws IOException, JsonProcessingException {
+    public void writeTree(final TreeNode treeNode) throws IOException, JsonProcessingException {
     }
 
     @Override
@@ -746,4 +743,47 @@ public class BPMNGraphGenerator extends JsonGenerator {
     public JsonStreamContext getOutputContext() {
         return null;
     }
+
+    @Override
+    public Version version() {
+        // TODO Auto-generated method stub
+        return null;
+    }
+
+    @Override
+    public int getFeatureMask() {
+        // TODO Auto-generated method stub
+        return 0;
+    }
+
+    @Override
+    public JsonGenerator setFeatureMask(int values) {
+        // TODO Auto-generated method stub
+        return null;
+    }
+
+    @Override
+    public void writeFieldName(SerializableString name) throws IOException {
+        // TODO Auto-generated method stub
+
+    }
+
+    @Override
+    public void writeString(SerializableString text) throws IOException {
+        // TODO Auto-generated method stub
+
+    }
+
+    @Override
+    public void writeBinary(Base64Variant bv, byte[] data, int offset, int len) throws IOException {
+        // TODO Auto-generated method stub
+
+    }
+
+    @Override
+    public int writeBinary(Base64Variant bv, InputStream data, int dataLength) throws IOException {
+        // TODO Auto-generated method stub
+        return 0;
+    }
 }
+
