@@ -22,8 +22,11 @@ import java.util.Optional;
 
 import org.kie.workbench.common.stunner.bpmn.client.resources.BPMNSVGGlyphFactory;
 import org.kie.workbench.common.stunner.bpmn.client.resources.BPMNSVGViewFactory;
+import org.kie.workbench.common.stunner.bpmn.definition.AdHocSubprocess;
 import org.kie.workbench.common.stunner.bpmn.definition.BaseSubprocess;
 import org.kie.workbench.common.stunner.bpmn.definition.EmbeddedSubprocess;
+import org.kie.workbench.common.stunner.bpmn.definition.EventSubprocess;
+import org.kie.workbench.common.stunner.bpmn.definition.MultipleInstanceSubprocess;
 import org.kie.workbench.common.stunner.bpmn.definition.ReusableSubprocess;
 import org.kie.workbench.common.stunner.core.client.shape.SvgDataUriGlyph;
 import org.kie.workbench.common.stunner.core.client.shape.view.HasTitle;
@@ -34,19 +37,33 @@ import org.kie.workbench.common.stunner.svg.client.shape.factory.SVGShapeViewRes
 import org.kie.workbench.common.stunner.svg.client.shape.view.SVGShapeView;
 
 public class SubprocessShapeDef extends BaseDimensionedShapeDef
-        implements BPMNSvgShapeDef<BaseSubprocess>{
+        implements BPMNSvgShapeDef<BaseSubprocess> {
 
     public static final SVGShapeViewResources<BaseSubprocess, BPMNSVGViewFactory> VIEW_RESOURCES =
             new SVGShapeViewResources<BaseSubprocess, BPMNSVGViewFactory>()
                     .put(ReusableSubprocess.class, BPMNSVGViewFactory::reusableSubProcess)
-                    .put(EmbeddedSubprocess.class, BPMNSVGViewFactory::embeddedSubProcess);
+                    .put(EmbeddedSubprocess.class, BPMNSVGViewFactory::embeddedSubProcess)
+                    .put(EventSubprocess.class, BPMNSVGViewFactory::eventSubProcess)
+                    .put(AdHocSubprocess.class, BPMNSVGViewFactory::adHocSubProcess)
+                    .put(MultipleInstanceSubprocess.class, BPMNSVGViewFactory::multipleInstanceSubProcess);
 
     public static final Map<Class<? extends BaseSubprocess>, SvgDataUriGlyph> GLYPHS =
             new HashMap<Class<? extends BaseSubprocess>, SvgDataUriGlyph>() {{
                 put(ReusableSubprocess.class, BPMNSVGGlyphFactory.REUSABLE_SUBPROCESS_GLYPH);
-                put(EmbeddedSubprocess.class, BPMNSVGGlyphFactory.ADHOC_SUBPROCESS_GLYPH);
+                put(EmbeddedSubprocess.class, BPMNSVGGlyphFactory.EMBEDDED_SUBPROCESS_GLYPH);
+                put(EventSubprocess.class, BPMNSVGGlyphFactory.EVENT_SUBPROCESS_GLYPH);
+                put(AdHocSubprocess.class, BPMNSVGGlyphFactory.ADHOC_SUBPROCESS_GLYPH);
+                put(MultipleInstanceSubprocess.class, BPMNSVGGlyphFactory.MULTIPLE_INSTANCE_SUBPROCESS_GLYPH);
             }};
 
+    private static HasTitle.Position getSubprocessTextPosition(final BaseSubprocess bean) {
+        if ((bean instanceof EmbeddedSubprocess) || (bean instanceof MultipleInstanceSubprocess) || (bean instanceof EventSubprocess) || (bean instanceof AdHocSubprocess)) {
+            return HasTitle.Position.TOP;
+        } else {
+            return HasTitle.Position.CENTER;
+        }
+    }
+
     @Override
     public FontHandler<BaseSubprocess, SVGShapeView> newFontHandler() {
         return newFontHandlerBuilder()
@@ -59,9 +76,9 @@ public class SubprocessShapeDef extends BaseDimensionedShapeDef
         return newSizeHandlerBuilder()
                 .width(task -> task.getDimensionsSet().getWidth().getValue())
                 .height(task -> task.getDimensionsSet().getHeight().getValue())
-                .minWidth(task -> 25d)
+                .minWidth(task -> 50d)
                 .maxWidth(task -> 1200d)
-                .minHeight(task -> 25d)
+                .minHeight(task -> 50d)
                 .maxHeight(task -> 1200d)
                 .build();
     }
@@ -71,15 +88,13 @@ public class SubprocessShapeDef extends BaseDimensionedShapeDef
                                            final BaseSubprocess task) {
         return newViewInstance(Optional.ofNullable(task.getDimensionsSet().getWidth()),
                                Optional.ofNullable(task.getDimensionsSet().getHeight()),
-                               VIEW_RESOURCES.getResource(factory, task));
+                               VIEW_RESOURCES.getResource(factory,
+                                                          task));
     }
 
     @Override
-    public Glyph getGlyph(final Class<? extends BaseSubprocess> type) {
+    public Glyph getGlyph(final Class<? extends BaseSubprocess> type,
+                          final String defId) {
         return GLYPHS.get(type);
     }
-
-    private static HasTitle.Position getSubprocessTextPosition(final BaseSubprocess bean) {
-        return bean instanceof EmbeddedSubprocess ? HasTitle.Position.BOTTOM : HasTitle.Position.CENTER;
-    }
 }
