@@ -35,7 +35,9 @@ import org.kie.workbench.common.stunner.bpmn.definition.EndNoneEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.EndTerminateEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.SequenceFlow;
 import org.kie.workbench.common.stunner.bpmn.definition.StartNoneEvent;
+import org.kie.workbench.common.stunner.bpmn.definition.StartSignalEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.UserTask;
+import org.kie.workbench.common.stunner.bpmn.definition.property.general.BPMNGeneralSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.general.Name;
 import org.kie.workbench.common.stunner.bpmn.definition.property.general.TaskGeneralSet;
 import org.mockito.ArgumentCaptor;
@@ -44,8 +46,13 @@ import org.mockito.Mock;
 import org.powermock.core.classloader.annotations.PrepareForTest;
 import org.powermock.modules.junit4.PowerMockRunner;
 
-import static org.junit.Assert.*;
-import static org.mockito.Mockito.*;
+import static org.junit.Assert.assertEquals;
+import static org.mockito.Mockito.any;
+import static org.mockito.Mockito.anyBoolean;
+import static org.mockito.Mockito.anyString;
+import static org.mockito.Mockito.doCallRealMethod;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(PowerMockRunner.class)
 @PrepareForTest(StringUtils.class)
@@ -85,6 +92,9 @@ public class AssignmentsEditorWidgetTest extends AssignmentBaseTest {
     @Mock
     StartNoneEvent startNoneEvent;
 
+    @Mock
+    StartSignalEvent startSignalEvent;
+
     @Mock
     EndTerminateEvent endTerminateEvent;
 
@@ -150,6 +160,10 @@ public class AssignmentsEditorWidgetTest extends AssignmentBaseTest {
         doCallRealMethod().when(startNoneEvent).isSingleInputVar();
         doCallRealMethod().when(startNoneEvent).hasOutputVars();
         doCallRealMethod().when(startNoneEvent).isSingleOutputVar();
+        doCallRealMethod().when(startSignalEvent).hasInputVars();
+        doCallRealMethod().when(startSignalEvent).isSingleInputVar();
+        doCallRealMethod().when(startSignalEvent).hasOutputVars();
+        doCallRealMethod().when(startSignalEvent).isSingleOutputVar();
         doCallRealMethod().when(endTerminateEvent).hasInputVars();
         doCallRealMethod().when(endTerminateEvent).isSingleInputVar();
         doCallRealMethod().when(endTerminateEvent).hasOutputVars();
@@ -292,6 +306,29 @@ public class AssignmentsEditorWidgetTest extends AssignmentBaseTest {
     @Test
     public void testSetBPMNModelStartNoneEvent() {
         widget.setBPMNModel(startNoneEvent);
+        assertEquals(false,
+                     widget.hasInputVars);
+        assertEquals(false,
+                     widget.isSingleInputVar);
+        assertEquals(false,
+                     widget.hasOutputVars);
+        assertEquals(false,
+                     widget.isSingleOutputVar);
+
+        String assignmentsInfoString = widget.getVariableCountsString(null,
+                                                                      null,
+                                                                      DATA_OUTPUT,
+                                                                      null,
+                                                                      PROCESS_VARS,
+                                                                      ASSIGNMENTS_SINGLE_OUTPUT,
+                                                                      widget.getDisallowedPropertyNames());
+        assertEquals("",
+                     assignmentsInfoString);
+    }
+
+    @Test
+    public void testSetBPMNModelStartSignalEvent() {
+        widget.setBPMNModel(startSignalEvent);
         assertEquals(false,
                      widget.hasInputVars);
         assertEquals(false,
@@ -315,9 +352,9 @@ public class AssignmentsEditorWidgetTest extends AssignmentBaseTest {
     @Test
     public void testSetBPMNModelEndTerminateEvent() {
         widget.setBPMNModel(endTerminateEvent);
-        assertEquals(true,
+        assertEquals(false,
                      widget.hasInputVars);
-        assertEquals(true,
+        assertEquals(false,
                      widget.isSingleInputVar);
         assertEquals(false,
                      widget.hasOutputVars);
@@ -331,16 +368,16 @@ public class AssignmentsEditorWidgetTest extends AssignmentBaseTest {
                                                                       PROCESS_VARS,
                                                                       ASSIGNMENTS_SINGLE_OUTPUT,
                                                                       widget.getDisallowedPropertyNames());
-        assertEquals("1 Data_Input",
+        assertEquals("",
                      assignmentsInfoString);
     }
 
     @Test
     public void testSetBPMNModelEndNoneEvent() {
         widget.setBPMNModel(endNoneEvent);
-        assertEquals(true,
+        assertEquals(false,
                      widget.hasInputVars);
-        assertEquals(true,
+        assertEquals(false,
                      widget.isSingleInputVar);
         assertEquals(false,
                      widget.hasOutputVars);
@@ -354,7 +391,7 @@ public class AssignmentsEditorWidgetTest extends AssignmentBaseTest {
                                                                       PROCESS_VARS,
                                                                       ASSIGNMENTS_SINGLE_OUTPUT,
                                                                       widget.getDisallowedPropertyNames());
-        assertEquals("1 Data_Input",
+        assertEquals("",
                      assignmentsInfoString);
     }
 
