@@ -19,10 +19,12 @@ package org.kie.workbench.common.stunner.cm.client.session;
 import javax.enterprise.context.Dependent;
 import javax.inject.Inject;
 
+import org.jboss.errai.ioc.client.api.Disposer;
 import org.kie.workbench.common.stunner.cm.qualifiers.CaseManagementEditor;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvas;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.canvas.CanvasFactory;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.CanvasControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.pan.PanControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.select.SelectionControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.zoom.ZoomControl;
@@ -35,12 +37,14 @@ public class CaseManagementReadOnlySession extends AbstractClientReadOnlySession
 
     @Inject
     @SuppressWarnings("unchecked")
-    public CaseManagementReadOnlySession(final @CaseManagementEditor CanvasFactory<AbstractCanvas, AbstractCanvasHandler> factory) {
+    public CaseManagementReadOnlySession(final @CaseManagementEditor CanvasFactory<AbstractCanvas, AbstractCanvasHandler> factory,
+                                         final Disposer<CanvasControl> canvasControlDisposer) {
         super(factory.newCanvas(),
               factory.newCanvasHandler(),
               factory.newControl(SelectionControl.class),
               factory.newControl(ZoomControl.class),
-              factory.newControl(PanControl.class));
+              factory.newControl(PanControl.class),
+              canvasControlDisposer);
     }
 
     @Override
