@@ -18,20 +18,24 @@ package org.kie.workbench.common.stunner.standalone.backend;
 
 import java.util.HashMap;
 import java.util.Map;
+
 import javax.annotation.PostConstruct;
 import javax.enterprise.context.ApplicationScoped;
+import javax.enterprise.event.Event;
 import javax.enterprise.inject.Produces;
+import javax.inject.Inject;
 import javax.inject.Named;
 
 import org.apache.lucene.analysis.Analyzer;
 import org.kie.workbench.common.services.refactoring.backend.server.indexing.ImpactAnalysisAnalyzerWrapperFactory;
 import org.kie.workbench.common.services.refactoring.backend.server.indexing.LowerCaseOnlyAnalyzer;
+import org.kie.workbench.common.services.refactoring.model.index.terms.ModuleNameIndexTerm;
+import org.kie.workbench.common.services.refactoring.model.index.terms.ModuleRootPathIndexTerm;
 import org.kie.workbench.common.services.refactoring.model.index.terms.PackageNameIndexTerm;
-import org.kie.workbench.common.services.refactoring.model.index.terms.ProjectNameIndexTerm;
-import org.kie.workbench.common.services.refactoring.model.index.terms.ProjectRootPathIndexTerm;
-import org.uberfire.ext.metadata.backend.lucene.LuceneConfig;
-import org.uberfire.ext.metadata.backend.lucene.LuceneConfigBuilder;
+import org.uberfire.ext.metadata.MetadataConfig;
 import org.uberfire.ext.metadata.backend.lucene.analyzer.FilenameAnalyzer;
+import org.uberfire.ext.metadata.event.BatchIndexEvent;
+import org.uberfire.ext.metadata.io.MetadataConfigBuilder;
 
 /**
  * This class contains the default Lucene configuration, and can be
@@ -40,30 +44,34 @@ import org.uberfire.ext.metadata.backend.lucene.analyzer.FilenameAnalyzer;
 @ApplicationScoped
 public class DefaultLuceneConfigProducer {
 
-    private LuceneConfig config;
+    private MetadataConfig config;
+
+    @Inject
+    private Event<BatchIndexEvent> batchIndexEvent;
 
     @PostConstruct
     public void setup() {
         final Map<String, Analyzer> analyzers = getAnalyzers();
-        this.config = new LuceneConfigBuilder().withInMemoryMetaModelStore()
+        this.config = new MetadataConfigBuilder().withInMemoryMetaModelStore()
                 .usingAnalyzers(analyzers)
                 .usingAnalyzerWrapperFactory(ImpactAnalysisAnalyzerWrapperFactory.getInstance())
                 .useDirectoryBasedIndex()
                 .useNIODirectory()
+                .useCDIBatchIndexObserver(batchIndexEvent)
                 .build();
     }
 
     @Produces
     @Named("luceneConfig")
-    public LuceneConfig configProducer() {
+    public MetadataConfig configProducer() {
         return this.config;
     }
 
     private Map<String, Analyzer> getAnalyzers() {
         return new HashMap<String, Analyzer>() {{
-            put(ProjectRootPathIndexTerm.TERM,
+            put(ModuleRootPathIndexTerm.TERM,
                 new FilenameAnalyzer());
-            put(ProjectNameIndexTerm.TERM,
+            put(ModuleNameIndexTerm.TERM,
                 new LowerCaseOnlyAnalyzer());
             put(PackageNameIndexTerm.TERM,
                 new LowerCaseOnlyAnalyzer());
