@@ -19,6 +19,7 @@ package org.kie.workbench.common.stunner.standalone.client.screens;
 import java.util.Collection;
 import java.util.logging.Level;
 import java.util.logging.Logger;
+
 import javax.annotation.PostConstruct;
 import javax.enterprise.context.Dependent;
 import javax.enterprise.event.Event;
@@ -34,6 +35,7 @@ import org.kie.workbench.common.stunner.client.widgets.toolbar.impl.EditorToolba
 import org.kie.workbench.common.stunner.client.widgets.views.session.ScreenErrorView;
 import org.kie.workbench.common.stunner.client.widgets.views.session.ScreenPanelView;
 import org.kie.workbench.common.stunner.core.api.DefinitionManager;
+import org.kie.workbench.common.stunner.core.client.annotation.DiagramEditor;
 import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.CanvasHandler;
 import org.kie.workbench.common.stunner.core.client.service.ClientFactoryService;
@@ -54,12 +56,12 @@ import org.kie.workbench.common.stunner.core.util.UUID;
 import org.kie.workbench.common.stunner.core.validation.DiagramElementViolation;
 import org.kie.workbench.common.stunner.core.validation.Violation;
 import org.kie.workbench.common.stunner.core.validation.impl.ValidationUtils;
+import org.uberfire.backend.vfs.PathFactory;
 import org.uberfire.client.annotations.WorkbenchContextId;
 import org.uberfire.client.annotations.WorkbenchMenu;
 import org.uberfire.client.annotations.WorkbenchPartTitle;
 import org.uberfire.client.annotations.WorkbenchPartView;
 import org.uberfire.client.annotations.WorkbenchScreen;
-import org.uberfire.client.mvp.PlaceManager;
 import org.uberfire.client.workbench.events.ChangeTitleWidgetEvent;
 import org.uberfire.ext.widgets.common.client.common.BusyPopup;
 import org.uberfire.lifecycle.OnClose;
@@ -76,6 +78,7 @@ import static java.util.logging.Level.FINE;
 
 // TODO: i18n.
 @Dependent
+@DiagramEditor
 @WorkbenchScreen(identifier = SessionDiagramEditorScreen.SCREEN_ID)
 public class SessionDiagramEditorScreen {
 
@@ -88,7 +91,6 @@ public class SessionDiagramEditorScreen {
     private final ShowcaseDiagramService diagramService;
     private final SessionManager sessionManager;
     private final SessionPresenterFactory<Diagram, AbstractClientReadOnlySession, AbstractClientFullSession> sessionPresenterFactory;
-    private final PlaceManager placeManager;
     private final Event<ChangeTitleWidgetEvent> changeTitleNotificationEvent;
     private final MenuDevCommandsBuilder menuDevCommandsBuilder;
     private final ScreenPanelView screenPanelView;
@@ -105,7 +107,6 @@ public class SessionDiagramEditorScreen {
                                       final ShowcaseDiagramService diagramService,
                                       final SessionManager sessionManager,
                                       final SessionPresenterFactory<Diagram, AbstractClientReadOnlySession, AbstractClientFullSession> sessionPresenterFactory,
-                                      final PlaceManager placeManager,
                                       final Event<ChangeTitleWidgetEvent> changeTitleNotificationEvent,
                                       final MenuDevCommandsBuilder menuDevCommandsBuilder,
                                       final ScreenPanelView screenPanelView,
@@ -115,7 +116,6 @@ public class SessionDiagramEditorScreen {
         this.diagramService = diagramService;
         this.sessionManager = sessionManager;
         this.sessionPresenterFactory = sessionPresenterFactory;
-        this.placeManager = placeManager;
         this.changeTitleNotificationEvent = changeTitleNotificationEvent;
         this.menuDevCommandsBuilder = menuDevCommandsBuilder;
         this.screenPanelView = screenPanelView;
@@ -237,16 +237,8 @@ public class SessionDiagramEditorScreen {
                                                  final Metadata metadata = diagram.getMetadata();
                                                  metadata.setShapeSetId(shapeSetId);
                                                  metadata.setTitle(title);
-                                                 final AbstractClientFullSession session = newSession(diagram);
-                                                 presenter = sessionPresenterFactory.newPresenterEditor();
-                                                 screenPanelView.setWidget(presenter.getView());
-                                                 presenter
-                                                         .withToolbar(true)
-                                                         .withPalette(true)
-                                                         .displayNotifications(type -> true)
-                                                         .open(diagram,
-                                                               session,
-                                                               new ScreenPresenterCallback(callback));
+                                                 openDiagram(diagram,
+                                                             callback);
                                              }
 
                                              @Override
@@ -257,12 +249,33 @@ public class SessionDiagramEditorScreen {
                                          });
     }
 
+    private void openDiagram(Diagram diagram,
+                             Command callback) {
+        final Metadata metadata = diagram.getMetadata();
+        sessionManager.getSessionFactory(metadata,
+                                         ClientFullSession.class)
+                .newSession(metadata,
+                            s -> {
+                                final AbstractClientFullSession session = (AbstractClientFullSession) s;
+                                presenter = sessionPresenterFactory.newPresenterEditor();
+                                screenPanelView.setWidget(presenter.getView());
+                                presenter
+                                        .withToolbar(true)
+                                        .withPalette(true)
+                                        .displayNotifications(type -> true)
+                                        .open(diagram,
+                                              session,
+                                              new ScreenPresenterCallback(callback));
+                            });
+    }
+
     private Metadata buildMetadata(final String defSetId,
                                    final String shapeSetId,
                                    final String title) {
         return new MetadataImpl.MetadataImplBuilder(defSetId,
                                                     definitionManager)
                 .setTitle(title)
+                .setRoot(PathFactory.newPath(".", "default://master@stunner/"))
                 .setShapeSetId(shapeSetId)
                 .build();
     }
@@ -274,16 +287,8 @@ public class SessionDiagramEditorScreen {
                                   new ServiceCallback<Diagram>() {
                                       @Override
                                       public void onSuccess(final Diagram diagram) {
-                                          final AbstractClientFullSession session = newSession(diagram);
-                                          presenter = sessionPresenterFactory.newPresenterEditor();
-                                          screenPanelView.setWidget(presenter.getView());
-                                          presenter
-                                                  .withToolbar(true)
-                                                  .withPalette(true)
-                                                  .displayNotifications(type -> true)
-                                                  .open(diagram,
-                                                        session,
-                                                        new ScreenPresenterCallback(callback));
+                                          openDiagram(diagram,
+                                                      callback);
                                       }
 
                                       @Override
@@ -391,11 +396,6 @@ public class SessionDiagramEditorScreen {
                                                                      this.title));
     }
 
-    private AbstractClientFullSession newSession(final Diagram diagram) {
-        return (AbstractClientFullSession) sessionManager.getSessionFactory(diagram,
-                                                                            ClientFullSession.class).newSession();
-    }
-
     private AbstractClientFullSession getSession() {
         return null != presenter ? presenter.getInstance() : null;
     }
