@@ -16,22 +16,27 @@
 
 package org.kie.workbench.common.widgets.metadata.client;
 
+import java.util.Optional;
+import java.util.function.Supplier;
+
 import javax.enterprise.event.Observes;
 import javax.inject.Inject;
 
 import com.google.gwt.core.client.GWT;
 import com.google.gwt.user.client.ui.IsWidget;
+import org.guvnor.common.services.project.client.context.WorkspaceProjectContext;
 import org.guvnor.common.services.project.client.security.ProjectController;
-import org.guvnor.common.services.project.context.ProjectContext;
-import org.guvnor.common.services.project.model.Project;
 import org.guvnor.common.services.shared.metadata.model.Metadata;
 import org.guvnor.common.services.shared.metadata.model.Overview;
+import org.guvnor.messageconsole.client.console.widget.button.AlertsButtonMenuItemBuilder;
 import org.guvnor.structure.repositories.RepositoryRemovedEvent;
 import org.jboss.errai.bus.client.api.messaging.Message;
+import org.jboss.errai.common.client.api.Caller;
 import org.kie.workbench.common.widgets.client.callbacks.CommandBuilder;
 import org.kie.workbench.common.widgets.client.callbacks.CommandDrivenErrorCallback;
 import org.kie.workbench.common.widgets.client.menu.FileMenuBuilder;
 import org.kie.workbench.common.widgets.client.source.ViewDRLSourceWidget;
+import org.kie.workbench.common.widgets.metadata.client.validation.AssetUpdateValidator;
 import org.kie.workbench.common.widgets.metadata.client.widget.OverviewWidgetPresenter;
 import org.uberfire.backend.vfs.ObservablePath;
 import org.uberfire.client.workbench.type.ClientResourceType;
@@ -42,16 +47,21 @@ import org.uberfire.ext.editor.commons.client.file.popups.DeletePopUpPresenter;
 import org.uberfire.ext.editor.commons.client.file.popups.RenamePopUpPresenter;
 import org.uberfire.ext.editor.commons.client.file.popups.SavePopUpPresenter;
 import org.uberfire.ext.editor.commons.client.menu.MenuItems;
+import org.uberfire.ext.editor.commons.client.validation.ValidationErrorReason;
+import org.uberfire.ext.editor.commons.client.validation.Validator;
+import org.uberfire.ext.editor.commons.client.validation.ValidatorWithReasonCallback;
+import org.uberfire.ext.editor.commons.service.support.SupportsSaveAndRename;
+import org.uberfire.mvp.Command;
 import org.uberfire.mvp.PlaceRequest;
+import org.uberfire.workbench.events.NotificationEvent;
 import org.uberfire.workbench.model.menu.MenuItem;
 
-public abstract class KieEditor
-        extends BaseEditor
+public abstract class KieEditor<T>
+        extends BaseEditor<T, Metadata>
         implements KieEditorWrapperView.KieEditorWrapperPresenter {
 
     @Inject
     protected KieEditorWrapperView kieView;
-
     @Inject
     protected OverviewWidgetPresenter overviewWidget;
 
@@ -59,37 +69,47 @@ public abstract class KieEditor
     protected FileMenuBuilder fileMenuBuilder;
 
     @Inject
-    protected ProjectContext workbenchContext;
-
+    protected WorkspaceProjectContext workbenchContext;
     @Inject
     protected SavePopUpPresenter savePopUpPresenter;
-
     @Inject
     protected DeletePopUpPresenter deletePopUpPresenter;
-
     @Inject
     protected RenamePopUpPresenter renamePopUpPresenter;
-
     @Inject
     protected CopyPopUpPresenter copyPopUpPresenter;
 
     @Inject
     protected ProjectController projectController;
 
-    protected Metadata metadata;
+    @Inject
+    protected AssetUpdateValidator assetUpdateValidator;
 
+    @Inject
+    protected AlertsButtonMenuItemBuilder alertsButtonMenuItemBuilder;
+
+    protected Metadata metadata;
     private ViewDRLSourceWidget sourceWidget;
 
     //The default implementation delegates to the HashCode comparison in BaseEditor
-    private final MayCloseHandler DEFAULT_MAY_CLOSE_HANDLER = (object) -> {
-        if (object != null) {
-            return KieEditor.this.mayClose(object.hashCode());
-        } else {
-            return true;
+    private final MayCloseHandler DEFAULT_MAY_CLOSE_HANDLER = new MayCloseHandler() {
+
+        @Override
+        public boolean mayClose(final Object object) {
+            if (object != null) {
+                return KieEditor.this.mayClose(object.hashCode());
+            } else {
+                return true;
+            }
         }
     };
     //This implementation always permits closure as something went wrong loading the Editor's content
-    private final MayCloseHandler EXCEPTION_MAY_CLOSE_HANDLER = (object) -> true;
+    private final MayCloseHandler EXCEPTION_MAY_CLOSE_HANDLER = new MayCloseHandler() {
+        @Override
+        public boolean mayClose(final Object object) {
+            return true;
+        }
+    };
 
     private MayCloseHandler mayCloseHandler = DEFAULT_MAY_CLOSE_HANDLER;
 
@@ -214,7 +234,7 @@ public abstract class KieEditor
 
         this.overviewWidget.setContent(overview,
                                        versionRecordManager.getPathToLatest());
-        this.metadata = overview.getMetadata();
+        resetMetadata(overview);
 
         kieView.clear();
 
@@ -224,6 +244,15 @@ public abstract class KieEditor
                                 () -> overviewWidget.refresh(versionRecordManager.getVersion()));
     }
 
+    private void resetMetadata(final Overview overview) {
+
+        this.metadata = overview.getMetadata();
+
+        if (Optional.ofNullable(metadata).isPresent()) {
+            setMetadataOriginalHash(metadata.hashCode());
+        }
+    }
+
     protected void OnClose() {
         kieView.clear();
     }
@@ -238,23 +267,99 @@ public abstract class KieEditor
     @Override
     protected void makeMenuBar() {
         if (canUpdateProject()) {
-            fileMenuBuilder
-                    .addSave(versionRecordManager.newSaveMenuItem(this::onSave))
-                    .addCopy(versionRecordManager.getCurrentPath(),
-                             fileNameValidator)
-                    .addRename(versionRecordManager.getPathToLatest(),
-                               fileNameValidator)
-                    .addDelete(versionRecordManager.getPathToLatest());
+            addSave(fileMenuBuilder);
+            addCopy(fileMenuBuilder);
+            addRename(fileMenuBuilder);
+            addDelete(fileMenuBuilder);
         }
 
+        addCommonActions(fileMenuBuilder);
+    }
+
+    void addSave(final FileMenuBuilder fileMenuBuilder) {
+        fileMenuBuilder.addSave(versionRecordManager.newSaveMenuItem(getSaveActionCommand()));
+    }
+
+    void addCopy(final FileMenuBuilder fileMenuBuilder) {
+        fileMenuBuilder.addCopy(versionRecordManager.getCurrentPath(), assetUpdateValidator);
+    }
+
+    void addRename(final FileMenuBuilder fileMenuBuilder) {
+
+        final Optional<? extends Caller<? extends SupportsSaveAndRename<T, Metadata>>> saveAndRenameServiceCaller =
+                Optional.ofNullable(getSaveAndRenameServiceCaller());
+
+        if (saveAndRenameServiceCaller.isPresent()) {
+            fileMenuBuilder.addRename(getSaveAndRename());
+        } else {
+            fileMenuBuilder.addRename(versionRecordManager.getPathToLatest(), assetUpdateValidator);
+        }
+    }
+
+    void addDelete(final FileMenuBuilder fileMenuBuilder) {
+        fileMenuBuilder.addDelete(versionRecordManager.getPathToLatest(), assetUpdateValidator);
+    }
+
+    void addCommonActions(final FileMenuBuilder fileMenuBuilder) {
         fileMenuBuilder
                 .addValidate(onValidate())
-                .addNewTopLevelMenu(versionRecordManager.buildMenu());
+                .addNewTopLevelMenu(versionRecordManager.buildMenu())
+                .addNewTopLevelMenu(alertsButtonMenuItemBuilder.build());
+    }
+
+    Command getSaveActionCommand() {
+        return this::saveAction;
+    }
+
+    @Override
+    protected Supplier<Metadata> getMetadataSupplier() {
+        return () -> metadata;
+    }
+
+    @Override
+    public Validator getRenameValidator() {
+        return assetUpdateValidator;
+    }
+
+    protected void saveAction() {
+        assetUpdateValidator.validate(null,
+                                      new ValidatorWithReasonCallback() {
+                                          @Override
+                                          public void onFailure(final String reason) {
+                                              if (ValidationErrorReason.NOT_ALLOWED.name().equals(reason)) {
+                                                  showError(kieView.getNotAllowedSavingMessage());
+                                              } else {
+                                                  showError(kieView.getUnexpectedErrorWhileSavingMessage());
+                                              }
+                                          }
+
+                                          @Override
+                                          public void onSuccess() {
+                                              onSave();
+                                          }
+
+                                          @Override
+                                          public void onFailure() {
+                                              showError(kieView.getUnexpectedErrorWhileSavingMessage());
+                                          }
+                                      });
+    }
+
+    @Override
+    protected void onSave() {
+        super.onSave();
+    }
+
+    private void showError(final String error) {
+        notification.fire(new NotificationEvent(error,
+                                                NotificationEvent.NotificationType.ERROR));
     }
 
     protected boolean canUpdateProject() {
-        final Project activeProject = workbenchContext.getActiveProject();
-        return activeProject == null || projectController.canUpdateProject(activeProject);
+        return workbenchContext
+                .getActiveWorkspaceProject()
+                .map(activeProject -> projectController.canUpdateProject(activeProject))
+                .orElse(true);
     }
 
     @Override
@@ -297,20 +402,14 @@ public abstract class KieEditor
     }
 
     public void onRepositoryRemoved(final @Observes RepositoryRemovedEvent event) {
-        if (event.getRepository() == null) {
-            return;
-        }
-        if (workbenchContext == null) {
-            return;
-        }
-        if (workbenchContext.getActiveRepository() == null) {
-            return;
-        }
-        if (workbenchContext.getActiveRepository().equals(event.getRepository())) {
-            for (MenuItem mi : menus.getItemsMap().values()) {
-                mi.setEnabled(false);
-            }
-        }
+        Optional.ofNullable(workbenchContext)
+                .flatMap(context -> context.getActiveWorkspaceProject())
+                .filter(proj -> event.getRepository() != null && proj.getRepository().equals(event.getRepository()))
+                .ifPresent(proj -> {
+                    for (MenuItem mi : menus.getItemsMap().values()) {
+                        mi.setEnabled(false);
+                    }
+                });
     }
 
     @Override
