@@ -16,10 +16,16 @@
 
 package org.kie.workbench.common.widgets.metadata.client;
 
+import static org.uberfire.ext.widgets.common.client.common.ConcurrentChangePopup.newConcurrentDelete;
+import static org.uberfire.ext.widgets.common.client.common.ConcurrentChangePopup.newConcurrentRename;
+import static org.uberfire.ext.widgets.common.client.common.ConcurrentChangePopup.newConcurrentUpdate;
+
 import java.util.ArrayList;
 import java.util.HashSet;
 import java.util.List;
+import java.util.Optional;
 import java.util.Set;
+
 import javax.annotation.PostConstruct;
 import javax.enterprise.event.Event;
 import javax.enterprise.event.Observes;
@@ -27,14 +33,14 @@ import javax.inject.Inject;
 
 import com.google.gwt.core.client.GWT;
 import com.google.gwt.user.client.ui.IsWidget;
-import org.drools.workbench.models.datamodel.imports.Imports;
+import org.guvnor.common.services.project.client.context.WorkspaceProjectContext;
 import org.guvnor.common.services.project.client.security.ProjectController;
-import org.guvnor.common.services.project.context.ProjectContext;
-import org.guvnor.common.services.project.model.Project;
 import org.guvnor.common.services.shared.metadata.model.Overview;
 import org.guvnor.structure.repositories.RepositoryRemovedEvent;
 import org.jboss.errai.bus.client.api.messaging.Message;
 import org.jboss.errai.common.client.api.RemoteCallback;
+import org.kie.soup.commons.validation.PortablePreconditions;
+import org.kie.soup.project.datamodel.imports.Imports;
 import org.kie.workbench.common.widgets.client.callbacks.CommandBuilder;
 import org.kie.workbench.common.widgets.client.callbacks.CommandDrivenErrorCallback;
 import org.kie.workbench.common.widgets.client.datamodel.AsyncPackageDataModelOracle;
@@ -42,17 +48,19 @@ import org.kie.workbench.common.widgets.client.menu.FileMenuBuilder;
 import org.kie.workbench.common.widgets.client.source.ViewDRLSourceWidget;
 import org.kie.workbench.common.widgets.configresource.client.widget.bound.ImportsWidgetPresenter;
 import org.kie.workbench.common.widgets.metadata.client.menu.RegisteredDocumentsMenuBuilder;
+import org.kie.workbench.common.widgets.metadata.client.validation.AssetUpdateValidator;
 import org.kie.workbench.common.widgets.metadata.client.widget.OverviewWidgetPresenter;
 import org.uberfire.backend.vfs.ObservablePath;
 import org.uberfire.backend.vfs.Path;
 import org.uberfire.client.workbench.events.ChangeTitleWidgetEvent;
-import org.uberfire.commons.validation.PortablePreconditions;
 import org.uberfire.ext.editor.commons.client.BaseEditorView;
 import org.uberfire.ext.editor.commons.client.file.popups.SavePopUpPresenter;
 import org.uberfire.ext.editor.commons.client.history.VersionRecordManager;
 import org.uberfire.ext.editor.commons.client.menu.MenuItems;
 import org.uberfire.ext.editor.commons.client.resources.i18n.CommonConstants;
 import org.uberfire.ext.editor.commons.client.validation.DefaultFileNameValidator;
+import org.uberfire.ext.editor.commons.client.validation.ValidationErrorReason;
+import org.uberfire.ext.editor.commons.client.validation.ValidatorWithReasonCallback;
 import org.uberfire.ext.editor.commons.version.events.RestoreEvent;
 import org.uberfire.ext.widgets.common.client.common.ConcurrentChangePopup;
 import org.uberfire.mvp.Command;
@@ -62,10 +70,6 @@ import org.uberfire.workbench.events.NotificationEvent;
 import org.uberfire.workbench.model.menu.MenuItem;
 import org.uberfire.workbench.model.menu.Menus;
 
-import static org.uberfire.ext.widgets.common.client.common.ConcurrentChangePopup.newConcurrentDelete;
-import static org.uberfire.ext.widgets.common.client.common.ConcurrentChangePopup.newConcurrentRename;
-import static org.uberfire.ext.widgets.common.client.common.ConcurrentChangePopup.newConcurrentUpdate;
-
 /**
  * A base for Multi-Document-Interface editors. This base implementation adds default Menus for Save", "Copy",
  * "Rename", "Delete", "Validate" and "VersionRecordManager" drop-down that can be overriden by subclasses.
@@ -82,14 +86,16 @@ public abstract class KieMultipleDocumentEditor<D extends KieDocument> implement
     protected ImportsWidgetPresenter importsWidget;
     protected Event<NotificationEvent> notificationEvent;
     protected Event<ChangeTitleWidgetEvent> changeTitleEvent;
-    protected ProjectContext workbenchContext;
+    protected WorkspaceProjectContext workbenchContext;
     protected SavePopUpPresenter savePopUpPresenter;
 
     protected FileMenuBuilder fileMenuBuilder;
     protected VersionRecordManager versionRecordManager;
     protected RegisteredDocumentsMenuBuilder registeredDocumentsMenuBuilder;
     protected DefaultFileNameValidator fileNameValidator;
+    protected AssetUpdateValidator assetUpdateValidator;
     protected ProjectController projectController;
+    protected Event<NotificationEvent> notification;
 
     //Constructed
     protected BaseEditorView editorView;
@@ -101,7 +107,7 @@ public abstract class KieMultipleDocumentEditor<D extends KieDocument> implement
 
     protected Menus menus;
 
-    private D activeDocument = null;
+    protected D activeDocument = null;
     protected final Set<D> documents = new HashSet<>();
 
     //Handler for MayClose requests
@@ -119,7 +125,6 @@ public abstract class KieMultipleDocumentEditor<D extends KieDocument> implement
 
     private MayCloseHandler mayCloseHandler = DEFAULT_MAY_CLOSE_HANDLER;
 
-    @SuppressWarnings("unused")
     KieMultipleDocumentEditor() {
         //Zero-parameter constructor for CDI proxy
     }
@@ -166,7 +171,7 @@ public abstract class KieMultipleDocumentEditor<D extends KieDocument> implement
     }
 
     @Inject
-    protected void setWorkbenchContext(final ProjectContext workbenchContext) {
+    protected void setWorkbenchContext(final WorkspaceProjectContext workbenchContext) {
         this.workbenchContext = workbenchContext;
     }
 
@@ -194,11 +199,21 @@ public abstract class KieMultipleDocumentEditor<D extends KieDocument> implement
         this.fileNameValidator = fileNameValidator;
     }
 
+    @Inject
+    protected void setAssetUpdateValidator(final AssetUpdateValidator assetUpdateValidator) {
+        this.assetUpdateValidator = assetUpdateValidator;
+    }
+
     @Inject
     protected void setProjectController(final ProjectController projectController) {
         this.projectController = projectController;
     }
 
+    @Inject
+    protected void setNotification(final Event<NotificationEvent> notification) {
+        this.notification = notification;
+    }
+
     @Override
     public void registerDocument(final D document) {
         PortablePreconditions.checkNotNull("document",
@@ -465,10 +480,11 @@ public abstract class KieMultipleDocumentEditor<D extends KieDocument> implement
             fileMenuBuilder
                     .addSave(getSaveMenuItem())
                     .addCopy(() -> getActiveDocument().getCurrentPath(),
-                             fileNameValidator)
+                             assetUpdateValidator)
                     .addRename(() -> getActiveDocument().getLatestPath(),
-                               fileNameValidator)
-                    .addDelete(() -> getActiveDocument().getLatestPath());
+                               assetUpdateValidator)
+                    .addDelete(() -> getActiveDocument().getLatestPath(),
+                               assetUpdateValidator);
         }
 
         this.menus = fileMenuBuilder
@@ -479,8 +495,10 @@ public abstract class KieMultipleDocumentEditor<D extends KieDocument> implement
     }
 
     protected boolean canUpdateProject() {
-        final Project activeProject = workbenchContext.getActiveProject();
-        return activeProject == null || projectController.canUpdateProject(activeProject);
+        return workbenchContext
+                               .getActiveWorkspaceProject()
+                               .map(activeProject -> projectController.canUpdateProject(activeProject))
+                               .orElse(true);
     }
 
     /**
@@ -489,11 +507,40 @@ public abstract class KieMultipleDocumentEditor<D extends KieDocument> implement
      */
     protected MenuItem getSaveMenuItem() {
         if (saveMenuItem == null) {
-            saveMenuItem = versionRecordManager.newSaveMenuItem(this::doSave);
+            saveMenuItem = versionRecordManager.newSaveMenuItem(this::saveAction);
         }
         return saveMenuItem;
     }
 
+    protected void saveAction() {
+        assetUpdateValidator.validate(null,
+                                      new ValidatorWithReasonCallback() {
+                                          @Override
+                                          public void onFailure(final String reason) {
+                                              if (ValidationErrorReason.NOT_ALLOWED.name().equals(reason)) {
+                                                  showError(kieEditorWrapperView.getNotAllowedSavingMessage());
+                                              } else {
+                                                  showError(kieEditorWrapperView.getUnexpectedErrorWhileSavingMessage());
+                                              }
+                                          }
+
+                                          @Override
+                                          public void onSuccess() {
+                                              doSave();
+                                          }
+
+                                          @Override
+                                          public void onFailure() {
+                                              showError(kieEditorWrapperView.getUnexpectedErrorWhileSavingMessage());
+                                          }
+                                      });
+    }
+
+    private void showError(final String error) {
+        notification.fire(new NotificationEvent(error,
+                                                NotificationEvent.NotificationType.ERROR));
+    }
+
     /**
      * Get the MenuItem that should be used for listing "(Registered) documents".
      * @return
@@ -605,18 +652,10 @@ public abstract class KieMultipleDocumentEditor<D extends KieDocument> implement
     }
 
     void onRepositoryRemoved(final @Observes RepositoryRemovedEvent event) {
-        if (event.getRepository() == null) {
-            return;
-        }
-        if (workbenchContext == null) {
-            return;
-        }
-        if (workbenchContext.getActiveRepository() == null) {
-            return;
-        }
-        if (workbenchContext.getActiveRepository().equals(event.getRepository())) {
-            enableMenus(false);
-        }
+        Optional.ofNullable(workbenchContext)
+                .flatMap(context -> context.getActiveWorkspaceProject())
+                .filter(proj -> event.getRepository() != null && proj.getRepository().equals(event.getRepository()))
+                .ifPresent(repo -> enableMenus(false));
     }
 
     /**
