@@ -19,18 +19,22 @@ package org.kie.workbench.common.widgets.metadata.client;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
+import java.util.Optional;
 
 import com.google.gwtmockito.GwtMockitoTestRunner;
 import com.google.gwtmockito.WithClassesToStub;
-import org.drools.workbench.models.datamodel.imports.Imports;
-import org.guvnor.common.services.project.model.Project;
+import org.guvnor.common.services.project.model.Module;
+import org.guvnor.common.services.project.model.WorkspaceProject;
 import org.guvnor.common.services.shared.metadata.model.Overview;
+import org.guvnor.structure.organizationalunit.OrganizationalUnit;
+import org.guvnor.structure.repositories.Branch;
 import org.guvnor.structure.repositories.Repository;
 import org.guvnor.structure.repositories.RepositoryRemovedEvent;
 import org.jboss.errai.common.client.api.RemoteCallback;
 import org.jboss.errai.security.shared.api.identity.User;
 import org.junit.Test;
 import org.junit.runner.RunWith;
+import org.kie.soup.project.datamodel.imports.Imports;
 import org.kie.workbench.common.widgets.client.datamodel.AsyncPackageDataModelOracle;
 import org.kie.workbench.common.widgets.metadata.client.widget.OverviewWidgetPresenter;
 import org.mockito.ArgumentCaptor;
@@ -61,7 +65,7 @@ public class KieMultipleDocumentEditorTest
 
     @Test
     public void testSetupMenuBar() {
-        doReturn(mock(Project.class)).when(workbenchContext).getActiveProject();
+        doReturn(Optional.of(mock(WorkspaceProject.class))).when(workbenchContext).getActiveWorkspaceProject();
         doReturn(true).when(projectController).canUpdateProject(any());
 
         editor.setupMenuBar();
@@ -70,12 +74,13 @@ public class KieMultipleDocumentEditorTest
                times(1)).addSave(any(MenuItem.class));
         verify(fileMenuBuilder,
                times(1)).addCopy(any(BasicFileMenuBuilder.PathProvider.class),
-                                 eq(fileNameValidator));
+                                 eq(assetUpdateValidator));
         verify(fileMenuBuilder,
                times(1)).addRename(any(BasicFileMenuBuilder.PathProvider.class),
-                                   eq(fileNameValidator));
+                                   eq(assetUpdateValidator));
         verify(fileMenuBuilder,
-               times(1)).addDelete(any(BasicFileMenuBuilder.PathProvider.class));
+               times(1)).addDelete(any(BasicFileMenuBuilder.PathProvider.class),
+                                   eq(assetUpdateValidator));
         verify(fileMenuBuilder,
                times(1)).addValidate(any(Command.class));
         verify(fileMenuBuilder,
@@ -84,7 +89,7 @@ public class KieMultipleDocumentEditorTest
 
     @Test
     public void testSetupMenuBarWithoutUpdateProjectPermission() {
-        doReturn(mock(Project.class)).when(workbenchContext).getActiveProject();
+        doReturn(Optional.of(mock(WorkspaceProject.class))).when(workbenchContext).getActiveWorkspaceProject();
         doReturn(false).when(projectController).canUpdateProject(any());
 
         editor.setupMenuBar();
@@ -93,12 +98,13 @@ public class KieMultipleDocumentEditorTest
                never()).addSave(any(MenuItem.class));
         verify(fileMenuBuilder,
                never()).addCopy(any(BasicFileMenuBuilder.PathProvider.class),
-                                eq(fileNameValidator));
+                                eq(assetUpdateValidator));
         verify(fileMenuBuilder,
                never()).addRename(any(BasicFileMenuBuilder.PathProvider.class),
-                                  eq(fileNameValidator));
+                                  eq(assetUpdateValidator));
         verify(fileMenuBuilder,
-               never()).addDelete(any(BasicFileMenuBuilder.PathProvider.class));
+               never()).addDelete(any(BasicFileMenuBuilder.PathProvider.class),
+                                  eq(assetUpdateValidator));
         verify(fileMenuBuilder,
                times(1)).addValidate(any(Command.class));
         verify(fileMenuBuilder,
@@ -663,6 +669,9 @@ public class KieMultipleDocumentEditorTest
 
     @Test
     public void testSave() {
+        doReturn(Optional.of(mock(WorkspaceProject.class))).when(workbenchContext).getActiveWorkspaceProject();
+        doReturn(true).when(projectController).canUpdateProject(any());
+
         final TestDocument document = createTestDocument();
         registerDocument(document);
         activateDocument(document);
@@ -744,7 +753,10 @@ public class KieMultipleDocumentEditorTest
     @Test
     public void testOnRepositoryRemoved() {
         final Repository repository = mock(Repository.class);
-        when(workbenchContext.getActiveRepository()).thenReturn(repository);
+        when(workbenchContext.getActiveWorkspaceProject()).thenReturn(Optional.of(new WorkspaceProject(mock(OrganizationalUnit.class),
+                                                                                                       repository,
+                                                                                                       mock(Branch.class),
+                                                                                                       mock(Module.class))));
 
         editor.setupMenuBar();
 
